function MRF4Story_analysis(basicdir,designcase,analysistype,...
	LabelSize,FigureFontSize)
% MRF4Story_analysis(basicdir,designcase,analysistype,...
% LabelSize,FigureFontSize)
% Using this file you can run pushover, dynamic, eigenvalue or IDA analysis on the
% 4-story MRF building. You can also plot the model created in Opensees, 
% but this option is available only if you first run dynamic or pushover analysis
% so that the .out file of the model is created via OpenSees
% -------------------------------------------------------------------------
% INPUT
% basicdir:     directory where MRF4Story_analysis file is located
% designcase:   defines which design of the MRF you want to run. Options:
%               'A' or 'a'    for the 4-story MRF designed using method A 
%                             (book's example 1)
%               'B' or 'b'    for the 4-story MRF designed using method B 
%                             (book's example 2)
%               'C' or 'c'    for the 4-story MRF designed using method C 
%                             (book's example 3)
% analysistype: 'pushover'    run pushover analysis
%               'dynamic'     run dynamic analysis
%               'IDA'         run Incremental Dynamic Analysis (IDA)
%               'eigenvalue'  run eigenvalue analysis
%               'plotModel'   plot the model of the MRF
%                             (available only if you have already run
%                             pushover or dynamic analysis)
%               The analysistype parameter is not case-sensitive
% LabelSize:      size of x and y axes labels of figures (default: 22)
% FigureFontSize: size of fonts in figures (default: 18)
% -------------------------------------------------------------------------
% OUTPUT
% none but saves many files in the
% ..\Examples_1_2_3\Results\ExampleXX\Analysis\analysistype path
% -------------------------------------------------------------------------
% EXAMPLES of how we call this function:
% % Run pushover analysis on book's example 3 in Akrivi's PC
% MRF4Story_analysis('C:\Users\superuser\Examples_1_2_3','C','pushover')
% % Plot the model of book's example 3 on Akrivi's PC (available only if 
% you have run pushover or dynamic analysis first)
% MRF4Story_analysis('C:\Users\superuser\Examples_1_2_3','C','plotModel')
% % Run IDA analysis on book's Example 3 in Akrivi's PC
% MRF4Story_analysis('C:\Users\superuser\Examples_1_2_3','C','IDA')
% _________________________________________________________________________
% Created 08/07/2019 by A. Chatzidaki & D. Vamvatsikos


% ****************** check user input ******************
if nargin<5, FigureFontSize=18; end
if nargin<4, LabelSize=22; end
if nargin<3, error('Need at least three arguments'); end

% check that the designcase is valid and define the number of the example 
if strcmpi(designcase, 'a') == 1;
	exampleNo = 1; 
elseif strcmpi(designcase, 'b') == 1;
	exampleNo = 2; 
elseif strcmpi(designcase, 'c') == 1;
	exampleNo = 3; 
else
	error('unknown designcase!')
end


% check that the designcase is valid and define the number of the example 
analysistypes =  {'pushover', 'dynamic', 'IDA', 'eigenvalue', 'plotModel'};
if ~any(strcmpi(analysistypes, analysistype))
	error('unknown analysistype!')
end
% ****************** check user input (end) ******************


% ****************** setting the parameters ******************
% change the "\" to "/" in the directory
basicdir=regexprep(basicdir,'\','/');

% Define the folder where the .tcl files of the MRF are stored. By
% default they are in:
FilesPath=[basicdir,'/OpenseesModel/Model'];
cd(FilesPath)

% define the path where the results will be stored. By default they are
% saved in basicdir/Results/ExampleXX/Analysis/analysistype
ResultsPath=[basicdir,'/Results/Example',num2str(exampleNo),'/Analysis'];
% Create this folder if it does not already exist
if ~exist(ResultsPath, 'dir'); mkdir(ResultsPath);  end


% Define the height of the building (used to convert the roof
% drift ratio to roof displacement) and the input unit (used in the x-label
% of the pushover curve)
BldgHeight= 16.45; 
BldgHeightUnit= 'm'; % input in inches
% scale factor to convert the kN computed via OpenSees to the forceUnit
% in the following case the desired forceUnit is kN thus the forceConv is 1.
forceConv=1.;
forceUnit='kN';

if strcmpi(analysistype,'IDA')==1
    % For IDA analysis, the following directories should be defined:

	% directory of the records 
	recorddir=[basicdir,'/RunIDA/bundle_runIDA/osees/records'];
	% change '\' slashes to '/' so that Opensees can read the paths 
    recorddir=regexprep(recorddir,'\','/');
    
    % Define the path where the Osees files will be stored for running IDA
    % analysis (they will be copied automatically in this path)
	anlsdir  =[basicdir,'/RunIDA/bundle_runIDA/osees/Model'];
	% Path where the bundle_runIDA functions are stored
	IDAPTpath=[basicdir,'/RunIDA/bundle_runIDA'];
end
% ****************** setting the parameters (end) ******************


if strcmpi(analysistype,'pushover')==1
	% Run pushover analysis and plot the pushover curve in terms of 
	% base shear in forceUnit and roof displacement in BldgHeightUnit
	
	% write the .tcl file with the type of analysis and the building that
	% you want to run
	write_MatIDA_paramfile(FilesPath,'Mat_anlsfile.tcl',0,...
        'analysistype','pushover','design',designcase)
	% Run pushover analysis. During the pushover analysis you can
	% view the deformation of the model, by uncommenting 582-589 lines of the 
	% Lumped_Mark4Story.tcl file in ...\Examples_1_2_3\OpenseesModel\Model
	% path
	!Opensees.exe Lumped_Mark4Story.tcl
	
	% read the roof drift and plot the pushover curve in terms of base
	% shear (kN) and roof displacement (=roof drift * BldgHeight)
	RoofDrift=dlmread(fullfile(FilesPath,'roofdrx.out'));figure; hold on
	plot(RoofDrift(:,2)*BldgHeight,RoofDrift(:,1)*forceConv,'k-','linewidth',2)
	xlabel(['roof displacement (',BldgHeightUnit,')'],'fontsize',LabelSize)
	ylabel(['base shear (',forceUnit,')'],'fontsize',LabelSize)
	grid on; box on; set(gca,'fontsize',FigureFontSize)
	% store the pushover figure in the ResultsPath/pushover directory
    % create this directory if it doesnt exist
    PushoverPath=[ResultsPath,'/',analysistype];
	if ~exist(PushoverPath, 'dir'); mkdir(PushoverPath);  end
	% save the figures in .fig and .png format
	saveas(gca,fullfile(PushoverPath,'Pushover'))
	saveas(gca,fullfile(PushoverPath,'Pushover'),'png')
	
	
elseif strcmpi(analysistype,'dynamic')==1
	% run dynamic analysis and plot thetaroof - dt figure
	
	% write the .tcl file with the analysis type to be performed and the
	% building that you want to run
	write_MatIDA_paramfile(FilesPath,'Mat_anlsfile.tcl',0,...
        'analysistype','dynamic','design',designcase)
	% run the dynamic analysis
	!Opensees.exe Lumped_Mark4Story.tcl
    % read the results and plot thetaroof-dt 
    RoofDrift=dlmread(fullfile(FilesPath,'roofdrx.out'));figure; hold on
    plot(RoofDrift(:,1),RoofDrift(:,2),'linewidth',2)
	ylabel('roof drift','fontsize',LabelSize)
	grid on; box on; set(gca,'fontsize',FigureFontSize)
    % the figure will be stored in the ResultsPath/dynamic directory 
    DynamicPath=[ResultsPath,'/',analysistype];
    % create the directory if it doesnt exist
	if ~exist(DynamicPath, 'dir'); mkdir(DynamicPath);  end
	% save the figures in .fig and .png format
	saveas(gca,fullfile(DynamicPath,'rdr'))
	saveas(gca,fullfile(DynamicPath,'rdr'),'png')

elseif strcmpi(analysistype,'eigenvalue')==1
	% run eigenvalue analysis and show the periods in the command line 
	
	% write the .tcl file with the analysis type to be performed and the
	% building that you want to run
	write_MatIDA_paramfile(FilesPath,'Mat_anlsfile.tcl',0,...
        'analysistype','eigenvalue','design',designcase)
	% run eigenvalue analysis
	!Opensees.exe Lumped_Mark4Story.tcl
    % read the periods 
    Periods=dlmread(fullfile(FilesPath,'MRF4StoryPeriods.out'));
	display(Periods)
	
    % the periods will be stored in the ResultsPath/eigenvalue directory 
    EigenvaluePath=[ResultsPath,'/',analysistype];
    % create the directory if it doesnt exist
	if ~exist(EigenvaluePath, 'dir'); mkdir(EigenvaluePath);  end
	% copy the periods file to the eigenvalue analysis results path
	copyfile(fullfile(FilesPath,'MRF4StoryPeriods.out'), fullfile(EigenvaluePath,'MRF4StoryPeriods.out'));

elseif strcmpi(analysistype,'IDA')==1
    % run Incremental Dynamic Analysis (IDA) using the records defined in
    % the runIDA_MRF4Story.m file. The records should be located inside
    % the recorddir.
    
   	% write the .tcl file with the analysis parameters and the building 
	% you want to run. Note that running IDA analysis requires
   	% setting the analysis type to dynamic 
	write_MatIDA_paramfile(FilesPath,'Mat_anlsfile.tcl',0,...
        'analysistype','dynamic','design',designcase)
        
    % by default the model files and Opensees.exe file should be located 
    % in anlsdir parent folder. To avoid asking the user to copy-paste
    % them manually, we do it automatically using the following function.
    % This does not allow e.g. continuing the analysis if it stopped but
    % the user can easily modify the code so that this option is enabled
    preIDA_MRF4Story( anlsdir, FilesPath )
    
	% load the path of runIDA_MRF4Story.m file
	cd(IDAPTpath)
	
	% Run the analysis! This analysis may last for a couple of hours so do
	% not worry about it! The output is the MRF4Story.sida.mat file 
	% that can be found in anlsdir.
	runIDA_MRF4Story(anlsdir,recorddir)
	
elseif strcmpi(analysistype,'plotModel')==1
    % plot the 2D model created in Opensees.
    
	% Define the path where the MRF4StoryModel.out file is stored. You
	% should first run any kind of analysis for this file to be
	% created and then you can plot the model. 
	% By default the figure of the model is saved in the FilesPath folder
	EVfname=[FilesPath,'/MRF4StoryModel.out'];
    if exist(EVfname,'file')==2
        [FEnode,FEelt,FEfix,FEzero,FErigid,cdisps,eigv,SPcon,MPcon,...
            nloads,nmass,MQN,ndim]=read_opensees_modelfile(EVfname);
        figure
        clf
        plotframe2(FEnode,FEelt,FEfix,FEzero,FErigid,nloads,nmass,ndim,[1,1,0,0]);
        % save the figure of the model in Results/model path
         % create the directory if it doesnt exist
        ModelPath=[ResultsPath,'/model'];
        % create the directory if it doesnt exist
        if ~exist(ModelPath, 'dir'); mkdir(ModelPath);  end
        % save the figures in .fig and .png format
        saveas(gca,fullfile(ModelPath,'MRF4StoryModel'))
        saveas(gca,fullfile(ModelPath,'MRF4StoryModel'),'png')
        
    else
        error ('please run pushover or dynamic analysis first so that the .out file of the model is created...')
    end
end

