function [ FDrpoConf,FCr,FDrpo] = CheckPOs_StripeAnalysis( AnalysisType,...
    EDPlim,EDPval,IMlevel,conf,betaadditional,sf,T,hz,statisticsflag,plotflag )
% [FDrpoConf,FCr,FDrpo] = CheckPOs_StripeAnalysis( AnalysisType,EDPlim,EDPval,...
%           IMlevel,conf,betaadditional,sf,T,hz,statisticsflag,plotflag )
% Estimates the Factored Demand (FDrpo) and Factored Capacity (FCr) based on 
% single- or double-stripe analysis results 
% -------------------------------------------------------------------------
% INPUT
% AnalysisType   = type of analysis results to be used for estimating FDrpo 
%                  and FCr. Options: 
%                  "single" for single stripe analysis results
%                  "double" for double stripe analysis results
% EDPlim         = limit of the PO to be checked
% EDPval         = EDP stripe results. For single stripe analysis it
%                  should be a (1x1) cell with (1 x NStripeRecords) vector. 
%                  For double stripe analysis (2x1) cell containing the 
%                  EDP values of each stripe
% IMlevel        = for single stripe analysis it is the IM level of the 
%                  stripe. For double stripe analysis it is a (2x1) vector
%                  of the IM level of each stripe.
% betaadditional = additional uncertainty on demand and capacity 
%                  (see Section 13.4.2.1 of book)
% conf           = confidence level of the PO to be checked
% T              = period of the structure. Used to find the Hazard Curve
% hz             = hazard curve data
% sf             = scale factor for scaling the Hazard Curve (default = 1)
% statisticsflag = flag that controls how the statistics of the stripes
%                  are computed. For 1 the median and std functions
%                  are used while for 2 the quantile function is
%                  used. The latter can be useful if NaN values appear in 
%                  the EDP data, since the median and std functions would 
%                  return NaN. (Default value is 2)
% plotflag       = if plotflag=1 then the figures are displayed
%                  (default = 1)
% -------------------------------------------------------------------------
% OUTPUT
% FDrpoConf      = factored demand with at "conf" confidence 
% FCr            = factored capacity
% FDrpo          = factored demand at 50% confidence
% -------------------------------------------------------------------------
% _________________________________________________________________________
% Created 08/07/2019 by A. Chatzidaki & D. Vamvatsikos


% -------------------------- CHECK INPUT (start) ------------------------------
% check the dimensions of the  EDPval and the IMlevel 
% depending on the analysis type
if strcmpi(AnalysisType,'single')==1; 
	if ~length(EDPval)==1; error ('wrong dimensions of the EDPval cell'); end
	if ~length(IMlevel)==1; error ('wrong dimensions of the IMlevel'); end
elseif strcmpi(AnalysisType,'double')==1; 
	if ~length(EDPval)==2; error ('wrong dimensions of the EDPval cell'); end
	if ~length(IMlevel)==2; error ('wrong dimensions of the IMlevel'); end
else
	error('analysisType should be either single or double');
end

% if the sf is not determined, then the HC is assumed to be unscaled
if isempty(sf); sf=1; display('unscaled Hazard Curve'); end
	
if isempty(plotflag); plotflag=1; end
if isempty(statisticsflag); statisticsflag=2; end

FigureFontSize=22;
FigureLineWidth=3;
% -------------------------- CHECK INPUT (end) ------------------------------


if statisticsflag==2;
	% calculate the median and the log standard deviation of the EDP values.
	% We used the quantile instead of the "median" to avoid NaN outputs if NaN
	% values are found in the EDPs
	medEDP=quantile(EDPval{1,1},0.5);
	betaDR=(quantile(log(EDPval{1,1}),0.84)-quantile(log(EDPval{1,1}),0.50));
else 
	medEDP=median(EDPval{1,1});
	betaDR=std(log(EDPval{1,1}));

end

% calculate the slope
if strcmpi(AnalysisType,'single')==1
	% for single stripe analysis, the slope is assumed to be equal to 1. 
	slope = 1;
elseif strcmpi(AnalysisType,'double')==1
	% for double stripe analysis, the slope equals the slope of the 
	% line that connects the median EDP values 
   if ~isnan(EDPval{2,1})
	   medDRDouble=median(EDPval{2,1});
   else
	   medDRDouble=quantile(EDPval{2,1},0.5);
   end
   slope=(log(medDRDouble)-log(medEDP))/log(IMlevel(2)/IMlevel(1));
end


% Estimate the slope of the line that connects IM1 and IM2 and the
% corresponding values of the Hazard Curve. For the reasoning behind this 
% biased first-order fitting of the IDA, see
% Vamvatsikos D. (2014). Accurate application and second-order improvement 
% of the SAC/FEMA probabilistic formats for seismic performance assessment. 
% ASCE Journal of Structural Engineering, 140(2), 04013058. 

IM1=IMlevel(1)*exp(0.);
IM2=IMlevel(1)*exp(-1.0*sqrt(betaadditional^2+betaDR^2)/slope);

[MAFIM]=findMAFfromHazardCurve(T,sf,[IM1,IM2],hz,'interplinear',plotflag);
MAFIM1=MAFIM(1); MAFIM2=MAFIM(2);
if plotflag==1;
	hold on
	plot(IM2,MAFIM2,'o','MarkerSize',7,'MarkerFaceColor','k','MarkerEdgeColor','k')
	text(IM2,MAFIM2,[' IM = ',num2str(round(1000*IM2)/1000)],'HorizontalAlignment','right','color','k','FontSize',FigureFontSize)
	text(IM1,MAFIM1,[' IM = ',num2str(round(1000*IM1)/1000)],'HorizontalAlignment','left','color','k','FontSize',FigureFontSize)
	set(gca,'fontsize',FigureFontSize)
	% plot the line connecting (IM1,MAFIM1) and (IM2,MAFIM2)
	a=(log(MAFIM1)-log(MAFIM2))/(log(IM1)-log(IM2));
	b=log(MAFIM1)-a*log(IM1);
	plot([0.03,10],[exp(a*log(0.03)+b),exp(a*log(10)+b)],'k:','LineWidth',FigureLineWidth)
    ylim([10^-10, 1])
end

% estimate the slope k
k=abs(log(MAFIM1)-log(MAFIM2))/(log(IM1)-log(IM2));

% Estimate Factored Capacity and Factored Demand 
FDrpo=medEDP*exp(0.5*k*betaDR^2/slope);
FCr=EDPlim*exp(-0.5*k*betaadditional^2/slope);
% Estimate factored demand @conf
FDrpoConf=FDrpo*exp(norminv(conf,0,1)*betaadditional);
end

