function [lambda,extrapl]=MAF_of_limitstate_basedon_IM_hazfast(c_IM,IM,MAF,ndiv)
% [lambda,extrapl]=MAF_of_limitstate_basedon_IM_hazfast(c_IM,IM,MAF,ndiv)
%____________________________________________________________
% INPUT
%   c_IM : Array ( #Records x Nls or 2 x Nls) of the capacity values in IM 
%          for the limit state we want to calculate. Each column corresponds
%          to a single limit-state. Each column is either a vector of
%          capacity IM values from records or it is a vector of
%          two only. Then each column is assumed to be [mean(log);std(log)] for a
%          lognormal distribution assumption.
% MAF,IM : Mean Annual Frequencies for the same IM as the capacity
%          is expressed in. Two (1 x #IM_values) arrays
%          first contains the IM-values (x)  and the second
%          the MAFs (lambdas or "y"). They should be ordered in descending
%          order of MAF
% ndiv   : number of subdivisions, used internally to control
%          accuracy of the integration. Default value is 10, which
%          is usually good enough. If you input N=20 c_IM values, you 
%          get 200 points for the trapezoidal-rule integration by
%          default. Note that if c_IM is two-elements (lnflag is on) then
%          a number of 40*ndiv will be used for the integration of the
%          lognormal. 
%
% OUTPUT
%  lambda : a vector of Nls values, where Nls is the number of limit-states supplied for
%           MAF calculation with the given hazard curve.
%  extrapl: a vector of Nls values to indicate extrapolation in the
%           production of the corresponding lambda-value. 
%           0 = no extrapolation
%           1 = limited extrapolation (10 or 90% point out of hazard bounds
%               for lognormal or min or max capacity point out of bounds
%               for discrete case).
%           2 = bad extrapolation (median capacity out of bounds)
%______________________________________________________________________
% 
% Created 18/Feb/2012 by D. Vamvatsikos, based on
%          MAF_of_limitstate_basedon_IM.m
% Updated 20/Aug/2012: Added a check to make sure that the numerically
%     computed hazard is at least equal to the elastic one when a very low
%     dispersion is supplied. Similar to what is done for my Excel
%     spreadsheet! I have also added a check to introduce additional points
%     to improve even better when the dispersion is low. I have also added
%     some checks to produce the extrapl output that tells us when
%     extrapolation has occured. BE WARNED THAT I HAVE NOT TESTED THIS
%     ENOUGH THOUGH. ANOTHER SOLUTION IS TO IMPROVE THE HAZARD FIT TO
%     MAINTAIN A REASONABLE SLOPE AT BOTH ENDS. SEE MY IMRPOVED SAC/FEMA
%     scripts.

%
% NOTE: 
%  1) I have thought about implementing my PDF version of this routine, as
%  in the 4th version of ATC76-SdiHazard in Excel. While it should be
%  faster, it will only work well for the lognormal case. Otherwise I would
%  need to estimate a PDF by linearly approximating the PMF and rescaling
%  it properly to have an integral of 1 for the number of points selected.
%  This could work but it could also be trouble. 
%  2) If you want to check the accuracy of this routine, use
%  improvedSACFEMA. Therein, in the comments, I have included some lines to
%  test this against its predecessor and for both the lognormal and the
%  discrete case. You will see that the discrete case produces slightly
%  higher results than the lognormal. If you increase the number of ndiv
%  though and the number of points supplied, then you will get indeed
%  much closer results between the two.
%  3) Something left to resolve is the extrapolation to higher values. It
%  sure raises the flag but for sure, by assigning zero values to the
%  hazard over there  we should be able to salvage things. It is nearly
%  impossible to salvage the low IM extrapolation problem.
%




% 10 subdivisions ensure good accuracy in most cases.
if nargin<4, ndiv=10; end
if nargin<3, error('need at least 3 arguments'); end
if length(MAF)~=length(IM), error('IM and MAF must be same length'); end
% assuming a lognormal distribution with parameters that are something like
% the vector of two: c_IM=[mean(log),std(log)]
[N,Nls]=size(c_IM);
if N==2, lnflag=1; else lnflag=0; end
%keyboard

% Zero means no extrapolation
extrapl=zeros(1,Nls);

% fit nMAF with a spline! Allows us to generate MAF for arbitrary
% SAs. Actually, fit the log-log curve
% get the pp-form of the curve
% Discard all values on the hazard curve where MAF=0. They do not add
% to the probability of exceedance and are not easy to spline-fit
indy=find(MAF~=0);
spline_loghz=spline(log(IM(indy)),log(MAF(indy)));
% now do the differentiation to get gradient. Careful, because sMAF
% is in the log-log space.
d_spline_loghz=fnder(spline_loghz);
% Note that: d(lnx)= (d(lnx)/dx) * dx = 1/x * dx
% d(lny)/d(lnx) = (1/y)/(1/x)*dy/dx
%               = x/y * dy/dx
% SO dy/dx = y/x * d(lny)/d(lnx)

lambda=zeros(1,Nls);


if ~lnflag
   extrapl(find(min(c_IM)<IM(1)|max(c_IM)>IM(end)))=1;
   extrapl(find(median(c_IM)<IM(1)|median(c_IM)>IM(end)))=2;
   for i=1:Nls
      % store the original c_IM, because later, when you want to use
      % quantiles, means and stddevs to get the lambda2 approximation,
      % removing repeated values will bias the result.
      orgc_IM=c_IM(:,i)';
      %*** Newer Version: Allows repeats and fixes the empirical CCDF
      % accordingly so that no repeats appear there. Otherwise interp1q
      % gives us trouble.
      [tabc_IM,I,J]=unique(orgc_IM);
      % tabulate only accepts positive integers.
      % You could also use ecdf here.
      freq=tabulate(J);
      Pc_IM=cumsum(freq(:,2)')*(1/N); % empirical CDF of IMc
      if any(tabc_IM~=0 & tabc_IM<IM(1))
         warning('numerical integration inaccurate: Capacities are lower than minIM of hazard curve')
         % NOTE: I AM ASSUMING THAT EXTRAPOLATION ON THE HIGHER END WILL BE
         % OK BUT THIS IS NOT TRUE WITH THE GIVEN HAZARD FIT THAT MAY
         % DIVERGE FROM ITS PATH TO VERY LOW VALUES.
      end

      % Check if all c_IM are the same (lnflag==0).
      % This usually means that you have an elastic SDOF system and you should
      % simply return the Sa-hazard MAF that corresponds to the median Sa
      % capacity.
      if length(tabc_IM)==1
         % remember that c_IM contains only the unique values of capacity!
         lambda(i)=exp(ppual(spline_loghz,log(c_IM(1))));
         continue
      end
      % Generate the IM values where the integration will be done.
      % Start
      % from the minimum IM-capacity all the way not just to the max IM
      % capacity, but to the last IM value where MAF~=0.
      % Makes no sense to go lower than the lowest c_IM, as the empirical CDF is
      % zero there.
      c_indy=find(tabc_IM<IM(indy(end))&tabc_IM>=IM(1));
      IM_points = [tabc_IM(c_indy),IM(indy(end))];
      len_points = length(IM_points);
      % An ingeneous way to put ndiv points between each of the c_IM
      % points. Use a linear interpolation between 1,2,3 and the
      % IM-points and then use it to calculate values at 1.1, 1.2, 1.3 etc.
      x=interp1q([1:len_points]',IM_points',linspace(1,len_points,len_points*ndiv)');
      y=exp(ppual(spline_loghz,log(x)));
      dlny_dlnx=ppual(d_spline_loghz,log(x));
      dy_dx= (y./x) .*dlny_dlnx;
      % LINEAR INTERPOLATION OF THE EMPIRICAL CDF
      % Notice that we only compute points from the first c_IM point up to the
      % one where MAF first becomes 0. Points higher are useless, while lower
      % IM's than the first capacity should not be "linearly interpolated" from
      % IM=0 to IM=c_IM(1). They have high MAFs and if we give them any chance to
      % cause collapse, if their prob of causing collapse is non-zero, they will
      % affect the result, especially if we have few records.
      if x(end)>tabc_IM(end)
         % happens for IO. Need to designate all IMs above last c_IM to
         % have probability of 1
         linear_Pc=interp1q([tabc_IM,IM(indy(end))]',[Pc_IM,1]',x);
      else
         % happens for CP and GI. No IM in "x" is large enough to have
         % probability of 1.
         linear_Pc=interp1q(tabc_IM',Pc_IM',x);
      end
      lambda(i)=trapz(x,-linear_Pc.*dy_dx); % units is 1/yr
   end
else
   %% Generate the IM values where the integration will be done.
   % if having a lognormal, then there is still some probability at the low
   % end so you might as well include that, down to the lowest IM point in
   % the hazard curve. Thus include all the IM-points of the hazard curve
   % with non-zero MAF. The next commands will put more points in-between!
   IM_points = IM(indy);
   len_points = length(IM_points);
   % An ingeneous way to put ndiv points between each of the c_IM
   % points. Use a linear interpolation between 1,2,3 and the
   % IM-points and then use it to calculate values at 1.1, 1.2, 1.3 etc.
   x=interp1q([1:len_points]',IM_points',linspace(1,len_points,len_points*ndiv)');
   % New addition: Make things denser between the 10% and 90% of the
   % capacity distribution, with more emphasis on the earlier parts that
   % produce most of the integrant. If the dispersion is low, sometimes you miss
   % this spot completely.
   IMlim10=logninv(repmat(0.1,1,Nls),c_IM(1,:),c_IM(2,:));
   IMlim90=logninv(repmat(0.9,1,Nls),c_IM(1,:),c_IM(2,:));
   y=exp(ppual(spline_loghz,log(x)));
   dlny_dlnx=ppual(d_spline_loghz,log(x));
   dy_dx= (y./x) .*dlny_dlnx;

   % Mark any results that exceed the seismic hazard curve limits as
   % extrapolated:

   % 1 means limited extrapolation (10% or 90% points are off scale)
   extrapl(find(IMlim10<IM(1)|IMlim90>IM(end)))=1;
   % 2 means bad extrapolation, i.e. the median IM capacity is out of
   % bounds. This will overwrite some of the 1's introduced before
   extrapl(find(c_IM(1,:)<log(IM(1))|c_IM(1,:)>log(IM(end))))=2;
   
   %if exp(orgc_IM(1))<IM(1)
   %   warning('median IM capacity less than minIM of hazard. Extrapolation!')
   %elseif exp(orgc_IM(1))>IM(end)
   %   warning('median IM capacity more than maxIM of hazard. Extrapolation!')
   %end
   
   for i=1:Nls
      % store the original c_IM, because later, when you want to use
      % quantiles, means and stddevs to get the lambda2 approximation,
      % removing repeated values will bias the result.
      orgc_IM=c_IM(:,i);
      % Check if beta is zero
      % This usually means that you have an elastic SDOF system and you should
      % simply return the Sa-hazard MAF that corresponds to the median Sa
      % capacity.
      minlambda=exp(ppual(spline_loghz,orgc_IM(1)));


      if (orgc_IM(2)==0 || IMlim10(i)==IMlim90(i))
         % This also captures the case of zero response (orgc_IM(1)==inf)
         % as zero response always comes with zero dispersion. IF NOT,
         % RESCALE SOMEHOW!
         % The second statement is used to guard against round-off errors
         % where for a very low dispersion the 10-90% values come out the
         % same. Consider this the same as having a zero dispersion!
         % c_IM(1) is already a log-mean.
         lambda(i)=minlambda;
      else
         % find indices in the [10%,90%] interval of capacity.
         % if none or few, you must add some!
         xind=find(x>IMlim10(i)&x<IMlim90(i));
         if length(xind)<ceil(0.5*ndiv)
            %introduce extra points to cover the IM-distribution better
            xextra=linspace(IMlim10(i),IMlim90(i),ceil(0.5*ndiv))';
            yextra=exp(ppual(spline_loghz,log(xextra)));
            dlny_dlnx_extra=ppual(d_spline_loghz,log(xextra));
            dy_dx_extra=(yextra./xextra) .*dlny_dlnx_extra;
            % Insert the extra points in the expanded vector. Find first
            % the highest point in x that is lower than all xextra to see where
            % this insertion should happen.
            xindy=max(find(x<IMlim10(i)));
            xindy2=min(find(x>IMlim90(i)));

            % If you are extrapolating make sure at least that the dy_dx_extra are
            % increasing (remember, the dlny_dlnx decrease but the dy_dx
            % increase, meaning that they become less negative)
            % with x: Obviously don't do this for the
            % entire dy_dx as in some cases this may be legitimate.
            dindy=find(diff(dy_dx_extra)<0);
            % find if you are extrapolating low or high!
            if isempty(xindy)
               % this means that the 10% IM capacity is less than the
               % minIM of hazard. Extrapolation occurs. Still let's keep
               % integrating. The user has been warned anyway
               x_new=[xextra ; x];
               for j=length(dindy):-1:1
                  % start from the end and keep increasing dy_dx_extra
                  % values until you hit the very first one. This way
                  % you are certain that you are not in trouble
                  % vis-a-vis initial part of interpolated hazard curve
                  dy_dx_extra(dindy(j))=dy_dx_extra(dindy(j)+1);
               end
               dy_dx_new=[dy_dx_extra;dy_dx];
            elseif xindy==length(x)
               % we are beyond the maxIM point. This means extrapolation
               % occurs towards zero hazard, although we don't really
               % know what will happen for really low values (you are
               % dealing with polynomials here). Best is to call the
               % hazard zero here.
               x_new=[x;xextra];
               for j=1:length(dindy)
                  % start from the end and keep increasing dy_dx_extra
                  % values until you hit the very first one. This way
                  % you are certain that you are not in trouble
                  % vis-a-vis initial part of interpolated hazard curve
                  dy_dx_extra(dindy(j)+1)=dy_dx_extra(dindy(j));
               end
               dy_dx_new=[dy_dx; dy_dx_extra];
            else
               % We are interpolating! Good! 
               % replace all points between xindy and xindy2 (i.e., all in
               % xind) by the xextra points.
               x_new=[x(1:xindy) ; xextra ; x(xindy2:end)];
               dy_dx_new=[dy_dx(1:xindy) ; dy_dx_extra; dy_dx(xindy2:end)];
            end
         else
            % no new points need to be added. Continue as normal
            x_new=x;
            dy_dx_new=dy_dx;
         end
         % Estimate the lognormal CDF directly
         %if ~exist('x_new','var'); keyboard; end
         linear_Pc=logncdf(x_new,orgc_IM(1),orgc_IM(2));
         % make sure result is larger or equal to elastic hazard to guard
         % against very low dispersions!!
         lambda(i)=max([minlambda,trapz(x_new,-linear_Pc.*dy_dx_new)]); % units is 1/yr
      end
   end
end