function [ IMMAF ] = findIMfromHazardCurve(T,sf,MAFs,hz,interpflag,plotflag,...
                LabelSize,FigureFontSize,MarkerSize) 
% [ IMMAF ] = findIMfromHazardCurve(T,sf,MAFs,hz,interpflag,plotflag,...
%                 LabelSize,FigureFontSize,MarkerSize)
% Estimates the MAFs from the hazard curve given the IMs.
% -------------------------------------------------------------------------
% INPUT
% T          = period of the building 
% sf         = scale factor used to scale the Hazard Curve. If sf = 1 or empty
%			   then the hazard curve remains unscaled. If sf != 1, then the MAF of
%              of the hazard curve is scaled by sf
% MAFs        = MAF value/values for which the IM will be computed through the
%              Hazard Curve (1xNmafs) vector
% hz         = seismic hazard curve data 
% interpflag = defines how the interpolation of the hazard curve is
%              performed. Options:
%              0: interplinear = interpolation in the linear space
%              1: interplog    = interpolation in the log-log space
%              other: spline/other = values are calculated by spline fitting of
%                             the hazard curve. This is the best option 
%                             (default)
% plotflag       = if 1 then the Hazard Curve is shown (default = 1)
% LabelSize      = size of x and y axes labels of figures (default 22)
% FigureFontSize = size of fonts in figures (default 18)
% MarkerSize     = size of the markers plot on IDA curves (default 5)
% -------------------------------------------------------------------------
% OUTPUT
% IMMAF    = IM for each MAF, estimated through the (scaled in case of 
%            sf=/=1) hazard curve 
% -------------------------------------------------------------------------


% ----------------- CHECK INPUT DATA (start) -------------------------------
if nargin<9, MarkerSize=5; end
if nargin<8, FigureFontSize=18; end
if nargin<7, LabelSize=22; end
if nargin<6; plotflag=0; end
if nargin<5; interpflag='spline'; end 
if nargin<4, error('Need at least four arguments'); end
% ----------------- CHECK INPUT DATA (end) -------------------------------

% get the hazard curve for the period of the building
[IM,MAF]=get_SaHazardcurve(hz,T,0);


% interpolate the hazard curve to find the IM for the given MAF based on the hazard
% curve
if strcmp(interpflag,'interplinear')==0
    % Interpolate the Hazard Curve to get the MAFs for IM
    % values. Generally, it's better to do it in log-log space rather in the 
    % linear space. However, if the points of the hazard curve are dense 
    % interpolation in the linear space works fine. Best solution is to fit a
    % spline and estimate the MAF and the IM of the spline :-)
    IMMAF=interp1(MAF*sf,IM,MAFs);
elseif strcmp(interpflag,'interplog')==1
    % interpolation in the log-log space (better than in the linear space)
    logIMMAF=interp1(log(MAF*sf),log(IM),log(MAFs));
    IMMAF=exp(logIMMAF);
else
    % spline fitting (best choice)
	MAF2=MAF*sf;
    indy=find((MAF2)~=0);
    ispline_loghz=spline(log(MAF2(indy)),log(IM(indy)));
    IMMAF=exp(ppual(ispline_loghz,log(MAFs))); 
end


if plotflag==1
	% If plotflag=1 the hazard curve is shown
    figure
	loglog(IM,MAF*sf,'k','LineWidth',3)
	% title('Hazard Curves','FontSize',20)
	xlabel('IM (g)','FontSize',LabelSize)
	ylabel('MAF','FontSize',LabelSize)
	set(gcf,'color','white'); 	set(gca,'FontSize',FigureFontSize)
	grid on; box on; hold on
	plot(IMs,IMMAF,'o','MarkerSize',MarkerSize,'MarkerFaceColor','k','MarkerEdgeColor','k')
end

end

