function [ MAFIM ] = findMAFfromHazardCurve(T,sf,IMs,hz,interpflag,plotflag,...
                LabelSize,FigureFontSize,MarkerSize) 
% [ MAFIM ] = findMAFfromHazardCurve(T,sf,IMs,hz,interpflag,plotflag,...
%                 LabelSize,FigureFontSize,MarkerSize)
% Estimates the MAFs from the hazard curve given the IMs. 
% -------------------------------------------------------------------------
% INPUT
% T          = period of the building 
% sf         = scale factor used to scale the Hazard Curve. If sf = 1 or empty
%			   then the hazard curve remains unscaled. If sf != 1, then the MAF of
%              of the hazard curve is scaled by sf
% IMs        = IM value/values for which the MAF will be computed through the
%              Hazard Curve (1xNims) vector
% hz         = seismic hazard curve data 
% interpflag = defines how the interpolation of the hazard curve is
%              performed. Options:
%              interplinear = interpolation in the linear space
%              interplog    = interpolation in the log-log space
%              spline/other = values are calculated by spline fitting of
%                             the hazard curve. This is the best option 
%                             (default)
% plotflag       = if 1 then the Hazard Curve is shown (default = 1)
% LabelSize      = size of x and y axes labels of figures (default 22)
% FigureFontSize = size of fonts in figures (default 18)
% MarkerSize     = size of the markers plot on IDA curves (default 5)
% -------------------------------------------------------------------------
% OUTPUT
% MAFIM    = MAF for each IM, estimated through the HC 
% -------------------------------------------------------------------------

% ----------------- CHECK INPUT DATA (start) -------------------------------
if nargin<9, MarkerSize=5; end
if nargin<8, FigureFontSize=18; end
if nargin<7, LabelSize=22; end
if nargin<6; plotflag=0; end
if nargin<5; interpflag='spline'; end 
if nargin<4, error('Need at least four arguments'); end
% ----------------- CHECK INPUT DATA (end) -------------------------------

% get the hazard curve for the period of the building
[IM,MAF]=get_SaHazardcurve(hz,T,0);

if strcmp(interpflag,'interplinear')==1
    % Interpolate the Hazard Curve to get the MAFs for IM
    % values. Generally, it's better to do it in log-log space rather in the 
    % linear space. However, if the points of the hazard curve are dense 
    % interpolation in the linear space works fine. Best solution is to fit a
    % spline and estimate the MAF and the IM of the spline :-)
    MAFIM=interp1(IM,MAF*sf,IMs);
elseif strcmp(interpflag,'interplog')==1
    % interpolation in the log-log space (better than in the linear space)
    logMAFIM=interp1(log(IM),log(MAF*sf),log(IMs));
    MAFIM=exp(logMAFIM);
else
    % spline fitting (best choice)
    MAF2=MAF*sf;
    indy=find((MAF2)~=0);
    spline_loghz=spline(log(IM(indy)),log(MAF2(indy)));
    MAFIM=exp(ppual(spline_loghz,log(IMs))); 
   
end


if plotflag==1
	% If plotflag=1 the hazard curve is shown
    figure
	loglog(IM,MAF*sf,'k','LineWidth',3)
	% title('Hazard Curves','FontSize',20)
	xlabel('IM (g)','FontSize',LabelSize)
	ylabel('MAF','FontSize',LabelSize)
	set(gcf,'color','white'); 	set(gca,'FontSize',FigureFontSize)
	grid on; box on; hold on
	plot(IMs,MAFIM,'o','MarkerSize',MarkerSize,'MarkerFaceColor','k','MarkerEdgeColor','k')
end

end

