function [ sf ] = findSfHazardCurve(T,MAF_IM,IM_T,hz,interpflag,plotflag,...
    LabelSize,FigureFontSize,MarkerSize)
% [ sf ] = findSfHazardCurve(T,MAF_IM,IM_T,hz,interpflag,plotflag,...
%     LabelSize,FigureFontSize,MarkerSize)
% This function is used to compute the scale factor needed for scaling the Hazard Curve
% (scaling based on the MAF) so that for the IM_T the MAF equals MAF_IM
% ------------------------------------------------------------------------
% INPUT
% T             = period of the building
% MAF_IM, IM_T  = IM value for the given period and corresponding target MAF.
%                 The caled hazard curve will return MAF_IM for IM_T
% hz            = seismic hazard curve data 
% interpflag    = defines how the interpolation of the hazard curve is
%                 performed. Options:
%                 interplinear = interpolation in the linear space
%                 interplog    = interpolation in the log-log space
%                 spline/other = values are calculated by spline fitting of
%                                the hazard curve. This is the best option so
%                                is the default
% plotflag      = if 1 the hazard curves (scaled and unscaled) are shown
%                 (default = 1)
% LabelSize     = size of x and y axes labels of figures (default 22)
% FigureFontSize= size of fonts in figures (default 18)
% MarkerSize:   = size of the markers plot on IDA curves (default 5)
% -------------------------------------------------------------------------
% OUTPUT
% sf            = scale factor 
% _________________________________________________________________________
% Created 08/07/2019 by A. Chatzidaki & D. Vamvatsikos


% ----------------- CHECK INPUT DATA (start) -------------------------------
if nargin<10, MarkerSize=5; end
if nargin<9, FigureFontSize=18; end
if nargin<8, LabelSize=22; end
if nargin<7, plotflag=1; end
if nargin<6, interpflag='spline'; end 
if nargin<5, error('Need at least four arguments'); end
% ----------------- CHECK INPUT DATA (end) -------------------------------


% Get the hazard curve for the period of the building
[IM,MAF]=get_SaHazardcurve(hz,T,0);

% get the IM of the unscaled hazard curve given the MAF_IM 
if strcmp(interpflag,'interplinear')==1
    % interpolation in linear space
    Sa_MAF=interp1((MAF),(IM),(MAF_IM));
elseif strcmp(interpflag,'interplog')==1
    % interpolation in the log-log space
    logSa_MAF=interp1(log(MAF),log(IM),log(MAF_IM));
    Sa_MAF=exp(logSa_MAF);
else
    % spline interpolation (best)
    indy=find(MAF~=0);
    ispline_loghz=spline(log(MAF(indy)),log(IM(indy)));
    Sa_MAF=exp(ppual(ispline_loghz,log(MAF_IM)));
end


% Plot the Hazard Curve and the IM_MAF
loglog(IM,MAF,'color','k','LineWidth',3)
title('Unscaled Hazard Curve','FontSize',FigureFontSize+4)
xlabel('IM (g)','FontSize',FigureFontSize)
ylabel('MAF','FontSize',FigureFontSize)
set(gcf,'color','white')
set(gca,'FontSize',FigureFontSize)
grid on
hold on 
plot(Sa_MAF,MAF_IM,'o','MarkerSize',MarkerSize,'MarkerFaceColor','k','MarkerEdgeColor','k')
text(Sa_MAF,MAF_IM,['IM = ',num2str(round(1000*Sa_MAF)/1000),' \rightarrow'],'HorizontalAlignment','right','FontSize',FigureFontSize)


% If we multiply the hazard curve with the scale factor we should 
% get the MAF_IM for the IM_T. Let's estimate the MAF_Sa, which is the
% MAF value that we get from the Hazard Curve given the IM_T.
if strcmp(interpflag,'interplinear')==1
    % interpolation in linear space
    MAF_Sa=interp1((IM),(MAF),(IM_T));
elseif strcmp(interpflag,'interplog')==1
    % interpolation in the log-log space
    logMAF_Sa=interp1(log(IM),log(MAF),log(IM_T));
	MAF_Sa=exp(logMAF_Sa);
else
    % spline interpolation
    indy=find(MAF~=0);
    spline_loghz=spline(log(IM(indy)),log(MAF(indy)));
    MAF_Sa=exp(ppual(spline_loghz,log(IM_T)));
end

% Now estimate the scale factor: for IM_T we want to get MAF_IM
%                                for IM_T we get         MAF_Sa
% the scale factor of the hazard curve equals: MAF_IM/MAF_Sa
sf=MAF_IM/MAF_Sa;

if plotflag==1;
    % Plots scaled and unscaled hazard curves to check the results
    figure
    loglog(IM,MAF,'color',[0.46,0.44,0.44],'LineWidth',3)
    hold on
    loglog(IM,MAF*sf,'color','k','LineWidth',2)
    % title('Hazard Curves','FontSize',20)
    xlabel('IM (g)','FontSize',LabelSize)
    ylabel('MAF','FontSize',LabelSize)
    set(gcf,'color','white')
    set(gca,'FontSize',FigureFontSize)
    legend('unscaled','scaled')
    grid on
    hold on 
    plot(Sa_MAF,MAF_IM,'o','MarkerSize',MarkerSize,'MarkerFaceColor',[0.46,0.44,0.44],'MarkerEdgeColor',[0.46,0.44,0.44])
    text(Sa_MAF,MAF_IM,['       IM = ',num2str(round(1000*Sa_MAF)/1000)],'HorizontalAlignment','left','color',[0.46,0.44,0.44],'FontSize',FigureFontSize)

    plot(IM_T,MAF_IM,'o','MarkerSize',MarkerSize,'MarkerFaceColor','k','MarkerEdgeColor','k')
    text(IM_T,MAF_IM,['IM = ',num2str(round(1000*IM_T)/1000),'    '],'HorizontalAlignment','right','color','k','FontSize',FigureFontSize)
end


end

