function [FEnode,FEelt,FEfix,FEzero,FErigid,cdisps,eigv,SPcon,MPcon,...
   nloads,nmass,MQN,ndim,idel,eigMass,etype]=read_opensees_modelfile(EVfname)
% 
% For Kavala use:  
% read_opensees_modelfile('e:\users\divamva\opensees\divamva\RCsect','KavalaBridge.out','KavalaBridgeEigenVectors.out')
% For G9 use:  
% read_opensees_modelfile('e:\users\divamva\opensees\divamva\RCsect','G9Bridge.out','G9BridgeEigenVectors.out')
%
% Note: SPcon contains the displacements imposed, so 0 means a fixed dof, 
%       and NaN a free one. On the other hand, FEfix uses 1 to denote a fixed 
%       dof and 0 to denote a free dof.
%________________________________________________________________________
% INPUT
%   EVfname: Name + path to file produced via "print" in OpenSEES
% OUTPUT
%   idel: contains indices to rows of FEelt showing where 4-node elems
%             and 8-node elems start. If empty, only 2-node elems exist.
%  eigMass: contains quantities related to eigenmode masses. It is a structure
%           that contains the field Gamma, Meffx, Meffy, Meffz and Meffxyz. 
%_________________________________________________________________________
%
% Updated: 19/07/04, made compatible with 2D structures as well
% Updated: 20/01/05, will now produce SinglePoint Constraint information, 
%                    by reading the SP_Constraint lines.
% Updated: 24/04/05, able to read masses information and produce 
%                    effective modal masses! Also, it now produces similar
%                    FEnode,FEelt style output that is more human readable.
% Updated: 04/05/05, will produce MQN (member-end forces and moments).
% Updated: 17/06/05, fixed some minor error with Dispbeamcolumn2d
% Updated: 28/09/05, now it will not try to compute Meff when no
%                    eigenvectors exist (this would cause a crash)
% Updated: 03/03/06, fixed to be compatible with openSEES 1.7.0, i.e., 
%                    read the new line describing SP_Constraint.
% Updated: 06/05/06, fixed so that it reads truss-elements that were defined
%                    with a "section" and appear as "TrussSection" elements.
% Updated: 16/Mar/08, fixed a small error in the checking of Mn to figure
%                    out if it contains non-zero elements. Using the 
%                    any(any( ... )) allows this to work for 3D structures.
% Updated: 01/Jun/08, now M and W are plotted even if they are one or two
%                    element vectors
% Updated: 04/Sep/08, fixed an issue where a 3D structure with no mass
%                    would cause a crash when printing the masses.
% Updated: 17/Feb/09, OpenSEES 2.1 uses "Disps" instead of "CommitDisps"
% Updated: 27/Apr/09, included Corottruss element
% Updated: 12/Jul/09, included FourNodeQuad
% Updated: 07/Mar/10, to return eigMass
% Updated: 05/May/10, included ShellMITC4
% Updated: 24/Oct/2012: Around line 395, changed max(...) to max(abs(...))
%         when estimating the max value of the eigenmode to normalize by
%         for estimating Gamma. Also added the capability of reading 
%         "ZeroLengthSection" elements.
% Updated: 14/Jun/2014: They changed the numbering of DOFs in the output file. 
%         It used to be 0-5 and now it is 1-6. I had to change the following
%         lines "SPcon(indx,SPvalues(3)+1)=SPvalues(4); FEfix(indx,SPvalues(3)+1)=(SPvalues(4)==0);
%         to introduce the SPvalues(3)+1 rather than +2 in the past.
% Updated: 16/May/2017: Added support for TwoNodeLink elements at the
%         request of K. Bakalis. Now it also outputs eltype, showing the
%         type of each element in FEelt

% Scheduled: make it produce FErigid and MPcon.
%
% Copyright (c) 2004 by D. Vamvatsikos



rnodej=[];coords=[];cdisps=[];eigv=[];elnode=[];FEelt=[];FEelt4=[];ndim=[];
FEzero=[];SPcon=[];nloads=[];nmass=[];FEfix=[]; FErigid=[]; MPcon=[];MQN=[];
etype={}; etype4={};
% prefer "0" from "[]", as ([]+some array) WILL fail, but (0+some array) NOT!
Mn=0; Ln=0;
Mtotal=0;
imass=0;
ndof=0;


% First we always get a name
fid=fopen(EVfname);

if fid>=0
    %node and element counters!
    i=0;
    j=0; j4=0;
    % string that retains a value depending on what is being read!
    % help distinguish "unblalanced load", whether it refers to a node or a
    % truss element
    creading='';
    while 1
       tline = fgetl(fid);
       % EOF will return -1, so this will force a break.
       %if ~ischar(tline), break, else i=i+1; end
       if ~ischar(tline), break, end
       [firststr,count,errmsg,ni]=sscanf(tline,'%s',1);
       switch lower(firststr)
       case 'node:'
          creading='node';
          i=i+1;
          [nodej,count,errmsg,ni]=sscanf(tline(ni:end),'%d',1);
          % so if you want to find where Opensees node "i" is
          % you just look at rnodej(i). So coords(rnodej(i),:)
          % are its coordinates.
          %rnodej(nodej)=i;
          rnodej(i)=nodej;
       case 'element:'
          % remove string "Element: 29 Type: ForceBeamColumn2d Connected Nodes:"
          % CAREFUL: The elements are renumbered here! The first
          % one always becomes Element 1. Better if you can keep a 
          % nicer count here!
          creading='elem';
          elnum=sscanf(tline(ni:end),'%d',1);
          indy=strfind(lower(tline),'type:');
          if ~isempty(indy)
             [elemtype,count,errmsg,eni]=sscanf(tline(indy(end)+5:end),'%s',1);
             ni=indy(end)+5+eni;
          else
             % this occurs for twonodelink elements that have the type
             % designation in the next line, not the same one as the number
             % of the element. Added 16/06/2017
             tline = fgetl(fid);
             indy=strfind(lower(tline),'type:');
             [elemtype,count,errmsg,eni]=sscanf(tline(indy(end)+5:end),'%s',1);
             ni=indy(end)+5+eni;
          end
          
          switch lower(elemtype)
          case {'forcebeamcolumn2d','forcebeamcolumn3d'}
             creading='elem';
             j=j+1;
             [junk,count,errmsg,jni]=sscanf(tline(ni:end),'%s',2);
             FEelt(j,:)=[elnum,sscanf(tline(ni+jni:end),'%f')'];
             etype{j}=elemtype;
          case  {'truss','trusssection'}
             creading='elem';
             j=j+1;
             indy=strfind(lower(tline),'inode:');
             FEelt(j,1:2)=[elnum, sscanf(tline(indy+6:end),'%f')];
             indy=strfind(lower(tline),'jnode:');
             FEelt(j,3)=sscanf(tline(indy+6:end),'%f');
             etype{j}=elemtype;
          case {'zerolength'}
             creading='elem';
             indy=strfind(lower(tline),'inode:');
             Znode(1,1:2)=[elnum,sscanf(tline(indy+6:end),'%f')];
             indy=strfind(lower(tline),'jnode:');
             Znode(1,3)=sscanf(tline(indy+6:end),'%f');
             FEzero=[FEzero;Znode];
             %etype{j}=elemtype;
          case 'twonodelink'
             % Added 16/06/2017
             %Element: 10122
             %type: TwoNodeLink
             %iNode: 1002, jNode: 2002
             %Material dir1: 20002
             %Mratio:   shearDistI: 0.5 0.5
             %
             %addRayleigh: 0  mass: 0
             %resisting force: 0 -1387.06 -624.179 0 1387.06 -624.179
             creading='elem';
             j=j+1;
             tline = fgetl(fid);
             indy=strfind(lower(tline),'inode:');
             FEelt(j,1:2)=[elnum, sscanf(tline(indy+6:end),'%f')];
             indy=strfind(lower(tline),'jnode:');
             FEelt(j,3)=sscanf(tline(indy+6:end),'%f');
             etype{j}=elemtype;
          otherwise 
             disp('unknown element type')
          end
       case {'corottrusssection,','corottruss,'}  
          creading='elem';
          j=j+1;
          % remove the ' tag:' part
          elnum=sscanf(tline(ni+5:end),'%d',1);
          etype{j}=lower(firststr(1:end-1));
          tline = fgetl(fid);
          % remove string 'connected nodes:'
          [junk,count,errmsg,jni]=sscanf(tline,'%s',2);
          FEelt(j,:)=[elnum,sscanf(tline(jni:end),'%f')'];
       case 'mitc4' 
          creading='elem';
          j4=j4+1;
          % remove the ' element id:' part
          tline = fgetl(fid);
          elnum=sscanf(tline(16:end),'%d',1);
          etype4{j4}=lower(firststr);
          for ijc=1:4
             tline = fgetl(fid);
             tmpnodes(ijc)=sscanf(tline(9:end),'%d');
          end
          % NOTE: this line might cause problems if having beams mixed with
          % quads. Beams have 2 nodes, quads have 4.
          FEelt4(j4,:)=[elnum,tmpnodes];   
       case 'fournodequad,'
          creading='elem';
          j4=j4+1;
          % remove the ' element id:' part
          elnum=sscanf(tline(ni+12:end),'%d',1);
          etype4{j4}=lower(firststr(1:end-1));
          tline = fgetl(fid);
          % remove string 'connected nodes:'
          [junk,count,errmsg,jni]=sscanf(tline,'%s',3);
          % NOTE: this line might cause problems if having beams mixed with
          % quads. Beams have 2 nodes, quads have 4.
          FEelt4(j4,:)=[elnum,sscanf(tline(jni:end),'%f')'];
       case 'zerolengthsection,'   
          creading='elem';
          Znode(1,1)=sscanf(tline(ni+6:end),'%d',1);
          tline = fgetl(fid);
          % remove string 'connected nodes:'
          [junk,count,errmsg,jni]=sscanf(tline,'%s',2);
          Znode(1,2:3)=sscanf(tline(jni:end),'%f')';
          FEzero=[FEzero;Znode];
       case {'elasticbeam2d:','elasticbeam3d:'}
          creading='elem';
          j=j+1;
          elnum=sscanf(tline(ni:end),'%d',1);
          etype{j}=lower(firststr(1:end-1));
          tline = fgetl(fid);
          % remove string 'connected nodes:'
          [junk,count,errmsg,jni]=sscanf(tline,'%s',2);
          FEelt(j,:)=[elnum,sscanf(tline(jni:end),'%f')'];
       case {'dispbeamcolumn3d,','dispbeamcolumn2d,'}   
          creading='elem';
          j=j+1;
          % remove string 'element id:'
          [junk,count,errmsg,jni]=sscanf(tline(ni:end),'%s',2);
          elnum=sscanf(tline(ni+jni:end),'%d',1);
          etype{j}=lower(firststr(1:end-1));
          tline = fgetl(fid);
          % remove string 'connected external nodes:'
          [junk,count,errmsg,jni]=sscanf(tline,'%s',3);
          FEelt(j,:)=[elnum,sscanf(tline(jni:end),'%f')'];
       case 'coordinates'
          % remove the useless "  :"
          [junk,count,errmsg,jni]=sscanf(tline(ni:end),'%s',1);
          % ndim is actually the dimensionality of the model!
          [tcoords,ndim]=sscanf(tline(ni+jni:end),'%f');
          %keyboard
          coords(i,:)=tcoords';
       case {'disps:','commitdisps:'}
          % no need to read the rotations
          if ndof==0
             allcdisp=sscanf(tline(ni:end),'%f');
             ndof=length(allcdisp);
          end
          cdisps(i,:)=sscanf(tline(ni:end),'%f',ndim)';
       case 'unbalanced'
          % truss elements have the nasty habit to produce an 
          % "unbalanced load" label. If this is the case, then do not try to read
          % nodal loads!
          if strcmp(creading,'node')
             % remove the junk "load:"
             [junk,count,errmsg,jni]=sscanf(tline(ni:end),'%s',1);
             nloads(i,:)=sscanf(tline(ni+jni:end),'%f')';
          end
       %case 'nodal load'
          % if no nloads have been read so far, means that we use Quad
          % elements. So only the load pattern has any information on nodal
          % loads! Weird opensees thing.
        %  if isempty(nloads)
             
       case 'sp_constraint:'
          % the line :"SP_Constraints: numConstraints: " is automatically rejected!! 
          % This is because of the extra "s"!!
          [SPvalues]=sscanf(tline(ni:end),'%d Node: %d DOF: %d ref value: %d current value: %d');
          if isempty(SPcon)
             indx=[];
          else
             indx=find(SPcon(:,1)==SPvalues(2));
          end
          % You will get a problem here if there are no committed
          % displacements. Then you will not be able to set ndof and the
          % following will probably fail.
          if isempty(indx)
             % place NaN at each dof
             SPcon=[SPcon;[SPvalues(2),repmat(NaN,1,ndof)]];
             indx=size(SPcon,1);
             % place 0's at each dof.
             FEfix=[FEfix;[SPvalues(2),repmat(0,1,ndof)]];
          end
          % assign the imposed displacement or rotation to the right DOF and node!
          SPcon(indx,SPvalues(3)+1)=SPvalues(4);
          % assign "1" if the selected dof is fixed.
          FEfix(indx,SPvalues(3)+1)=(SPvalues(4)==0);
       case 'end'
          % Read member forces and moments at the ends
          % e.g. "End 1 Forces (P V M): 35.5248 5637.6 8456.4"
          [nextstr]=sscanf(tline(ni:end),'%s',1);
          if any(strcmp(nextstr,{'1','2'})) 
             end_12=str2double(nextstr);
             % remove the strings "Forces (P Mz Vy My Vz T):" (for 3D, 6 dofs!)
             [junk,count,errmsg,jni]=sscanf(tline(ni:end),'%s',2+ndof);
             MQN(j,(end_12-1)*ndof+1:end_12*ndof)=...
                        sscanf(tline(ni+jni:end),'%g',ndof);
          end
       case 'mass'  
          % if the next string is ":" continue (if it is e.g. "density", exit!)
          [nextstr]=sscanf(tline(ni:end),'%s');
          if strcmp(nextstr,':')
             % read the mass assignment for the current node!
             % read the first line of local mass matrix into one matrix line!
             % tmass=sscanf(fgetl(fid),'%f')';
             % from its size determine how many dofs the model has!
             % ndof=size(tmass,2);
             % now read the rest of the mass matrix
             for k=1:ndof
                tline = fgetl(fid);
                % first index is eigenmode, second is node, third denotes x,y,z
                tmass(k,:)=sscanf(tline,'%f');
             end
             nmass(i,:)=diag(tmass)';
             % save the node number for the last addition to the mass matrix
             imass=i;
             Mtotal=Mtotal+nmass(i,:);
          end
          % Note that the effective masses are computed when the
          % eigenvectors are read. That is because the masses appear
          % before the eigenvectors for each node!
       case 'eigenvectors:'
          % read the next "ndim" lines to get x,y,z eigenvector values
          % discard rotations. Each line is one of x,y,z,rx,ry,rz dofs
          % and each column corresponds to one of the modes. 
          for k=1:ndof
             tline = fgetl(fid);
             % first index is eigenmode, second is node, third denotes x,y,z
             eigv(:,i,k)=sscanf(tline,'%f');
          end
          % From Chopra's Book, (pg.482) let's calculate the effective
          % modal mass in X,Y,Z direction separately and in all directions
          % together.
          % The formula (for nth-mode) is : 
          %        Mn_star=(Ln^2)/Mn
          % For masses lumped at the nodes:
          %       Ln = Sum_i(fni*mi*I)
          %       Mn = Sum_i(fni^2*mi)
          %   where i denotes the node, fni the i-th element of nth-eigenvector
          %   and mi is the mass at node-i. 
          %   Now "I" is a vector that has "1" for nodes where acceleration
          %   exists and "0" for nodes where no acceleration exists!
          %   Since we never use rotational components, rotational masses are
          %   useless!
          %   And because of this simple summation formula you do not need to
          %  assemble the full eigenvectors and mass matrices. It can be
          %  done with the locals (they are diagonal anyway!)
          
          % if no mass has been assigned for this node, don't include it
          % in the effective mass calculations. In that case, no 
          % mass output precedes this eigenvector, so imass < i!
          if imass==i 
             for k=1:ndof
                tLn(:,k) = (nmass(i,k)*eigv(:,i,k));
                tMn(:,k) = (nmass(i,k)*eigv(:,i,k).^2);
             end
             Ln=Ln+tLn;
             Mn=Mn+tMn;
          end
       end
          
    end
    fclose(fid);
else
   warning(sprintf('File %s not found',EVfname));
end

%FElin=elnode;
FEnode=[rnodej',coords];

idel=[];
% concatenate the FEelt and FEelt4
if ~isempty(FEelt4)
   % add two columns of NaNs to match sizes between 2node elems and 4node
   % elems. Then add the 4-node elements. This works even if FEelt is
   % empty.
   idel(1)=size(FEelt,1)+1;
   % you will see a warning here if FEelt is empty
   warning off
   FEelt=[[FEelt,repmat(NaN,idel-1,2)];FEelt4];
   warning on
end

% do this check so that when Mtotal=0 (no mass in the model)
% it will not try the rest! Also it will not attempt the calculation
% if Mn==0, meaning that no eigenvectors where calculated.
% Fixed this to work even if Mn is a matrix rather than a vector. Now
% the two any(any(..)) will detect if any single element in Mn is non-zero.
% Mtotal = vector 1xN where N is the number of dofs. 
% It contains the total mass (translational or rotational) participating
% in each of the 3 (for 2D) or 6 (for 3D) dofs typically used in buildings.
% Mn = matrix MxN where M is the # of eigenmodes and N is the number of
% dofs in the structure. Contains the participating mass for each mode and
% each dof.
% Note that the sum of each line of Mn is 1! By comparing such values in a
% single line you can tell if a given mode is e.g. mainly translational
% along x or y or rotational around z (3D structure).
% Also note that the modal participation factor for each node is defined as
% Gamma_n = sum_i(mi*fni)/sum_i(mi*fni^2) according to Fajfar
% (Spectra,1992). This is the C0 used for pushover analysis by FEMA356 and
% EC8.


eigMass.Mtotal=Mtotal;
if (any(Mtotal~=0))&&(any(any(Mn~=0)))
   fprintf('Total model mass (units assume units_constants_metric.tcl is used)\n')
   if ndim==3
      fprintf('Mx: %0.6g tn,   My: %0.6g tn, Mz: %0.6g tn, Mrz: %0.6g tn*m2\n',...
            Mtotal(1),Mtotal(2),Mtotal(3),Mtotal(6))
      % In earth's gravity: 1tn = 1000kg  --> 1000kg*9.81m/s2 = 9.81 * 1000 kg*m/s2
      %                                                       = 9.81 kN
      fprintf('Wx: %0.6g kN,   Wy: %0.6g kN, Wz: %0.6g kN, Wrz: %0.6g kN*m2\n',...
         Mtotal(1)*9.81,Mtotal(2)*9.81,Mtotal(3)*9.81,Mtotal(6)*9.81)
   elseif ndim==2 && length(Mtotal)==3
      fprintf('Mx: %0.6g tn,   My: %0.6g tn, Mrz: %0.6g tn*m2\n',...
         Mtotal(1),Mtotal(2),Mtotal(3))
      fprintf('Wx: %0.6g kN,   Wy: %0.6g kN, Wrz: %0.6g kN*m2\n',...
         Mtotal(1)*9.81,Mtotal(2)*9.81,Mtotal(3)*9.81)
   else
      % happens for 2D trusses!  No mass and a single zero for M and W.
      fprintf('M: %0.6g\n',Mtotal)
      fprintf('W: %0.6g \n',Mtotal*9.81)
   end

   if Mtotal(1)~=0
      Meffx=((Ln(:,1).^2)./Mn(:,1))/Mtotal(1)
      % No this Gamma is not working: Fajfar assumes the mode shape is normalized
      % with 1 being the value on the roof! Otherwise you are not producing
      % the participation factor at the level of the roof! Identify the
      % roof node first, then normalize each mode shape.
      %Gamma =Mn(:,1)./Ln(:,1);
      % Normalize eigv for x-direction by the eigv of the roof node. Locate
      % this node by finding the node that has mass and has the highest 
      % modal displacement in the first mode along x.
      
      % Load patterns (sn according to Chopra's MPA for mode n)
      % use only x-direction!
      % Note that nmass may contain less nodes than eigv, since many
      % zero-mass nodes may not have been added to nmass after the last
      % non-zero-mass node. So fill it up with zeros
      nmass=[nmass;zeros(size(FEnode,1)-size(nmass,1),size(nmass,2))];
      Sn = repmat(nmass(:,1)',size(eigv,1),1) .* squeeze(eigv(:,:,1));
      indx=find(nmass(:,1)~=0);
      % find max of 1st mode shape in x-direction. If you have many nodes
      % on roof-floor this will select one of them that gets (by numerical
      % truncation) a somewhat higher displacement.
      eigvx = squeeze(eigv(:,indx,1));
      [max1st,maxind]=max(abs(eigvx(1,:))); % used to be only "max"
      % Normalize all modes by the appropriate modal coord at the roof
      % level.
      eigvx = eigvx./repmat(eigvx(:,maxind),1,size(eigvx,2));
      % x-masses for each node with non-zero mass.
      nmassx=nmass(indx,1)';
      nmassx=repmat(nmassx,size(eigvx,1),1);
      % Gamma_n = sum_i(mi*fni)/sum_i(mi*fni^2)
      Gamma = sum(nmassx.*eigvx,2)./sum(nmassx.*eigvx.^2,2)
      eigMass.Meffx=Meffx;
      eigMass.Gamma=Gamma;
   end
   if ndof>=2 && Mtotal(2)~=0
      Meffy=((Ln(:,2).^2)./Mn(:,2))/Mtotal(2)
      eigMass.Meffy=Meffy;
   end
   if ndof>=3 && Mtotal(3)~=0
      Meffz=((Ln(:,3).^2)./Mn(:,3))/Mtotal(3)
      eigMass.Meffz=Meffz;
   end
   if any(Mtotal(1:ndim)~=0)
      % sum up the masses in the three translational dofs
      Meffxyz=(sum(Ln(:,1:ndim),2).^2)./sum(Mn(:,1:ndim),2)/sum(Mtotal(1:ndim))
      eigMass.Meffxyz=Meffxyz;
   end
   if any(Mtotal(1:ndof)~=0)
      % sum up the masses in all the dofs. The rotational ones will tend to
      % dominate unfortunately.
      Meffall=(sum(Ln,2).^2)./sum(Mn,2)/sum(Mtotal(1:ndof))
   end
end

% remove the useless rotational dofs from the eigenvalues!
% So keep only up to ndim dimensions!
if ~isempty(eigv)
   eigv=eigv(:,:,1:ndim);
end