# Define building-specific parameters
# Created 07/08/2019 by A. Chatzidaki & D. Vamvatsikos 
#                   (with the contribution of C. Lyritsakis & F. Andris)
			 
# The following model is created:
#
#                 end     intermediate intermediate intermediate     end          leaning
#               column      column        column       column       column         column
#                  ___________________________________________________
#                 |            |            |            |            |				 |
#                 |            |            |            |            |				 |
#                 |            |            |            |            |				 |
#                 |____________|____________|____________|____________|				 |
#                 |            |            |            |            |				 |
#                 |            |            |            |         ___|___			 |
#                 |            |            |            |        |   |   |          |             |  above floor level
#                 |____________|____________|____________|________|___|   |------------------>  ___|
#                 |            |            |            |        |   |   |          |             |
#                 |            |            |            |        |___|___|          |             |  below floor level
#                 |            |            |            |            |				 |
#                 |____________|____________|____________|____________|				 |
#                 |            |            |            |            |				 |
#                 |            |            |            |            |				 |
#                 |            |            |            |            |				 |
#                _|_          _|_          _|_          _|_          _|_			_|_							



# source the units file, to convert units to SI easily
source ../util/units_constants_metric.tcl


#-----------------------"Sourcing" analysis type file ---------------------------------
# In the this file the analysis type and the design method of the building should be defined 
# Options:
# analysistype : "dynamic" for dynamic or IDA analysis
#  			   : "pushover" for pushover analysis
#  			   : "eigenvalue" for eigenvalue analysis
# design       : "A" or "a"; # for book's Example 1
#              : "B" or "b"; # for book's Example 2
# 			   : "C" or "c"; # for book's Example 3
if {[file exists Mat_anlsfile.tcl]} {
   puts "Using EXTERNAL Design Parameters data-file (Matlab-generated)"
	source Mat_anlsfile.tcl
	
} else {
   puts "Using STANDARD Parameters data-file"
   source standard_anlsfile.tcl
   puts "4 story MRF - Design $design"
}


#--------------------Define the geometry of the frame -----------------------
# Number of bays 
set Nbay 4
# Number of stories
set Nstory 4
# set the height of each story For the 4 stories of the MRF we have:
set storyHeight "[expr 15.*$ft] [expr 13.*$ft] [expr 13.*$ft] [expr 13.*$ft]"

# bay length of the frame. Here it is assumed to be the same for all bays. If not the
# user should change it manually
set baylength [expr 30.0*$ft]

#------------------Define the loads acting on the frame ---------------------
# set total floormass: D+0.25L (live load does not act on the roof)
set deadload [expr 175.*$psff]; #psf
set liveload [expr 50.*$psff]; #psf
set loadcombo [expr $deadload+0.25*$liveload]
set loadcomboRoof [expr $deadload]
set Atrib [expr 180.*$ft*120.*$ft/2.];
set tribmass [expr $Atrib*$loadcombo/$g*$ton]
set tribmassRoof [expr $Atrib*$loadcomboRoof/$g*$ton]
set floormass "$tribmass $tribmass $tribmass $tribmassRoof"


#------------------Define the tributary load acting on the frame ---------------------
# This is the ratio of tributary load that goes to the frame. The rest goes to the leaning column 
set pTrib 0.1979 ;


#------------------Define the Young modulus of concrete ---------------------
# Set the Young modulus of concrete
set Econcrete [expr 31.68*$GPa]
# set the young modulus of the columns (Nstories)x(Ncolumns) 
#  					end column	     intermediate col   intermediate col     intermediate col      end column
set Ecol "   {  [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa] }
			 {  [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa] }
			 {  [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa] }
			 {  [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa]   [expr 31.68*$GPa] }
			"
# set the Young modulus of the beams 1x(Nstories) 
set Ebeam "$Econcrete $Econcrete $Econcrete $Econcrete"
			
			
#------------------Define the axial load acting on the columns ---------------------
# set the axial load in a 1x(Nstories) vector
set axialLoad "[expr  -1426.0*$kN] [expr  -1070.0*$kN] [expr  -713.0*$kN] [expr  -356.0*$kN]"; 


#------------------Define material properties ---------------------
# set reinforcing steel properties: needed in the distributed-plasticity modeling
# for defining the steel rebars and in the lumped-plasticity model to calculate the
# yield curvature of the columns, as per book's Eq. 17.16, page 415
set fye [expr 69.*$ksi] ; # steel yield strength (expected)	
# set the Young modulus of steel
set Es [expr 29000.*$ksi]		
# set the yield strain of the steel = fye/Es
set eys [expr $fye/$Es] 

# set concrete properties: needed to determine the constitutive law of the fiber sections
# in the distributed-plasticity model and to estimate the yield curvature of 
# columns in the lumped-plasticity model, as per book's Eq. 17.16, page 415
set fce [expr 6.5*$ksi] ; #expected concrete strength = 6.5ksi for 5ksi concrete

# copy fce and fsy and convert them to psi WITHOUT multiplying by the corresponding unit:,
# needed to calculate the rotation of the beams due to anchorage slip, as per book's eq. 17.15
# page 413
#EXAMPLE: if fc=6.5ksi and fsy=69ksi, then set below fcs=6500 and fsys=69000
set fcs 6500.
set fsys 69000.


		
if {$design=="A"||$design=="a"} {
   
	#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ C O L U M N S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
	
	#----------------------------- Dimensions --------------------------------------------------------- 
	# Define column dimension for end and intermediate columns
	# height:
	# colexth = colexth: end column, h: height
	set colexth "[expr 36.0*$in] [expr 32.0*$in] [expr 30.0*$in] [expr 26.0*$in]" ; 
	# colinth = colint: intermediate column, h: height
	set colinth "[expr 36.0*$in] [expr 32.0*$in] [expr 30.0*$in] [expr 26.0*$in]" ; 
	# width:
	# colintb = colint: intermediate column, b = width
	set colintb $colinth; # for b=h. If not, the user should modify it
	# colextb = colext: end column, b = width
	set colextb $colexth; #assuming b=h. If not, the user should modify it
	
	# set the width of each column in a (Nstories) x (Ncolumns) matrix 
	#                     	end     		    intermediate 		intermediate 			intermediate     		end          
	#                      column      			   column                column                column       	   column         
	set bcolumn "   {  [lindex $colexth 0]   [lindex $colinth 0]   [lindex $colinth 0]   [lindex $colinth 0]   [lindex $colexth 0] }
					{  [lindex $colexth 1]   [lindex $colinth 1]   [lindex $colinth 1]   [lindex $colinth 1]   [lindex $colexth 1] }
					{  [lindex $colexth 2]   [lindex $colinth 2]   [lindex $colinth 2]   [lindex $colinth 2]   [lindex $colexth 2] }
					{  [lindex $colexth 3]   [lindex $colinth 3]   [lindex $colinth 3]   [lindex $colinth 3]   [lindex $colexth 3] }
			 "
	# set the height of each column in a (Nstories) x (Ncolumns) matrix 
	#                     	end     		    intermediate 		intermediate 			intermediate     		end          
	#                      column      			   column                column                column       	   column         
	set hcolumn "   {  [lindex $colexth 0]   [lindex $colinth 0]   [lindex $colinth 0]   [lindex $colinth 0]   [lindex $colexth 0] }
					{  [lindex $colexth 1]   [lindex $colinth 1]   [lindex $colinth 1]   [lindex $colinth 1]   [lindex $colexth 1] }
					{  [lindex $colexth 2]   [lindex $colinth 2]   [lindex $colinth 2]   [lindex $colinth 2]   [lindex $colexth 2] }
					{  [lindex $colexth 3]   [lindex $colinth 3]   [lindex $colinth 3]   [lindex $colinth 3]   [lindex $colexth 3] }
			 "
	
	
	#----------------------------- Reinforcement --------------------------------------------------------- 
	# set the reinforcement of each column. In the distributed-plasticity model it is used for creating the
	# fiber sections. In the lumped-plasticity model it is used to determine the reinforcement ratio of each
	# column, as needed for calculating the yield curvature of Eq. (17.17), book's page 415
	
	# Reinforcement area just above floor level for "end" and "intermediate" columns	
	# define a 1 x (Nstories) vector
	# Ascole = As: reinforcement area, cole: end columns, above floor level
	set Ascole   "[expr 20.32*$in2] [expr 20.32*$in2] [expr 20.32*$in2] [expr 15.24*$in2]"
	# Ascoli = As: reinforcement area, coli: intermediate columns, above floor level
	set Ascoli   "[expr 45.72*$in2] [expr 30.48*$in2] [expr 30.48*$in2] [expr 25.40*$in2]"

	# Reinforcement area just below floor level for "end" and "intermediate" columns
	# define a 1 x (Nstories) vector
	# Ascoleb = As: reinforcement area, cole: end columns, b: below floor level
	set Ascoleb "[expr 20.32*$in2] [expr 20.32*$in2] [expr 15.24*$in2] [expr 15.24*$in2]"
	# Ascolib = As: reinforcement area, coli: intermediate columns, b: below floor level
	set Ascolib "[expr 30.48*$in2] [expr 30.48*$in2] [expr 25.40*$in2] [expr 25.40*$in2]"
	
	# set the number of bars of each column, useful to create the fiber sections of the distributed-plasticity
	# model (1x(Nstories) vector)
	
	# Number of bars just above floor level for "end" and "intermediate" columns
	# above floor level
	# nobarcole = nobar: number of bars, cole: end columns, above floor level
	set nobarcole   "16 16 16 12"
	# nobarcoli = nobar: number of bars, coli: intermediate columns, above floor level
	set nobarcoli   "36 24 24 20"
	# below floor level
	# nobarcoleb = nobar: number of bars, cole: end columns, b: below floor level
	set nobarcoleb "16 16 12 12"
	# nobarcolib = nobar: number of bars, coli: intermediate columns, b: below floor level
	set nobarcolib "24 24 20 20"

	
   	#----------------------------- Plastic Moments for columns --------------------------------------------------------- 
	# The plastic moments of columns are defined approximately as the maximum moment of the moment-curvature analysis (M-C). 
	# set a (Nstories) x (Ncolumns) matrix with the plastic moments for columns  
	# Mycolt = Mycol: plastic moment of column, t: top of the column
	#                    end column           intermediate column    intermediate column     intermediate column      end column
	 set Mycolt " {  [expr 3281.70*$kN*$m]   [expr 4468.56*$kN*$m]   [expr 4468.56*$kN*$m]   [expr 4468.56*$kN*$m]   [expr 3281.70*$kN*$m] }
				  {  [expr 2731.75*$kN*$m]   [expr 3785.32*$kN*$m]   [expr 3785.32*$kN*$m]   [expr 3785.32*$kN*$m]   [expr 2731.75*$kN*$m] }
				  {  [expr 1955.42*$kN*$m]   [expr 2916.80*$kN*$m]   [expr 2916.80*$kN*$m]   [expr 2916.80*$kN*$m]   [expr 1955.42*$kN*$m] }
				 {  [expr 1562.72*$kN*$m]   [expr 2377.94*$kN*$m]   [expr 2377.94*$kN*$m]   [expr 2377.94*$kN*$m]   [expr 1562.72*$kN*$m] }
			   "
			  
	# Mycol = Mycol: plastic moment of column, bottom of the column
	#                    end column           intermediate column    intermediate column     intermediate column      end column
	set Mycol "   {  [expr 3281.70*$kN*$m]   [expr 6261.90*$kN*$m]   [expr 6261.90*$kN*$m]   [expr 6261.90*$kN*$m]   [expr 3281.70*$kN*$m] }
				  {  [expr 2731.75*$kN*$m]   [expr 3785.32*$kN*$m]   [expr 3785.32*$kN*$m]   [expr 3785.32*$kN*$m]   [expr 2731.75*$kN*$m] }
				  {  [expr 2432.95*$kN*$m]   [expr 3415.50*$kN*$m]   [expr 3415.50*$kN*$m]   [expr 3415.50*$kN*$m]   [expr 2432.95*$kN*$m] }
				  {  [expr 1562.72*$kN*$m]   [expr 2377.94*$kN*$m]   [expr 2377.94*$kN*$m]   [expr 2377.94*$kN*$m]   [expr 1562.72*$kN*$m]  }
			   "
	 
   	#----------------------------- Ieffective for columns --------------------------------------------------------- 
	# set a (Nstories) x (Ncolumns) matrix with the Ieff of columns as defined by averaging the initial stiffness with the nominal
	# stiffness at yield of the Moment-Curvature analysis results 
	#                  		end column        			   intermediate column     		   intermediate column     			intermediate column          				end column
	set Icol "    {  [expr 0.04093176614583333*$m4]    [expr 0.05014746272503189*$m4]   [expr 0.05014746272503189*$m4]   [expr 0.05014746272503189*$m4]   [expr 0.04093176614583333*$m4 ] }
				  {  [expr 0.029005644128787877*$m4]  [expr 0.03159525657050909*$m4]   [expr 0.03159525657050909*$m4]   [expr 0.03159525657050909*$m4]   [expr 0.029005644128787877*$m4 ] }
				  {  [expr 0.021036150675505048*$m4]  [expr 0.024646799958712122*$m4]  [expr 0.024646799958712122*$m4]  [expr 0.024646799958712122*$m4]  [expr 0.021036150675505048*$m4] }
				  {  [expr 0.012901999584903227*$m4] [expr 0.014907595207590014*$m4]  [expr 0.014907595207590014*$m4]  [expr 0.014907595207590014*$m4]  [expr 0.012901999584903227*$m4] }
				 "		 	


	
	#~~~~~~~~~~~~~~~~~~~~~~~~~~~~ B E A M S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
	
	#----------------------------- Dimensions --------------------------------------------------------- 
	# set a 1 x (Nstories) vector with the dimension of the beams. All beams of each story are assumed to have the 
	# same dimensions. If not, the user should modify the code below
	# beam width
	set beamb    "[expr 24*$in] [expr 24*$in] [expr 18*$in] [expr 14*$in]"
	# beam height
	set beamh    "[expr 36*$in] [expr 36*$in] [expr 32*$in] [expr 22*$in]"
	
	
	#----------------------------- Reinforcement --------------------------------------------------------- 
	# set the reinforcement of the beams, used in the distributed-plasticity model for creating the
	# fiber sections. 
	
	# Asbeamtop = Asbeam: reinforcement area, top: top flange of the beam
	set Asbeamtop "[expr  16.0*$in2] [expr  16.0*$in2] [expr  12.0*$in2] [expr  6.0*$in2]"
	# Asbeambot = Asbeam: reinforcement area, bot: bottom flange of the beam
	set Asbeambot "[expr  7.90*$in2] [expr  7.11*$in2] [expr  5.53*$in2] [expr  2.37*$in2]"
	
	# Define top and bottom bar diameter of each beam. All beams of the same floor have the same reinforcement.
	# Bar diameter is needed to calculate the rotation of the beam due to anchorage slip, as per Eq. 17.15 of Chapter
	# 17, page 413
	# topd = top bar diameter (#9 bars: d = 1.128in)
	set topd "[expr 28.65*$mm] [expr 28.65*$mm] [expr 28.65*$mm] [expr 28.65*$mm]"
	# botd = bottom bar diameter (#8 bars: d = 1.00in)
	set botd "[expr 25.4*$mm] [expr 25.4*$mm] [expr 25.4*$mm] [expr 25.4*$mm]"
		 
	# Define the number of bars in the beams, used to create the fiber sections in the distributed-plasticity model
	# nobarbeamtop = nobarbeam: number of bars in the beam, top: top flange
	set nobarbeamtop "16 16 12 6"
	# nobarbeambot = nobarbeam: number of bars in the beam, bot: bottom flange
	set nobarbeambot "10 9 7 3"
	
	
	#----------------------------- Plastic Moments for beams --------------------------------------------------------- 
	# set a 1X(Nstories) vector with the plastic moment for the beams of each story
	# Top Flange in Tension (negative Moment, generally larger than positive)
	#					story 1				story 2				story 3					story 4
	set Mybeam "[expr 4364.71*$kN*$m] [expr 4337.75*$kN*$m] [expr 2863.79*$kN*$m] [expr 959.22*$kN*$m]"
	#Top Flange in Compression (positive moment)
	#					story 1				story 2				story 3					story 4
	set Mybeamp "[expr 2200.17*$kN*$m] [expr 1981.44*$kN*$m]	[expr 1359.08*$kN*$m] [expr 390.52*$kN*$m]"
	
	
				 
   	#----------------------------- Ieffective for beams --------------------------------------------------------- 
	# set a (Nstories) x (Ncolumns) matrix with the Ieff of columns as defined by averaging the initial stiffness with the nominal
	# sttiffness at yield of the Moment-Curvature analysis results 
	#					story 1				story 2				story 3					story 4
	set Ibeam "[expr 0.0353632044665404*$m4] [expr 0.03432597468434344*$m4] [expr 0.018857638952020205*$m4] [expr 0.004190634848484849*$m4]"

			 
	
			 
	#~~~~~~~~~~~~~~~~~~~~~~~~~~~~ M O D E L I N G   P A R A M E T E R S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
	
	# Define modeling parameters - a ,b ,c -  (ASCE SEI 41, Table 10-8) for beams and columns of each story. This is 
	# used to create the lumped-plasticity model

	# modeling parameters for beams negative moment: 1 x (Nstories) vector, same for all the beams of one story
	set mpabp "0.0218 0.0215 0.0211 0.0210"
	set mpbbp "0.0371 0.0359 0.0346 0.0338" ; 
	set mpcb "0.2 0.2 0.2 0.2"
	

	# modeling parameters for beams positive moment: 1 x (Nstories) vector, same for all the beams of one story
	set mpab "0.025 0.025 0.025 0.0250"
	set mpbb "0.05 0.05 0.05 0.0500"
	
	
	# # Modeling Parameters for columns bottom cross-sections
	set mpa "    {  0.03   0.03   0.03   0.03   0.03 }
				  {  0.03   0.03   0.03   0.03   0.03 }
				  {  0.03   0.03   0.03   0.03   0.03 }
				  {  0.03   0.03   0.03   0.03   0.03 }
			  "
	set mpb "    {  0.044   0.044   0.044   0.044   0.044 }
				  {  0.044   0.044   0.044   0.044   0.044 }
				  {  0.044   0.044   0.044   0.044   0.044 }
				  {  0.044   0.044   0.044   0.044   0.044 }
			 "

	set mpc "    {  0.2   0.2   0.2   0.2   0.2 }
				  {  0.2   0.2   0.2   0.2   0.2 }
				  {  0.2   0.2   0.2   0.2   0.2 }
				  {  0.2   0.2   0.2   0.2   0.2 }
			  "
	#Modeling Parameters for columns top cross-sections
	set mpat "   {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
			 "
	set mpbt "   {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
			 "
	#Residual moment strength parameters after capping (M_r=mpct*M_p)
	set mpct "   {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
		"	 

	
	
	#~~~~~~~~~~  P - D   C O L U M N  ~~~~~~~~~~

	# set the PD column area and Izz 
	# We assume that the inertia of the gravity columns is about 1/3 of the columns of the moment frame. 
	# set the inertia properties of the PD column (1x(Nstories)) 
	set  IcolPD "[expr 0.432378*$m4] [expr 0.283689*$m4] [expr 0.213693*$m4] [expr 0.124917*$m4] "
	
	# set the area of the PD column (1x(Nstories) vector
	set  AcolPD "[expr 7.*$m2] [expr 6.*$m2] [expr 5.*$m2] [expr 4.*$m2] "


   
} elseif {$design=="B"||$design=="b"} {
   
	#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ C O L U M N S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
	
	#----------------------------- Dimensions --------------------------------------------------------- 
	# Define column dimension for end and intermediate columns
	# height:
	# colexth = colexth: end column, h: height
	set colexth "[expr 36.*$in] [expr 36.*$in] [expr 32.*$in] [expr 28.*$in]" ; 
	# colinth = colint: intermediate column, h: height
	set colinth "[expr 36.*$in] [expr 36.*$in] [expr 32.*$in] [expr 28.*$in]" ; #internal column basic dim
	# width:
	# colintb = colint: intermediate column, b = width
	set colintb $colinth; # for b=h. If not, the user should modify it
	# colextb = colext: end column, b = width
	set colextb $colexth; #assuming b=h. If not, the user should modify it
	
	# set the width of each column in a (Nstories) x (Ncolumns) matrix 
	#                     	end     		    intermediate 		intermediate 			intermediate     		end          
	#                      column      			   column                column                column       	   column         
	set bcolumn "   {  [lindex $colextb 0]   [lindex $colintb 0]   [lindex $colintb 0]   [lindex $colintb 0]   [lindex $colextb 0] }
					{  [lindex $colextb 1]   [lindex $colintb 1]   [lindex $colintb 1]   [lindex $colintb 1]   [lindex $colextb 1] }
					{  [lindex $colextb 2]   [lindex $colintb 2]   [lindex $colintb 2]   [lindex $colintb 2]   [lindex $colextb 2] }
					{  [lindex $colextb 3]   [lindex $colintb 3]   [lindex $colintb 3]   [lindex $colintb 3]   [lindex $colextb 3] }
			 "
	# set the height of each column in a (Nstories) x (Ncolumns) matrix 
	#                     	end     		    intermediate 		intermediate 			intermediate     		end          
	#                      column      			   column                column                column       	   column         
	set hcolumn "   {  [lindex $colexth 0]   [lindex $colinth 0]   [lindex $colinth 0]   [lindex $colinth 0]   [lindex $colexth 0] }
					{  [lindex $colexth 1]   [lindex $colinth 1]   [lindex $colinth 1]   [lindex $colinth 1]   [lindex $colexth 1] }
					{  [lindex $colexth 2]   [lindex $colinth 2]   [lindex $colinth 2]   [lindex $colinth 2]   [lindex $colexth 2] }
					{  [lindex $colexth 3]   [lindex $colinth 3]   [lindex $colinth 3]   [lindex $colinth 3]   [lindex $colexth 3] }
			 "
	
	
	#----------------------------- Reinforcement --------------------------------------------------------- 
	# set the reinforcement of each column. In the distributed-plasticity model it is used for creating the
	# fiber sections. In the lumped-plasticity model it is used to determine the reinforcement ratio of each
	# column, as needed for calculating the yield curvature of Eq. (17.17), book's page 415
	
	# Reinforcement area just above floor level for "end" and "intermediate" columns	
	# define a 1 x (Nstories) vector
	# Ascole = As: reinforcement area, cole: end columns, above floor level
	set Ascole   "[expr 30.48*$in2] [expr 25.40*$in2] [expr 25.40*$in2] [expr 15.24*$in2]"
	# Ascoli = As: reinforcement area, coli: intermediate columns, above floor level
	set Ascoli   "[expr 50.80*$in2] [expr 40.64*$in2] [expr 35.56*$in2] [expr 25.40*$in2]"


	# Reinforcement area just below floor level for "end" and "intermediate" columns
	# define a 1 x (Nstories) vector
	# Ascoleb = As: reinforcement area, cole: end columns, b: below floor level
	set Ascoleb "[expr 25.40*$in2] [expr 25.40*$in2] [expr 25.40*$in2] [expr 15.24*$in2]"
	# Ascolib = As: reinforcement area, coli: intermediate columns, b: below floor level
	set Ascolib "[expr 40.64*$in2] [expr 40.64*$in2] [expr 35.56*$in2] [expr 25.40*$in2]"
	
	# set the number of bars of each column, useful to create the fiber sections of the distributed-plasticity
	# model (1x(Nstories) vector)
	
	# Number of bars just above floor level for "end" and "intermediate" columns
	# above floor level
	# nobarcole = nobar: number of bars, cole: end columns, above floor level
	set nobarcole   "24 20 20 12"
	# nobarcoli = nobar: number of bars, coli: intermediate columns, above floor level
	set nobarcoli   "40 32 28 20"
	# below floor level
	# nobarcoleb = nobar: number of bars, cole: end columns, b: below floor level
	set nobarcoleb "20 20 20 12"
	# nobarcolib = nobar: number of bars, coli: intermediate columns, b: below floor level
	set nobarcolib "32 32 28 20"

	
   	#----------------------------- Plastic Moments for columns --------------------------------------------------------- 
	# The plastic moments of columns are defined approximately as the maximum moment of the moment-curvature analysis (M-C). 
	# set a (Nstories) x (Ncolumns) matrix with the plastic moments for columns  
	# Mycolt = Mycol: plastic moment of column, t: top of the column
	#                    end column           intermediate column    intermediate column     intermediate column      end column
	set Mycolt " {  [expr 3860.95*$kN*$m]   [expr 5657.58*$kN*$m]   [expr 5657.58*$kN*$m]   [expr 5657.58*$kN*$m]   [expr 3860.95*$kN*$m] }
				 {  [expr 3753.32*$kN*$m]   [expr 5553.84*$kN*$m]   [expr 5553.84*$kN*$m]   [expr 5553.84*$kN*$m]   [expr 3753.32*$kN*$m] }
				 {  [expr 3154.29*$kN*$m]   [expr 4210.57*$kN*$m]   [expr 4210.57*$kN*$m]   [expr 4210.57*$kN*$m]   [expr 3154.29*$kN*$m] }
				 {  [expr 1703.12*$kN*$m]   [expr 2602.12*$kN*$m]   [expr 2602.12*$kN*$m]   [expr 2602.12*$kN*$m]   [expr 1703.12*$kN*$m] }
			  "

	# Mycol = Mycol: plastic moment of column, bottom of the column
	#                    end column           intermediate column    intermediate column     intermediate column      end column
	set Mycol "   {  [expr 4468.56*$kN*$m]   [expr 6847.38*$kN*$m]   [expr 6847.38*$kN*$m]   [expr 6847.38*$kN*$m]   [expr 4468.56*$kN*$m] }
				  {  [expr 3753.32*$kN*$m]   [expr 5553.84*$kN*$m]   [expr 5553.84*$kN*$m]   [expr 5553.84*$kN*$m]   [expr 3753.32*$kN*$m] }
				  {  [expr 3154.29*$kN*$m]   [expr 4210.57*$kN*$m]   [expr 4210.57*$kN*$m]   [expr 4210.57*$kN*$m]   [expr 3154.29*$kN*$m] }
				  {  [expr 1703.12*$kN*$m]   [expr 2602.12*$kN*$m]   [expr 2602.12*$kN*$m]   [expr 2602.12*$kN*$m]   [expr 1703.12*$kN*$m]  }
			   "

	 
   	#----------------------------- Ieffective for columns --------------------------------------------------------- 
	# set a (Nstories) x (Ncolumns) matrix with the Ieff of columns as defined by averaging the initial stiffness with the nominal
	# sttiffness at yield of the Moment-Curvature analysis results 
	#                  		end column        			intermediate column     		intermediate column     			intermediate column          				end column
	set Icol " 	{[expr  0.0447850024080908*$m4]   [expr 0.0543086418534*$m4]  	[expr 0.0543086418534*$m4]  	[expr 0.0543086418534*$m4]  	[expr 0.0447850024080908*$m4]} 
	
				{[expr  0.04323576532974232*$m4]   [expr 0.05171093781578*$m4]  	[expr 0.05171093781578*$m4]  	[expr 0.05171093781578*$m4]  	[expr 0.04323576532974232*$m4]} 
				
				{[expr  0.029191698624111214*$m4]  [expr 0.0335009272411616*$m4] 	[expr 0.0335009272411616*$m4] 		[expr 0.0335009272411616*$m4] 		[expr 0.029191698624111214*$m4]} 
				
				{[expr  0.01558879340277777*$m4]  [expr 0.01887308705808*$m4] 	[expr 0.01887308705808*$m4]		[expr 0.01887308705808*$m4]  	[expr 0.01558879340277777*$m4]} "
		 
	 
		
	#~~~~~~~~~~~~~~~~~~~~~~~~~~~~ B E A M S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
	
	#----------------------------- Dimensions --------------------------------------------------------- 
	# set a 1 x (Nstories) vector with the dimension of the beams. All beams of each story are assumed to have the 
	# same dimensions. If not, the user should modify the code below
	# beam width
	set beamb    "[expr 22.*$in] [expr 22.*$in] [expr 20.*$in] [expr 14.*$in]"
	# beam height
	set beamh    "[expr 38.*$in] [expr 36.*$in] [expr 32.*$in] [expr 24.*$in]"
	
	
	#----------------------------- Reinforcement --------------------------------------------------------- 
	# set the reinforcement of the beams, used in the distributed-plasticity model for creating the
	# fiber sections. 
	
	# Asbeamtop = Asbeam: reinforcement area, top: top flange of the beam
	set Asbeamtop "[expr  18.0*$in2] [expr  18.0*$in2] [expr  14.0*$in2] [expr  7.0*$in2]"
	# Asbeambot = Asbeam: reinforcement area, bot: bottom flange of the beam
	set Asbeambot "[expr   9.0*$in2] [expr   8.0*$in2] [expr   6.0*$in2] [expr  3.0*$in2]"
	
	# Define top and bottom bar diameter of each beam. All beams of the same floor have the same reinforcement.
	# Bar diameter is needed to calculate the rotation of the beam due to anchorage slip, as per Eq. 17.15 of Chapter
	# 17, page 413
	# topd = top bar diameter (#9 bars: d = 1.128in)
	set topd "[expr 1.128*$in] [expr 1.128*$in] [expr 1.128*$in] [expr 1.128*$in]"
	# botd = bottom bar diameter (#9 bars: d = 1.128in)
	set botd "[expr 1.128*$in] [expr 1.128*$in] [expr 1.128*$in] [expr 1.128*$in]"
		 
	# Define the number of bars in the beams, used to create the fiber sections in the distributed-plasticity model
	# nobarbeamtop = nobarbeam: number of bars in the beam, top: top flange
	set nobarbeamtop "18 18 14 7"
	# nobarbeambot = nobarbeam: number of bars in the beam, bot: bottom flange
	set nobarbeambot "9 8 6 3"
	

	#----------------------------- Plastic Moments for beams --------------------------------------------------------- 
	# set a 1X(Nstories) vector with the plastic moment for the beams of each story
	# Top Flange in Tension (negative Moment, generally larger than positive)
	#					story 1				story 2				story 3					story 4
	set Mybeam "[expr 5159.06*$kN*$m] [expr 4827.25*$kN*$m]\
            [expr 3318.79*$kN*$m] [expr 1227.98*$kN*$m]"
 	#Top Flange in Compression (positive moment)
	#					story 1				story 2				story 3					story 4
	set Mybeamp "[expr 2650.25*$kN*$m] [expr 2226.12*$kN*$m]\
				[expr 1474.83*$kN*$m] [expr 524.34*$kN*$m]"
	
   	#----------------------------- Ieffective for beams --------------------------------------------------------- 
	# set a (Nstories) x (Ncolumns) matrix with the Ieff of columns as defined by averaging the initial stiffness with the nominal
	# sttiffness at yield of the Moment-Curvature analysis results 
	#					story 1				story 2				story 3					story 4
	set Ibeam "[expr  0.04117888*$m4] [expr 0.03463552*$m4] [expr 0.02106292*$m4] [expr 0.00582512*$m4]"
	
   
  

   
	#~~~~~~~~~~~~~~~~~~~~~~~~~~~~ M O D E L I N G   P A R A M E T E R S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
	
	# Define modeling parameters - a ,b ,c -  (ASCE SEI 41, Table 10-8) for beams and columns of each story. This is 
	# used to create the lumped-plasticity model

	# modeling parameters for beams negative moment: 1 x (Nstories) vector, same for all the beams of one story
	set mpabp "0.0199 0.0198 0.0202 0.0208"
	set mpbbp "0.0323 0.0308 0.0318 0.0334" ; 
	set mpcb "0.2 0.2 0.2 0.2"


	# modeling parameters for beams positive moment: 1 x (Nstories) vector, same for all the beams of one story
	set mpab "0.024 0.024 0.025 0.0250"
	set mpbb "0.047 0.048 0.049 0.0500"
		
		
	
	# Modeling Parameters for columns bottom cross-sections
	set mpa "    {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
			 "
	set mpb "    {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
			 "
	set mpc "    {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
			 "
			 
	# #Modeling Parameters for columns top cross-sections
	set mpat "   {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
			 "
	set mpbt "   {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
			 "
			 
	#Residual moment strength parameters after capping (M_r=mpct*M_p)
	set mpct "    {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
			 "	 
 
 

	#~~~~~~~~~~  P - D   C O L U M N  ~~~~~~~~~~

	# set the PD column area and Izz 
	# We assume that the inertia of the gravity columns is about 1/3 of the columns of the moment frame. 
	# set the inertia properties of the PD column (1x(Nstories)) 
	set  IcolPD "[expr 0.500755*$m4] [expr 0.464607*$m4] [expr 0.316219*$m4] [expr 0.172652*$m4] "
	# set the area of the PD column (1x(Nstories) vector
	set  AcolPD "[expr 7.4*$m2] [expr 7.00*$m2] [expr 6.*$m2] [expr 4.*$m2] "


  
} elseif {$design=="C"||$design=="c"} {
   
	#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ C O L U M N S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
	
	#----------------------------- Dimensions --------------------------------------------------------- 
	# Define column dimension for end and intermediate columns
	# height:
	# colexth = colexth: end column, h: height
	set colexth "[expr 38.0*$in] [expr 38.0*$in] [expr 34.0*$in] [expr 30.0*$in]" ; 
	# colinth = colint: intermediate column, h: height
	set colinth "[expr 38.0*$in] [expr 38.0*$in] [expr 34.0*$in] [expr 30.0*$in]" ;
	# width:
	# colintb = colint: intermediate column, b = width
	set colintb $colinth; # for b=h. If not, the user should modify it
	# colextb = colext: end column, b = width
	set colextb $colexth; #assuming b=h. If not, the user should modify it
	
	# set the width of each column in a (Nstories) x (Ncolumns) matrix 
	#                     	end     		    intermediate 		intermediate 			intermediate     		end          
	#                      column      			   column                column                column       	   column         
	set bcolumn "   {  [lindex $colextb 0]   [lindex $colintb 0]   [lindex $colintb 0]   [lindex $colintb 0]   [lindex $colextb 0] }
					{  [lindex $colextb 1]   [lindex $colintb 1]   [lindex $colintb 1]   [lindex $colintb 1]   [lindex $colextb 1] }
					{  [lindex $colextb 2]   [lindex $colintb 2]   [lindex $colintb 2]   [lindex $colintb 2]   [lindex $colextb 2] }
					{  [lindex $colextb 3]   [lindex $colintb 3]   [lindex $colintb 3]   [lindex $colintb 3]   [lindex $colextb 3] }
			 "
	# set the height of each column in a (Nstories) x (Ncolumns) matrix 
	#                     	end     		    intermediate 		intermediate 			intermediate     		end          
	#                      column      			   column                column                column       	   column         
	set hcolumn "   {  [lindex $colexth 0]   [lindex $colinth 0]   [lindex $colinth 0]   [lindex $colinth 0]   [lindex $colexth 0] }
					{  [lindex $colexth 1]   [lindex $colinth 1]   [lindex $colinth 1]   [lindex $colinth 1]   [lindex $colexth 1] }
					{  [lindex $colexth 2]   [lindex $colinth 2]   [lindex $colinth 2]   [lindex $colinth 2]   [lindex $colexth 2] }
					{  [lindex $colexth 3]   [lindex $colinth 3]   [lindex $colinth 3]   [lindex $colinth 3]   [lindex $colexth 3] }
			 "
	
	
	#----------------------------- Reinforcement --------------------------------------------------------- 
	# set the reinforcement of each column. In the distributed-plasticity model it is used for creating the
	# fiber sections. In the lumped-plasticity model it is used to determine the reinforcement ratio of each
	# column, as needed for calculating the yield curvature of Eq. (17.17), book's page 415
	
	# Reinforcement area just above floor level for "end" and "intermediate" columns	
	# define a 1 x (Nstories) vector
	# Ascole = As: reinforcement area, cole: end columns, above floor level
	set Ascole   "[expr 25.4*$in2] [expr 30.48*$in2] [expr 30.48*$in2] [expr 25.40*$in2]"
	# Ascoli = As: reinforcement area, coli: intermediate columns, above floor level
	set Ascoli   "[expr 60.96*$in2] [expr 45.72*$in2] [expr 45.72*$in2] [expr 35.56*$in2]"

	# Reinforcement area just below floor level for "end" and "intermediate" columns
	# define a 1 x (Nstories) vector
	# Ascoleb = As: reinforcement area, cole: end columns, b: below floor level
	set Ascoleb "[expr 30.48*$in2] [expr 30.48*$in2] [expr 30.48*$in2] [expr 25.40*$in2]"
	# Ascolib = As: reinforcement area, coli: intermediate columns, b: below floor level
	set Ascolib "[expr 45.72*$in2] [expr 45.72*$in2] [expr 45.72*$in2] [expr 35.56*$in2]"

	# set the number of bars of each column, useful to create the fiber sections of the distributed-plasticity
	# model (1x(Nstories) vector)
	
	# Number of bars just above floor level for "end" and "intermediate" columns
	# above floor level
	# nobarcole = nobar: number of bars, cole: end columns, above floor level
	set nobarcole   "20 24 24 20"
	# nobarcoli = nobar: number of bars, coli: intermediate columns, above floor level
	set nobarcoli   "48 36 36 28"
	# below floor level
	# nobarcoleb = nobar: number of bars, cole: end columns, b: below floor level
	set nobarcoleb "24 24 24 20"
	# nobarcolib = nobar: number of bars, coli: intermediate columns, b: below floor level
	set nobarcolib "36 36 36 28"

	
   	#----------------------------- Plastic Moments for columns --------------------------------------------------------- 
	# The plastic moments of columns are defined approximately as the maximum moment of the moment-curvature analysis (M-C). 
	# set a (Nstories) x (Ncolumns) matrix with the plastic moments for columns  
	# Mycolt = Mycol: plastic moment of column, t: top of the column
	#                    end column           intermediate column    intermediate column     intermediate column      end column
	set Mycolt " {  [expr 4770.46*$kN*$m]   [expr 6677.91*$kN*$m]   [expr 6677.91*$kN*$m]   [expr 6677.91*$kN*$m]   [expr 4770.46*$kN*$m] }
				 {  [expr 4654.50*$kN*$m]   [expr 6565.98*$kN*$m]   [expr 6565.98*$kN*$m]   [expr 6565.98*$kN*$m]   [expr 4654.50*$kN*$m] }
				 {  [expr 3967.85*$kN*$m]   [expr 5655.25*$kN*$m]   [expr 5655.25*$kN*$m]   [expr 5655.25*$kN*$m]   [expr 3967.85*$kN*$m] }
				 {  [expr 2828.68*$kN*$m]   [expr 3808.53*$kN*$m]   [expr 3808.53*$kN*$m]   [expr 3808.53*$kN*$m]   [expr 2828.68*$kN*$m] }
			  "

	# Mycol = Mycol: plastic moment of column, bottom of the column
	#                    end column           intermediate column    intermediate column     intermediate column      end column
	set Mycol "   {  [expr 4128.33*$kN*$m]   [expr 8563.65*$kN*$m]   [expr 8563.65*$kN*$m]   [expr 8563.65*$kN*$m]   [expr 4128.33*$kN*$m] }
				  {  [expr 4654.5*$kN*$m]    [expr 6565.98*$kN*$m]   [expr 6565.98*$kN*$m]   [expr 6565.98*$kN*$m]   [expr 4654.5*$kN*$m]  }
				  {  [expr 3967.85*$kN*$m]   [expr 5655.25*$kN*$m]   [expr 5655.25*$kN*$m]   [expr 5655.25*$kN*$m]   [expr 3967.85*$kN*$m] }
				  {  [expr 2828.68*$kN*$m]   [expr 3808.53*$kN*$m]   [expr 3808.53*$kN*$m]   [expr 3808.53*$kN*$m]   [expr 2828.68*$kN*$m] }
			   "
	 
	
   	#----------------------------- Ieffective for columns --------------------------------------------------------- 
	# set a (Nstories) x (Ncolumns) matrix with the Ieff of columns as defined by averaging the initial stiffness with the nominal
	# sttiffness at yield of the Moment-Curvature analysis results 
	#                  		end column        			intermediate column     		intermediate column     			intermediate column          				end column
	set Icol " 	{[expr  0.05350084280303031*$m4]   [expr 0.06928984517045455*$m4]  	[expr 0.06928984517045455*$m4]  	[expr 0.06928984517045455*$m4]  	[expr 0.05350084280303031*$m4]} 
				{[expr  0.05529999004621212*$m4]   [expr 0.06530012275883848*$m4]  	[expr 0.06530012275883848*$m4]  	[expr 0.06530012275883848*$m4]  	[expr 0.05529999004621212*$m4]} 
				{[expr  0.038290425899621214*$m4]  [expr 0.04564604017992428*$m4] 	[expr 0.04564604017992428*$m4] 		[expr 0.04564604017992428*$m4] 		[expr 0.038290425899621214*$m4]} 
				{[expr  0.023690276312500005*$m4]  [expr 0.02742149462173999*$m4] 	[expr 0.02742149462173999*$m4]		[expr 0.02742149462173999*$m4]  	[expr 0.023690276312500005*$m4]} "
	
	
	#~~~~~~~~~~~~~~~~~~~~~~~~~~~~ B E A M S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
	
	#----------------------------- Dimensions --------------------------------------------------------- 
	# set a 1 x (Nstories) vector with the dimension of the beams. All beams of each story are assumed to have the 
	# same dimensions. If not, the user should modify the code below
	# beam width
	set beamb    "[expr 26.*$in] [expr 26.*$in] [expr 22.*$in] [expr 16.*$in]"
	# beam height
	set beamh    "[expr 42.*$in] [expr 42.*$in] [expr 36.*$in] [expr 28.*$in]"
	
	
	#----------------------------- Reinforcement --------------------------------------------------------- 
	# set the reinforcement of the beams, used in the distributed-plasticity model for creating the
	# fiber sections. 
	
	# Asbeamtop = Asbeam: reinforcement area, top: top flange of the beam
	set Asbeamtop "[expr  22.0*$in2] [expr  20.0*$in2] [expr  16.0*$in2] [expr  10.0*$in2]"
	# Asbeambot = Asbeam: reinforcement area, bot: bottom flange of the beam
	set Asbeambot "[expr  10.0*$in2] [expr  10.0*$in2] [expr   8.0*$in2] [expr   5.0*$in2]"
	
	# Define top and bottom bar diameter of each beam. All beams of the same floor have the same reinforcement.
	# Bar diameter is needed to calculate the rotation of the beam due to anchorage slip, as per Eq. 17.15 of Chapter
	# 17, page 413
	# topd = top bar diameter (#9 bars: d = 1.128in)
	set topd "[expr 1.128*$in] [expr 1.128*$in] [expr 1.128*$in] [expr 1.128*$in]"
	# botd = bottom bar diameter (#9 bars: d = 1.128in)
	set botd "[expr 1.128*$in] [expr 1.128*$in] [expr 1.128*$in] [expr 1.128*$in]"
		 
	# Define the number of bars in the beams, used to create the fiber sections in the distributed-plasticity model
	# nobarbeamtop = nobarbeam: number of bars in the beam, top: top flange
	set nobarbeamtop "22 20 16 10"
	# nobarbeambot = nobarbeam: number of bars in the beam, bot: bottom flange
	set nobarbeambot "10 10 8 5"
	

	#----------------------------- Plastic Moments for beams --------------------------------------------------------- 
	# set a 1X(Nstories) vector with the plastic moment for the beams of each story
	# Top Flange in Tension (negative Moment, generally larger than positive)
	#					story 1				story 2				story 3					story 4
	set Mybeam "[expr 6979.03*$kN*$m] [expr 6412.06*$kN*$m]  [expr 4348.12*$kN*$m] [expr 2076.73*$kN*$m]"       
	#Top Flange in Compression (positive moment)
	#					story 1				story 2				story 3					story 4
	set Mybeamp "[expr 3273.72*$kN*$m] [expr 3274.0*$kN*$m]	[expr 2226.41*$kN*$m] [expr 1065.03*$kN*$m]"
	
				 
   	#----------------------------- Ieffective for beams --------------------------------------------------------- 
	# set a (Nstories) x (Ncolumns) matrix with the Ieff of columns as defined by averaging the initial stiffness with the nominal
	# sttiffness at yield of the Moment-Curvature analysis results 
	#					story 1				story 2				story 3					story 4
	set Ibeam "[expr 0.06290222*$m4] [expr 0.06023517*$m4] [expr 0.03390220*$m4] [expr 0.01175167*$m4]"

   
	#~~~~~~~~~~~~~~~~~~~~~~~~~~~~ M O D E L I N G   P A R A M E T E R S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
	
	# Define modeling parameters - a ,b ,c -  (ASCE SEI 41, Table 10-8) for beams and columns of each story. This is 
	# used to create the lumped-plasticity model

	# modeling parameters for beams negative moment: 1 x (Nstories) vector, same for all the beams of one story
	set mpabp "0.0201 0.0208 0.0199 0.0212"
	set mpbbp "0.0326 0.0341 0.0311 0.0347" ;
	set mpcb "0.2 0.2 0.2 0.2"


	# modeling parameters for beams positive moment: 1 x (Nstories) vector, same for all the beams of one story
	set mpab "0.0238 0.0246 0.0242 0.0250"
	set mpbb "0.0477 0.0492 0.0485 0.0500"
		
		
	
	# Modeling Parameters for columns bottom cross-sections
	set mpa "    {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
			 "
	set mpb "    {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
			 "
	set mpc "    {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
			 "
			 
	#Modeling Parameters for columns top cross-sections
	set mpat "   {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
				 {  0.03   0.03   0.03   0.03   0.03 }
			 "
	set mpbt "   {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
				 {  0.044   0.044   0.044   0.044   0.044 }
			 "
			 
	#Residual moment strength parameters after capping (M_r=mpct*M_p)
	set mpct "   {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
				 {  0.2   0.2   0.2   0.2   0.2 }
			 "	 

			 
			 
	#~~~~~~~~~~  P - D   C O L U M N  ~~~~~~~~~~

	# set the PD column area and Izz 
	# We assume that the inertia of the gravity columns is about 1/3 of the columns of the moment frame. 
	# set the inertia properties of the PD column (1x(Nstories)) 
	set  IcolPD "[expr 0.55462552*$m4] [expr 0.55462552*$m4] [expr 0.36802982*$m4] [expr 0.22457393*$m4] "
	# set the area of the PD column (1x(Nstories) vector
	set  AcolPD "[expr 8.*$m2] [expr 8.*$m2] [expr 7.*$m2] [expr 5.*$m2] "
	

	 
} else {
	error "Only Design Methods Mark A, B, C are currently available for the 4-story MRF building"
   
}









			 
				 