# Created 07/08/2019 by A. Chatzidaki & D. Vamvatsikos 
#                   (with the contribution of C. Lyritsakis & F. Andris)

wipe all


source ../util/units_constants_metric.tcl
source ../util/GetPeriodSetDamping.tcl
source ../util/RunGravityAnalysis.tcl


#-------------------------------
# Applying Rayleigh damping to 1st and Nth mode. Define which one is the Nth!
set maxMode_damped 2
# also define the damping ratio
set damping 0.05

# plastic hinge length as percentage of the length of the element
# For determining beam hinge length for lumped plasticity elements.
set hper [expr 0.001]; 

# Drift up to which you want the 1st mode applied. Default value is 1%
set PushDrift1 0.01
# Load pattern style to be applied after PushDrift1. Default is first mode (same as before!)
# 1 == 1st mode
# 2 == uniform
# 3 == inverted 1st mode (most aggressive usually)
set LPstyle2 1

# In double curvature bending, integrating the curvature up to the midpoint will provide us with the 
# total chord rotation (actually the difference in rotation between the end and the midpoint). If we assume 
# cy curvature at the end-point, zero at the center (obviously), linear variation (obviously as cy=-M/EI)
# Then a simple integration gives us: phy = 0.5*cy*L, where L=beam length (bay span).
# Our beams are 4m and the moment rotation diagrams suggest a yield curvature (maintaining the initial
# stiffness up to the nominal yield point) less than 0.001. 

# This was computed for maintaining the initial elastic stiffness of beams up to the cracking of the
# concrete in tension. It is roughly L*10^-4, where L is the bay width (or beam length)


# Yield at 0.2% rad and failure at 1.5% rad (the 0.01 rad is typical assumption for RC beams)
# But this is allowable section rotation and we are looking at chord rotation (or end-rotation of a beam below)
# Say we assume double curvature bending and figure out how the bay length influences! 
# Actually it is simpler if we remember that with rigid joints and columnts, chord rotation at both ends of a doubly-curved 
# beam in bending is the same as the interstory drift angle! Actually, the total rotation of the rigid joint
# gets distributed to beam and column according to their relative stiffness.
# *************
# So at this moment I prescribe a 0.2% yield drift for beams and a 0.5% for columns. These would be
# the true yield drifts if the other counterpart was rigid (i.e. 0.2% story drift would yield the beams
# if the columns were rigid). This makes sense as it will be easier for people to provide such values.
# The relative stiffness of beams and columns determines how the actual drift demand
# will be distributed to beams or columns. Since the moment - end-rotation relationship in double
# curv. bending is M_a = 6EI/L * theta_A,  for both beams and columns, it all depends on 
# EIbeam / EIcolumn. 
# The stiffer element (higher EI) gets lower rotations. It is as simple as that. Thus, for a given 
# yield rotation (or displacement) the higher My (or Fy) yield strength immediately means a 
# lower drift demand. So even if phy = dy, the stronger element (e.g. columns in a capacity-designed building)
# will attract the lower demands. I like this.
# Remember, to turn Fy to an equivalent My for the column use: Fy=2*My/L ==> My=Fy*L/2
# this will tell you which element (beam or column) is stronger. This is also perhaps a smart way
# to figure out the Fy for engineered buildings with columns and walls.
# OBSERVATION: As long as your beams are EP, there is no problem, they deflect for ever and 
# a story mechanism never develops for capacity-designed buildings. It seems the problem appears when
# beams have a finite ductility. Then the strength starts dropping and the columns need to pick the slack
# This is when column failures start appearing and capacity design goes out of the window!!!
#***********************************
# NOTE: the 1% rad ultimate rotation of ATC is actually "plastic hinge rotation" not total.
#       So this is in addition to the elastic part (i.e. the one up to yield).
#       If max steel strain in compression is 0.02, what is the max section curvature? 
#       Can we get it analytically? I guess it is best to go with the moment-curvature relationships from 
#       opensees analysis at this stage :)

set cnod 100


# Added BY DV FOR imultcpu command-line parameter functionality. 
# Simply ignore it if you are not running multiple threads in parallel.

set dataDir ".";

if {$dataDir!="."} {
   if {[info exists imultcpu]} {
       # this is passed via command-line parameters for secondary threads 
       # in multi-core computers.
       set dataDir "$dataDir#$imultcpu"   
   }
   if {![file exists $dataDir]} {
       file mkdir $dataDir; # create data directory
   }
}

# best to clear out all .out files in dataDir.
foreach file [glob -nocomplain -- $dataDir/*.out] {file delete -force -- $file} 


#-----------------------"Sourcing" FEM model tcl file ("subroutine") - Charis
if {[file exists MatIDA_paramfile_Lumped.tcl]} {
   puts "Using EXTERNAL Parameters data-file (Matlab-generated)"
   source MatIDA_paramfile_Lumped.tcl
} else {
   puts "Using STANDARD Parameters data-file"
   source standard_paramfile_4storyMark_Lumped.tcl
}


#---------------------------------------------------------------------------
# Source the analysistype information. Better to have it in a distinct file.
if {[file exists MatIDA_anlsfile.tcl]} {
   puts "Reading EXTERNAL Analysistype file (Matlab-generated)"
   source MatIDA_anlsfile.tcl
}

#---------------------------------------------------------------------------

puts "[string toupper $analysistype] analysis"
if {$analysistype=="dynamic"} {
   puts "Applying $damping damping to modes 1 & $maxMode_damped"
}


#-------------------------------------------------------------------------
# Source the timehistory information to apply. 
if {$analysistype=="dynamic" & [file exists "MatIDA_thfile.tcl"]} {
   set runIDAflag 1
   puts "Using EXTERNAL Timehistory data-file (Matlab-generated)"
   source MatIDA_thfile.tcl
} elseif {$analysistype=="dynamic"} {
   set runIDAflag 0
   puts "Using STANDARD Timehistory data-file"
   source standard_thfile.tcl
} else {
   set runIDAflag 0
}

#-------------------------------------------------------------------------
# max allowed subdivisions of dt. Use 1 for fast runs, but I  suggest using 2 for better
# accuracy. It allows the analysis to go to higher flatlines in some cases.
set dtsub 1.0; 

#--------------------------------
# Eigenvalues to calculate
# Estimate up to 4 eigenvalues. It may fail for only one story. Careful.
if {$analysistype=="eigenvalue"} {
  if {$Nstory<4} {
    set Ndof $Nstory
  } else {
    set Ndof 4  
  }
} else {
  set Ndof $maxMode_damped
}
set PinchingFlag 1

if {$beamtype!="elastic" || $columntype!="elastic" } {
	if {$PinchingFlag==1} {
		# book pinching
		source ../util/Pinching4_hinge.tcl
   } elseif {$PinchingFlag==2} {
   # slightly modified pinching
	source ../util/Pinching4_hinge_modified.tcl
   }
}


#--------------------------------
# Create ModelBuilder (with two-dimensions and 3 DOF/node)
model BasicBuilder -ndm 2 -ndf 3


#Geometric Transformation for columns
if {$PDelta == "plain"} {
        geomTransf PDelta 1
} elseif {$PDelta == "corotational"} {
        geomTransf Corotational 1
} elseif {$PDelta == "none"} {
        geomTransf Linear 1
}

# beams never need P-Delta!
geomTransf Linear 2


#--------------------------------------------------
# Create Nodes
# foundation node is fully fixed.
for {set j 1} {$j<=$Nbay+1+$PDcolumn} {incr j} {
  set tHeight 0.0
  set tMass 0.0
  node [expr 0+($j-1)*$cnod] [expr ($j-1)*$baylength] 0.
  if {$j==$Nbay+1+$PDcolumn} {
    fix [expr 0+($j-1)*$cnod] 1 1 0
  } else {
	if {$fixedbase==1} {
		fix [expr 0+($j-1)*$cnod] 1 1 1
	} else {
		fix [expr 0+($j-1)*$cnod] 1 1 0
	}		
		
  }

  for {set i 1} {$i<=$Nstory} {incr i} {
    set i_1 [expr $i-1]
    # height from ground
    set tHeight [expr $tHeight+[lindex $storyHeight $i_1]]   
    set tMass   [expr $tMass  +[lindex $floormass $i_1]]
    node             [expr $i+($j-1)*$cnod]   [expr ($j-1)*$baylength]   $tHeight  -mass [expr [lindex $floormass $i_1]/($Nbay+1.+$PDcolumn)] 0.1 0.1 
    if {$j>1} {
      equalDOF $i [expr $i+($j-1)*$cnod] 1
    }
  }
}

puts "Total height (m)  = $tHeight"
puts "Total mass   (tn) = $tMass"

set damagepars "0.5 0.8 0.7 \
                0.5 0.8 0.7 \
                0. 0.0 0.0 0.0 0.0\
            0. 0.0 0.0 0.0 0.0\
                0. 0.0 0.0 0.0 0.0\
        10. energy"  
# This is not really needed as an accurate value, only a dummy one. The fyb is adjusted later on
# to simply achieve the proper My on the beams.
set Wplzzc [expr 1.0*$m3]

#-------------------------------------------------
# ~~~~~~~  CREATE COLUMNS ~~~~~~~~~
#The following part is modified so differences between "End" and "Intermediate" columns can be taken into account.
#Each parameter (i.e I,A,Ec etc) is stored in a 2d matrix with dimensions (Nstory x Nbay+1). Each row contains the
#parameter X of columns for the corresponding story (CHARIS)

#Initialization 2d rotation matrices for columns that correspond to points C and E respectively
#for bottom (phuc & phul) and top (phuct &phult) cross-sections
set phuc " "
set phul " "
set phuct " "
set phult " "

#COLUMNS
#Nested loop for each story -> for each column
for {set i 1} {$i<=$Nstory} {incr i} {       
  set i_1 [expr $i-1]
  
  #Initialization of 1d dummy arrays for parameters a,b for each column of Kth story
  set dumara " "
  set dumarb " "
  set dumarat " "
  set dumarbt " "
  
  for {set j 1} {$j<=$Nbay+1} {incr j} {
	  set j_1 [expr $j-1]
	  

	  set Ec [lindex $Ecol $i_1 $j_1]
      
    # Added processing of modeling parameters -a,b,c- to calculate capping and ultimate rotations ~~~~~
	 
	  #Bottom column cross-section processing
	  set mpara [lindex $mpa $i_1 $j_1]
	  set mparb [lindex $mpb $i_1 $j_1]
	  
	  
	  lappend dumara [expr [lindex $phyc $i_1 $j_1]+$mpara] ; #Calculating and appending capping rotation for columns of i_1 story to list dumara
	  lappend dumarb [expr [lindex $phyc $i_1 $j_1]+$mparb] ; #Calculating and appending ultimate rotation for columns of i_1 story to list dumarb
      
	  #Top Column cross-section processing
	  set mpara [lindex $mpat $i_1 $j_1]
	  set mparb [lindex $mpbt $i_1 $j_1]
	  
	  lappend dumarat [expr [lindex $phyct $i_1 $j_1]+$mpara] ; #Calculating and appending capping rotation for columns of i_1 story to list dumara
	  lappend dumarbt [expr [lindex $phyct $i_1 $j_1]+$mparb] ; #Calculating and appending ultimate rotation for columns of i_1 story to list dumarb
	  
   }
   
   if {$PDcolumn==1} {
		set pdk [expr $Nbay+2]
	
	   element elasticBeamColumn  [expr 100+($i-1)*($Nbay+1)+$pdk]  [expr $i-1+($pdk-1)*$cnod] [expr $i+($pdk-1)*$cnod]\
								  [lindex $AcolPD $i_1]  $Ec [lindex $IcolPD $i_1]   1
    }  
    lappend phuc $dumara ; # Storing capping rotations for bottom x-sections of columns for i_1 floor to 2d array "phuc"  
    lappend phul $dumarb ; # Storing ultimate rotations for bottom x-sections of columns for i_1 floor to 2d array "phul"	
	lappend phuct $dumarat ; # Storing capping rotations for top x-sections of columns for i_1 floor to 2d array "phuct" 
    lappend phult $dumarbt ; # Storing ultimate rotations for top x-sections of columns for i_1 floor to 2d array "phult"	
	
}
for {set i 1} {$i<=$Nstory} {incr i} {
	set i_1 [expr $i-1]
	for {set j 1} {$j<=$Nbay+1} {incr j} {
		set j_1 [expr $j-1]
		set eletagnum [expr 1000+($i-1)*($Nbay+1)+$j]  ; #gia debugging
	    set sheight [lindex $storyHeight $i_1]    
	    set totalIc [lindex $Icol $i_1 $j_1]
		set totalIcg [lindex $Icolg $i_1 $j_1]
	    set totalAc [lindex $Acol $i_1 $j_1]		
		set Ec [lindex $Ecol $i_1 $j_1]
		
		if {$columntype=="Elastic"||$columntype=="elastic"} {  
			#element elasticBeamColumn $eleTag $iNode $jNode $A $E $Iz $transfTag
			element elasticBeamColumn [expr 1000+($i-1)*($Nbay+1)+$j]  [expr $i-1+($j-1)*$cnod] [expr $i+($j-1)*$cnod] $totalAc  $Ec $totalIc   1
        
  
	  } elseif {$columntype=="EHNR"} {  
			 
			
			  #Bottom cross-section parameters(above floor level)
			  set ah $ahc ;                                           #column post-yielding hardening (file standard_paramfile_name etc)
			  set mc [expr [lindex $phuc $i_1 $j_1]/[lindex $phyc $i_1 $j_1]]  ;#cap/y
			  set ac -0.90 ;                                          #capping negative slope (softening) as percentage of the initial flexural stiffness
			  set rp [lindex $mpc $i_1 $j_1] ;                                         #Residual strength (% My)  
			  set mu [expr [lindex $phul $i_1 $j_1]/[lindex $phyc $i_1 $j_1]] ; #Ultimate ductility    (,  mu=10*mc)
			  set mcr [expr [lindex $phcr $i_1 $j_1]/[lindex $phyc $i_1 $j_1]] ; # _cr/_p ratio
			  set thp [lindex $phyc $i_1 $j_1]; # plastic rotation
			  
			  #top cross-section parameters(below floor level)
			  set aht $ahc ;                                           
			  set mct [expr [lindex $phuct $i_1 $j_1]/[lindex $phyct $i_1 $j_1]]  
			  set act -0.90 ;                                          
			  set rpt [lindex $mpct $i_1 $j_1]                                        
			  set mut [expr [lindex $phult $i_1 $j_1]/[lindex $phyct $i_1 $j_1]]
		      set mcrt [expr [lindex $phcrb $i_1 $j_1]/[lindex $phyct $i_1 $j_1]] ; # _cr/_p ratio
			  set thpt [lindex $phyct $i_1 $j_1]
			  
			  set rat 1. ; #symmetrical behaviour of cross section
			  set mcp 1.; #Dummy for columns (check beams)
			  set mup 1.; # >>    >>    >>
			  set thpn 1.; # >>   >>  >>
			  set mcrn 1.; # >>   >>    >>
			
			# Just pick an "fyc" value that will produce a yield moment consistent with
			# the rough Wplzzb above and with the implied 6EI/L or 3EI/Lrot. stiffness of a column
			# in double or single curvature bending, respectively.
			# The point is to make sure that it yields with the proper stiffness at the designated phy.
			# We only care about the overall My of the hinge after all.
			# My = Wplzzc * fyc = phyc*6Ec*Ic/Lc ==> fyc = ....

			if {$i==1 & $fixedbase==0} {
			  # 1st floor base is pinned (3EI/L rotationa stiffness)
			  set nstiff [expr (1-2*$hper)/(3*$hper)]
			  #set fyc    [expr [lindex $phyc $i_1]*(3*$Ec*$totalIc)/($sheight*$Wplzzc)]
			} else {
			  # all higher floors and first floor as well is fixed (6EI/L rotationa stiffness)
			  set nstiff [expr (1-2*$hper)/(6*$hper)]
			  #set fyc    [expr [lindex $phyc $i_1]*(6*$Ec*$totalIc)/($sheight*$Wplzzc)]
			}
	        
			#Bottom cross-section law
			set btag [expr 10*$i_1+2*$j_1+1] ; #tag of bottom cross-section of j column
			set fyc    [expr [lindex $Mycol $i_1 $j_1]/$Wplzzc]
			Pinching4_hinge $btag $fyc $rat $Ec $totalIc $Wplzzc\
									$fcrack $thp $mcr $thpn $mcrn $ah $mc $ac $rp $mu $mcp $mup $nstiff $damagepars $eletagnum
			section Aggregator $btag $btag Mz
			
			#Top cross-section law
            set ttag [expr 10*$i_1+2*$j] ; #tag of top cross-section of j column
			set fyc    [expr [lindex $Mycolt $i_1 $j_1]/$Wplzzc]
			Pinching4_hinge $ttag $fyc $rat $Ec $totalIc $Wplzzc\
									$fcrack $thpt $mcrt $thpn $mcrn $aht $mct $act $rpt $mut $mcp $mup $nstiff $damagepars $eletagnum
			#puts "$btag, $ttag, [expr $btag+1000],[expr $ttag+1000]"						
			# bending  for 2D analysis is Mz by default. So orient Iyy the other way!
			# SEE THE FIGURES IN MANUAL FOR Section Aggregator!
			section Aggregator $ttag $ttag Mz
	   
            
			
			element beamWithHinges [expr 1000+($i-1)*($Nbay+1)+$j]  [expr $i-1+($j-1)*$cnod] [expr $i+($j-1)*$cnod]\
									$btag [expr $sheight*$hper] $ttag [expr $sheight*$hper]\
									$Ec $totalAc $totalIc 1 -iter 5
		
	  }
 }
}   


# This is not really needed as an accurate value, only a dummy one. The fyb is adjusted later on
# to simply achieve the proper My on the beams.
set Wplzzb [expr 1.0*$m3]



 
set nstiff [expr (1-2*$hper)/(6*$hper)]

set damagepars "0.5 0.8 0.7 \
                      0.5 0.8 0.7 \
                      0. 0.0 0.0 0.0 0.0\
                  0. 0.0 0.0 0.0 0.0\
                      0. 0.0 0.0 0.0 0.0\
              10. energy"  

set Beoff 10000

#--------------------------------------------------
# Add beams at each story
for {set i 1} {$i<=$Nstory} {incr i} {
  set i_1 [expr $i-1]
  # You need the 2x in the Abeam and Ibeam, for the same reason as in the stickNdof for rotational springs:
  # Each beam supports (restrains) two columns, so it helps twice.
  set totalIb [lindex $Ibeam $i_1]
  set totalIbg [lindex $Ibeamg $i_1]
  set totalAb [lindex $Abeam $i_1]
  set Eb   [lindex $Ebeam $i_1]
 
  if {$i==1} {
	set phub ""
	set phulb ""
	set phubp ""
	set phulbp ""
	}
	# positive moment 
  set mpara [lindex $mpab $i_1]
  set mparb [lindex $mpbb $i_1]
  set mparc [lindex $mpcb $i_1]
  
  lappend phub [expr [lindex $phyb $i_1]+$mpara]  ; #Calculating and appending POSITIVE capping rotation for beams of i_1 story to list phuc
  lappend phulb [expr [lindex $phyb $i_1]+$mparb]  ; #Calculating and appending POSITIVE ultimate rotation for beams of i_1 story to list phul
  
  # negative moment
  set mpara [lindex $mpabp $i_1]
  set mparb [lindex $mpbbp $i_1]
  
  lappend phubp [expr [lindex $phybp $i_1]+$mpara]  ; #Calculating and appending NEGATIVE capping rotation for beams of i_1 story to list phuc
  lappend phulbp [expr [lindex $phybp $i_1]+$mparb]  ; #Calculating and appending NEGATIVE ultimate rotation for beams of i_1 story to list phul
  
  

  if {$beamtype=="Elastic"||$beamtype=="elastic"} {
  for {set j 1} {$j<=$Nbay} {incr j} {
   
element elasticBeamColumn [expr 10000+($i-1)*$Nbay+$j]  [expr $i+($j-1)*$cnod] [expr $i+$j*$cnod] $totalAb $Eb $totalIb 2
    }
  } elseif {$beamtype=="EHNR"} {
	  # positive moment
	  set ah $ahb ;                                           #beam post-yielding hardening (file standard_paramfile_name etc)
      set mc [expr [lindex $phub $i_1]/[lindex $phyb $i_1]]  ;# capping ductility cap/y
      set ac -0.90 ;                                          #capping negative slope (softening) as percentage of the initial flexural stiffness
      set rp $mparc ;                                         #Residual strength (% My)  
      set mu [expr [lindex $phulb $i_1]/[lindex $phyb $i_1]] ; #Ultimate ductility    
	  set mcr [expr [lindex $phcrbp $i_1]/[lindex $phyb $i_1]] ; # _cr/_p for positive moment
	  set thp [lindex $phyb $i_1]   ;# _p for positive moment
	set fybp    [expr [lindex $Mybeamp $i_1]/$Wplzzb]  ; #positive moment input for pinching4hinge
	  # adding different capping and ultimate ductilities as input for the pinching4hinge routine for the unsymmetrical
	  # moment-rotation law
	  set mcp [expr [lindex $phubp $i_1]/[lindex $phybp $i_1]] ; # capping ductility for NEGATIVE moment (added)
	  set mup [expr [lindex $phulbp $i_1]/[lindex $phybp $i_1]] ; #ultimate ductility for NEGATIVE moment (added)
	  set mcrn [expr [lindex $phcrbn $i_1]/[lindex $phybp $i_1]] ; # _cr/_p for negative moment
	  set thpn [lindex $phybp $i_1]
    set fyb    [expr [lindex $Mybeam $i_1]/$Wplzzb]  ; #negative moment input for pinching4hinge
    
	set rat [expr $fybp/$fyb] ; #positive to negative moment ratio
    
    if {$PinchingFlag==1} {
		Pinching4_hinge [expr $i+$cnod] $fyb $rat $Eb $totalIb $Wplzzb\
                                  $fcrack $thpn $mcr $thp $mcrn $ah $mc $ac $rp $mu $mcp $mup $nstiff $damagepars $i

	} else {
		Pinching4_hinge [expr $i+$cnod] $fyb $rat $Eb $totalIb $Wplzzb\
                                  $fcrack $thpn $mcrn $thp $mcr $ah $mcp $ac $rp $mup $mc $mu $nstiff $damagepars $i
	}
    # bending  for 2D analysis is Mz by default. So orient Iyy the other way!
    # SEE THE FIGURES IN MANUAL FOR Section Aggregator!
    section Aggregator [expr $i+$cnod] [expr $i+$cnod] Mz
    
    for {set j 1} {$j<=$Nbay} {incr j} {
	
	

		element beamWithHinges [expr 10000+($i-1)*$Nbay+$j]  [expr $i+($j-1)*$cnod] [expr $i+$j*$cnod]\
								[expr $i+$cnod] [expr $baylength*$hper] [expr $i+$cnod] [expr $baylength*$hper]\
								$Eb $totalAb $totalIb 2 -iter 5
     }
  }
}


pattern Plain 1 "Linear" {
  for {set i 1} {$i<=$Nstory} {incr i} {
    set i_1 [expr $i-1]
    if {$PDcolumn==1} {
      set nload [expr -[lindex $floormass $i_1]*$pTrib*$g/($Nbay+1.)]
      set nloadPD [expr -[lindex $floormass $i_1]*(1-$pTrib)*$g]
      set j $Nbay+2
      load   [expr $i + ($j-1)*$cnod]     0.0  $nloadPD  0.0
    } else {
      set nload [expr -[lindex $floormass $i_1]*$g/($Nbay+1.)]  
    }
    for {set j 1} {$j<=$Nbay+1} {incr j} {
      load   [expr $i + ($j-1)*$cnod]     0.0  $nload  0.0
    }
  }
}


constraints Transformation
RunGravityAnalysis 10


#GetPeriodSetDamping Neigen  ksi    i  j  outfilename
GetPeriodSetDamping  $Ndof   $damping   1  $maxMode_damped  "MRF4StoryPeriods.out" 3



if {$runIDAflag==0} {
  file delete stickNdofGravity.out
  print stickNdofGravity.out
}


for {set i 1} {$i<=$Nstory} {incr i} {
   if {$i<10} {   
     recorder Drift  -file "idr_0$i\x.out" -time -iNode [expr $i-1] -jNode $i -dof 1 -perpDirn 2

   } else {
     recorder Drift  -file "idr_$i\x.out"  -time -iNode [expr $i-1] -jNode $i -dof 1 -perpDirn 2
   }
}

recorder Drift -file "roofdrx.out" -time -iNode  0 -jNode $Nstory  -dof 1  -perpDirn 2


# Recorders for COLUMN MQN : filename "mqncolumnLumped_1001.out" for example
for {set i 1} {$i<=$Nstory} {incr i} {
  for {set j 1} {$j<=$Nbay+1} {incr j} {
     set k [expr 1000+($i-1)*($Nbay+1)+$j]
    set elenum [expr $k] 
     recorder Element -file "mqncolumnLumped_$elenum.out" -time -ele $elenum localForce
	 recorder Element -file "plRot_column_$elenum.out" -time -ele $elenum plasticDeformation
  }
}

# Recorders for BEAM MQN : filename "mqnbeamLumped_10001.out" for example
for {set i 1} {$i<=$Nstory} {incr i} {
  for {set j 1} {$j<=$Nbay} {incr j} {
    set m [expr 10000+($i-1)*$Nbay+$j]
    set elenum2 [expr $m] 
     recorder Element -file "mqnbeamLumped_$elenum2.out" -time -ele $elenum2 localForce
	 recorder Element -file "plRot_beam_$elenum2.out" -time -ele $elenum2 plasticDeformation
  }
}

#------------------------------------------------------------------
####################    analysis   #########################

if {$analysistype=="dynamic"} {
  source ../util/ReadSMDFile3.tcl
  source ../util/DefineXYZ_UniformExcitation2.tcl
  # you are getting back "nptsx" and "dtx". Careful, since you already have 1 load pattern defined
  # (for gravity) you need to start your uniformexcitation patterns from tag "2" at least. 
  DefineXYZ_UniformExcitation $dtsub $g $GMdir $GMfileX $GMfileY $GMfileZ $GMfactorX $GMfactorY $GMfactorZ nptsx dtx 2
  
  # Define absolute acceleration recorders at center of slab
  for {set i 0} {$i<=$Nstory} {incr i} {
    if {$i<10} {
      recorder Node -file "acc_0$i\x.out" -timeSeries 1 -time -node $i -dof 1 accel
    } else {
      recorder Node -file "acc_$i\x.out" -timeSeries 1 -time -node $i -dof 1 accel
    }
  }
  

 integrator Newmark 0.5 0.25
  test NormDispIncr 1.0e-8 20 0
  # puts "nptsx=$nptsx"
  # Actually, if coming from same earthquake we should have nptsx==nptsy (or very close) and dtx==dty
  
  
    puts "analysis Transient"
    analysis Transient
    source ../util/RunTransient2Converge.tcl
    RunTransient2Converge [expr $nptsx*$dtsub] [expr $dtx/$dtsub] "ncerror.out"

} elseif {$analysistype=="pushover"} {
  source  ../util/RunPushover2Converge.tcl
	################ Display the model #################
	## The default option is to display the model during the pushover analysis. If you want to disable
	## this selection comment the 5 lines below
	# recorder display "Model" 10 10 600 600 -wipe
	# prp 0 0 50
	# vup 0 1 0
	# vpn 0 0 1
	# display 1 2 10
  
  # Create a Plain load pattern with a Linear TimeSeries: Note, the loads below do sum to 1.00!
  set cumsum 0.0
  for {set i 1} {$i<=$Nstory} {incr i} {
     set i_1 [expr $i-1]
     # use eigenvector 1 in DOF 1 to define the pushover load pattern. Use this loop
     # to find un-normalized forces and then normalize to 1.0 base shear.
     set nodeEigenvector [expr abs([nodeEigenvector $i 1 1])];
     set pushForce($i) [expr ($nodeEigenvector*[lindex $floormass $i_1])]
     set cumsum [expr $cumsum+$pushForce($i)]
  }
  puts "Pushover Load Pattern------ 1st mode"
  pattern Plain 2 "Linear" {
     for {set i 1} {$i<=$Nstory} {incr i} {
          load $i [expr $pushForce($i)/$cumsum] 0.0 0.0
          puts "$i: [expr $pushForce($i)/$cumsum]"
     }
  }

  # Careful: If you change the node numbering, you must also change the IDctrlNode!
  set IDctrlNode $Nstory
  
  # Mostly elastic range, up to 1% roof drift. Use large steps
  set Nsteps 200
  #set DriftStep 0.5e-4
  set DriftStep [expr $PushDrift1/$Nsteps]
  set DispStep [expr $tHeight*$DriftStep]
  set DmaxPush [expr $Nsteps*$DispStep]
  
  puts "Pushing Node $IDctrlNode to [expr $Nsteps*$DriftStep*100]% roof drift in  $Nsteps steps"
  integrator DisplacementControl $IDctrlNode 1 $DispStep
  #test EnergyIncr 1.0e-5 10 0
  test NormDispIncr 1.0e-8 20 0
  analysis Static
  
  #RunPushover2Converge IDctrlNode DmaxPush Nsteps dof
  RunPushover2Converge  $IDctrlNode $DmaxPush  $Nsteps

  #GetPeriodSetDamping  $Ndof   $damping   1  $maxMode_damped  "$dataDir/stickNdofPeriods2.out" 2
  
  if {$LPstyle2==2} {
     loadConst
     puts "Pushover Load Pattern------ Uniform"
     pattern Plain 3 "Linear" {
        for {set i 1} {$i<=$Nstory} {incr i} {
           load $i [expr 1.0/$Nstory] 0.0 0.0
           puts "$i: [expr 1.0/$Nstory]"
        }
     }
  } elseif {$LPstyle2==3} {
     loadConst
     puts "Pushover Load Pattern------ Inverse of 1st mode"
     pattern Plain 3 "Linear" {
        for {set i 1} {$i<=$Nstory} {incr i} {
           load $i [expr $pushForce([expr $Nstory-$i+1])/$cumsum] 0.0 0.0
           puts "$i: [expr $pushForce([expr $Nstory-$i+1])/$cumsum]"
        }
     }
  } else {
    puts "Pushover Load Pattern------ 1st mode"
    # nothing further needs to be done here. The existing load pattern is used
  }


  # Tough part: In the inelastic range we need really small steps.
  set currentDrift [expr $Nsteps*$DriftStep]
  set currentDisp  [expr $Nsteps*$DispStep]
  set DriftStep 0.1e-4
  set DispStep [expr $tHeight*$DriftStep]
  set Nsteps 6000
  set DmaxPush [expr $currentDisp+$Nsteps*$DispStep]
  puts "Pushing Node $IDctrlNode from [expr $currentDrift*100]% to [expr ($currentDrift+$Nsteps*$DriftStep)*100]% roof drift in  $Nsteps steps"
  integrator DisplacementControl $IDctrlNode 1 $DispStep

  #integrator ArcLength [expr $DispStep] 5.1
  #RunPushover2Converge IDctrlNode DmaxPush Nsteps dof
  RunPushover2Converge  $IDctrlNode $DmaxPush  $Nsteps
  loadConst -time 0.0
}

if {$runIDAflag==0} {
  file delete stickNdofFinal.out
  print stickNdofFinal.out
}
 ###28/Juli/2016 I added this command in order to plot the frame whichever analysis is run

 file delete MRF4StoryModel.out 
  print MRF4StoryModel.out
