# The modeling parameters are defined in this file!

# source building-specific information
source Design_Info.tcl



# Column and beam hysteretic behavior definitions. Allowable values include: 
#      "Elastic" : elastic! 
#      "EHNR"    : elastic-hardening-negative-residual, limited by ultimate ductility
#  Pinching hysteresis is employed, rather than kinematic hardening.
#  default is EHNR for both columns and beams.

set beamtype "EHNR"
set columntype "EHNR"

# flag to take into account initial uncracked section stiffness. 1= takes into account uncracked stiffness. =/= 1, initial stiffness is derived from cracked sections
set crackflag 2

if {$crackflag==1} {
	puts "UNCRACKED STIFFNESS INCLUDED"
	} else {
	puts "ONLY CRACKED STIFFNESS INCLUDED"
}
# if 1, then first floor columns are fixed at ground, otherwise they are pinned.
set fixedbase 1

set PDelta "plain";  # options: plain, corotational, none


set PDcolumn 1 ;#modified by Fotis 7July2016,adding with this way a PD col to the model


#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ C O L U M N S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
# Calculating plastic (yield) curvature and plastic (yield) rotations for columns 
# yield rotations for sections just above floor level are stored in the 2d array "phyc"
# yield rotations for sections just below floor level are stored in the 2d array "phyct"
# yield rotations are derived from yield curvatures through the relation y ~ d*y
# yield curvatures are derived from equation (17.16) of chapter 17 (page 415) : y = (1.8-1.3*P/(A_g*f_ce)+9*(-0.025))*sy/d
# Priestley approximation for column yield curvature is also added (as comment) as an alternative approach : y=2.1*sy/d
set phyc " "  ; # plastic (yield) rotation array for above floor level sections - initialization
set phyct " " ; # plastic (yield) rotation array for below floor level sections - initialization
for {set i 1} {$i<=$Nstory} {incr i} {
	set i_1 [expr $i-1]
	set Pc [expr -1.*[lindex $axialLoad $i_1]]; 
	set dumab " "
	set dumbe " "	
	for {set j 1} {$j<=$Nbay+1} {incr j} {
		set j_1 [expr $j-1]
		
		if {$j<2 || $j>$Nbay} {
			set Asla $Ascole ; #above floor lvl end
			set Aslb $Ascoleb ; #below floor lvl end
		} else {
			set Asla $Ascoli ; # above floor lvl inter
			set Aslb $Ascolib; #below floor lvl inter
	    }
		
		set depth [expr 0.9*([lindex $hcolumn $i_1 $j_1])] ; #depth from the top fiber to the centroid of the bottom long. reinf ~ simply 0.9*h 
		set Acgr [expr [lindex $bcolumn $i_1 $j_1]*[lindex $hcolumn $i_1 $j_1]] ; # calculating gross A of column 
		
		#Above floor level
		set rat [expr [lindex $Asla $i_1]/$Acgr] ; # reinforcement ratio = (area of the reinforcement)/(column area)
		#set phy [expr 2.1*$esy/$depth]
		set phy [expr (1.8-1.3*$Pc/($Acgr*$fce)+9.*($rat-0.025))*$eys/$depth] ; # yield curvature for column section above floor level
		
		lappend dumab [expr $depth*$phy]  ; # Yield rotation ~ d*phy
		
		#Below floor level
		set rat [expr [lindex $Aslb $i_1]/$Acgr]
		#set phy [expr 2.1*$esy/$depth]
		set phy [expr (1.8-1.3*$Pc/($Acgr*$fce)+9*($rat-0.025))*$eys/$depth] ; # yield curvature for column section below floor level
		lappend dumbe [expr $depth*$phy]  ; # Yield rotation ~ d*phy
	}
	lappend phyc $dumab
	lappend phyct $dumbe
}


#Derive cross-sectional area ,effective (cracked) and gross (uncracked) moments of intertia of columns (bcolumn dimensions and elements should be changed MANUALLY for each structure)
set Acol " "
set Icolg " "
for {set i 1} {$i<=$Nstory} {incr i} {
	set i_1 [expr $i-1]
	set dumli " "
	set dumin " "
	set dumgin " "
	for {set j 1} {$j<=$Nbay+1} {incr j} {
		set j_1 [expr $j-1]
		lappend dumli [expr [lindex $bcolumn $i_1 $j_1]*[lindex $hcolumn $i_1 $j_1]]
		set Izzg [expr [lindex $bcolumn $i_1 $j_1]*[lindex $hcolumn $i_1 $j_1]**3./12.]  ; # column moment of inertia (bh^3/12)
		lappend dumgin $Izzg
		}
	lappend Acol $dumli
	lappend Icolg $dumgin
}

# Derive cracking curvatures and rotations for column top (below floor lvl) and bottom (above floor level) sections
# if crackflag is 1, then a new cracking point will be created - (_cr, Mcr) and the curve that connects the points (0,0) -(_cr, Mcr)-(p,p) is billinear
# If crackflag is not 1, then the cracking point will be "moved" so that it will lie on the line that connects (0,0)-(p,p)

set phcr " " ; # initialize array of cracking rotations for above floor level column sections
set phcrb " " ; # initialize array of cracking rotations for below floor level columns sections
set fcrack 0.3  ; # M_crack=fcrack * Mp ---> cracking moment is ~30% of plastic moment strength

if {$crackflag==1} {
	for {set i 1} {$i<=$Nstory} {incr i} {
		set i_1 [expr $i-1]
		set dumcr " "
		set dumcrb " "
		for {set j 1} {$j<=$Nbay+1} {incr j} {
			set j_1 [expr $j-1]
			set depth [expr 0.90*[lindex $bcolumn $i_1 $j_1]]
			
			#Above floor level
			set curvcr [expr $fcrack*[lindex $Mycol $i_1 $j_1]/([lindex $Ecol $i_1 $j_1]*[lindex $Icolg $i_1 $j_1])] ; #cracking curvature for section above floor level -> cr=0.3Mp/(EI_g)
			lappend dumcr [expr $depth*$curvcr]
			
			#Below floor level
			set curvcr [expr $fcrack*[lindex $Mycolt $i_1 $j_1]/([lindex $Ecol $i_1 $j_1]*[lindex $Icolg $i_1 $j_1])] ; #cracking curvature for section above floor level
			lappend dumcrb [expr $depth*$curvcr]
	  }
	  lappend phcr $dumcr
	  lappend phcrb $dumcrb
	}
 } else {
	for {set i 1} {$i<=$Nstory} {incr i} {
		set i_1 [expr $i-1]
		set dumcr " "
		set dumcrb " "
		for {set j 1} {$j<=$Nbay+1} {incr j} {
			set j_1 [expr $j-1]
			
			#Above floor level
			set tang [expr [lindex $Mycol $i_1 $j_1]/[lindex $phyc $i_1 $j_1]]
			set curvcr [expr $fcrack*[lindex $Mycol $i_1 $j_1]/$tang] 
			lappend dumcr $curvcr  ; # this is already a rotation
			
			#Below floor level
			set tang [expr [lindex $Mycolt $i_1 $j_1]/[lindex $phyct $i_1 $j_1]]
			set curvcr [expr $fcrack*[lindex $Mycolt $i_1 $j_1]/$tang] ; #cracking curvature for section above floor level
			lappend dumcrb $curvcr
	    }
	  lappend phcr $dumcr
	  lappend phcrb $dumcrb
    }
 }


# hardening for columns
set ahc 0.01


#~~~~~~~~~~~~~~~~~~~~~~~~~~~~ B E A M S ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
#Derive cross-sectional area ,effective (cracked) and gross (uncracked) moments of intertia of beams
#Assuming beams belonging to nth floor all have save h and b.
set Abeam " "
set Ibeamg " "
for {set i 1} {$i<=$Nstory} {incr i} {
	set i_1 [expr $i-1]
		
	lappend Abeam [expr [lindex $beamb $i_1]*[lindex $beamh $i_1]]
	set Izzg [expr ([lindex $beamb $i_1]*[lindex $beamh $i_1]**3./12)] ; # beam moment of inertia (=bh^3/12)
	lappend Ibeamg $Izzg
}


set ahb 0.01


# Calculating plastic (yield) rotation for beams 
# Plastic curvatures when moment is negative are stored in the array "phybp", using the relation (17.7) of chapter 17, page 411: y=1.8*y/d (Paulay)
# Plastic curvatures when moment is positive are stored in the array "phyb", using the relation (17.8) of chapter 17, page 411:y=1.4*y/d (Paulay)
# For beams, anchorage slip is taken into account. Relation (17.15{1}) provides the rotation due to slip directly
# The slip rotation is the added to the yield rotation to form the total rotation at point B : y=2*depth*y+_slip
set phybp " "
set phyb " "
for {set i 1} {$i<=$Nstory} {incr i} {
	set i_1 [expr $i-1]
	set depth [expr 0.9*[lindex $beamh $i_1]] ; #distance between top beam fiber and bottom longitudinal rebar centroid ~0.9h
	# plastic rotation for negative moment (top flange in tension)
	set curvn [expr 1.8*$eys/[lindex $beamh $i_1]]
	# note that we use the formula with the 96. in the denominator but the bar diameter is defined 
	# in meters instead of inches. This is done because we multiply with the curvature which is in 
	# 1/m!
	set tslipn [expr $curvn*$fsys*[lindex $topd $i_1]/(96.*$fcs**0.5)]
	lappend phybp [expr 2.*$depth*$curvn+$tslipn]

	#plastic rotation for positive moment (bot flange in tension)
	set curvp [expr 1.4*$eys/[lindex $beamh $i_1]]
	set tslipp [expr $curvp*$fsys*[lindex $botd $i_1]/(96.*$fcs**0.5)]
	lappend phyb [expr 2.*$depth*$curvp+$tslipp]
}
          

# Derive cracking curvatures and rotations for beam sections 
#if crackflag is 1, then a new cracking point will be created - (_cr, Mcr) and the curve that connects the points (0,0) -(_cr, Mcr)-(p,p) is billinear
# If crackflag is not 1, then the cracking point will be "moved" so that it will lie on the line that connects (0,0)-(p,p)

#initialize arrays for negative and positive _cr
set phcrbn " "  ; # _cr for negative moments
set phcrbp " "  ; # _cr for positive moments
if {$crackflag==1} {
	for {set i 1} {$i<=$Nstory} {incr i} {
		set i_1 [expr $i-1]
		set depth [expr 0.90*[lindex $beamh $i_1]]
			
		#Negative moment
		set curvcr [expr $fcrack*[lindex $Mybeam $i_1]/([lindex $Ebeam $i_1]*[lindex $Ibeamg $i_1])] ; #cracking curvature for section above floor level -> cr=0.3Mp/(EI_g)
		lappend phcrbn [expr $depth*$curvcr]
		
		#Positive moment
		set curvcr [expr $fcrack*[lindex $Mybeamp $i_1]/([lindex $Ebeam $i_1]*[lindex $Ibeamg $i_1])] ; #cracking curvature for section above floor level
		lappend phcrbp [expr $depth*$curvcr]
	}
 } else {
	for {set i 1} {$i<=$Nstory} {incr i} {
		set i_1 [expr $i-1]
				
		#Negative Moment
		set tang [expr [lindex $Mybeam $i_1]/[lindex $phybp $i_1]]
		set curvcr [expr $fcrack*[lindex $Mybeam $i_1]/$tang] 
		lappend phcrbn $curvcr  ; # this is already a rotation
		
		#Positive Moment
		set tang [expr [lindex $Mybeamp $i_1]/[lindex $phyb $i_1]]
		set curvcr [expr $fcrack*[lindex $Mybeamp $i_1]/$tang] ; #cracking curvature for section above floor level
		lappend phcrbp $curvcr
    }
 }

#~~~~~~~~~~  P - D   C O L U M N  ~~~~~~~~~~
# If you want to estimate the inertia properties of the PD column automatically, you can uncomment & modify the section
# below.
# # define the basic dimension of the gravity columns for each floor (assuming that all gravity columns
# # of the same floor have the same dimensions and b=h
# # set gravcoldim "[expr 18.*$in] [expr 18.*$in] [expr 18.*$in] [expr 18.*$in]"
# # Define sum pattern for columns not belonging to the MRF (THIS MUST BE CHANGED FOR DIFFERENT FRAME STRUCTURES)
# # The idea is to use a formula that calculates A and Izz of the PD column for each floor
# set gravnum1 5  ; #5 gravity columns not belonging to the MRF that contribute to the PD with their FULL A,Izz
# set gravnum2 5  ; #5 gravity columns not belonging to the MRF that contribute to the PD with their HALF A,Izz
# set extnum1 2  ; #2 end columns not belonging to the examined MRF,that contribute to the PD with their FULL A,Izz
# set intnum1 2  ; #2 intermmediate columns not belonging to the MRF,that contribute to the PD with their FULL A,Izz
# set intnum2 2  ; #2 intermmediate columns not belonging to the MRF,that contribute to the PD with their HALF A,Izz

# # Initialize arrays for cross-sectional area and inertia A,Izz of the PD column
# set AcolPD ""
# set IcolPD ""

# for {set i 1} {$i<=$Nstory} {incr i} {
	# set i_1 [expr $i-1]
	
	# #lappend AcolPD [expr $extnum1*[lindex $colbe $i_1]*[lindex $colexth $i_1]+($gravnum1+0.5*$gravnum2)*([lindex $gravcoldim $i_1])**2+($intnum1+0.5*$intnum2)*[lindex $colinth $i_1]*[lindex $colbi $i_1]]
	
	# #lappend IcolPD  [expr $extnum1*[lindex $colexth $i_1]*[lindex $colbe $i_1]**3./12.+($gravnum1+0.5*$gravnum2)*([lindex $gravcoldim $i_1])**4./12.+($intnum1+0.5*$intnum2)*[lindex $colinth $i_1]*[lindex $colbi $i_1]**3./12.]
	
# } 