# Define a procedure which generates a rectangular reinforced concrete section
# with two different layers of steel and a confined core.
# Both layers are along the local z-axis. Top is in positive y.
# 
#                       y
#                       |
#                       |
#                       |    
#             ---------------------
#             |\                 /|
#             | \---------------/ |
#             | | o  o  o  o  o | |
#             | |     (top)     | |
#  z ---------| |               | |  h
#             | |    (bottom)   | |
#             | | o     o     o | |
#             | /---------------\ |
#             |/                 \|
#             ---------------------
#                       b
#
# Formal arguments
#    id - tag for the section that is generated by this procedure
#    h - overall height of the section (see above)
#    b - overall width of the section (see above)
#    cover - thickness of the cover patches
#    coreID - material tag for the core patch
#    coverID - material tag for the cover patches
#    steelID - material tag for the reinforcing steel
#    numBars - number of reinforcing bars on any given side of the section
#    barArea - cross-sectional area of each reinforcing bar
#    nfCoreY - number of fibers in the core patch in the y direction
#    nfCoreZ - number of fibers in the core patch in the z direction
#    nfCoverY - number of fibers in the cover patches with long sides in the y direction
#    nfCoverZ - number of fibers in the cover patches with long sides in the z direction
#    MatlabOut - if non-zero then the routine sends output to an external file that can be
#                read by matlab to plot the section shape and elements (optional, default=0).
#
# Notes
#    The thickness of cover concrete is constant on all sides of the core.
#    The reinforcing bars are all the same size.
#    The number of fibers in the short direction of the cover patches is set to 1.
#
# Created 15/May/2009, Copyright (c) by D.Vamvatsikos
#          based on RCsection.tcl
# Updated 30/Oct/2012, added option for different bar diameters at the top and bottom of the section

proc RCBeamSection {id h b cover coreID coverID steelID nBartop nBarbot topbarArea botbarArea nfCoreY nfCoreZ nfCoverY nfCoverZ {MatlabOut 0}} {

   # The distance from the section z-axis to the edge of the cover concrete
   # in the positive y direction
   set coverY [expr $h/2.0]

   # The distance from the section y-axis to the edge of the cover concrete
   # in the positive z direction
   set coverZ [expr $b/2.0]

   # The negative values of the two above
   set ncoverY [expr -$coverY]
   set ncoverZ [expr -$coverZ]

   # Determine the corresponding values from the respective axes to the
   # edge of the core concrete
   set coreY [expr $coverY-$cover]
   set coreZ [expr $coverZ-$cover]
   set ncoreY [expr -$coreY]
   set ncoreZ [expr -$coreZ]

   # Define the fiber section
   section fiberSec $id {

	# Define the core patch
	patch quadr $coreID $nfCoreZ $nfCoreY $ncoreY $coreZ $ncoreY $ncoreZ $coreY $ncoreZ $coreY $coreZ
      
	# Define the four cover patches
	patch quadr $coverID 1 $nfCoverY $ncoverY $coverZ $ncoreY $coreZ $coreY $coreZ $coverY $coverZ
	patch quadr $coverID 1 $nfCoverY $ncoreY $ncoreZ $ncoverY $ncoverZ $coverY $ncoverZ $coreY $ncoreZ
	patch quadr $coverID $nfCoverZ 1 $ncoverY $coverZ $ncoverY $ncoverZ $ncoreY $ncoreZ $ncoreY $coreZ
	patch quadr $coverID $nfCoverZ 1 $coreY $coreZ $coreY $ncoreZ $coverY $ncoverZ $coverY $coverZ

	# Define the steel along constant values of y (in the z direction)
	# layer straight $matTag $numBars $areaBar $yStart $zStart $yEnd $zEnd
	layer straight $steelID $nBarbot $botbarArea $ncoreY $coreZ $ncoreY $ncoreZ
	layer straight $steelID $nBartop $topbarArea $coreY $coreZ $coreY $ncoreZ

   }
   if { $MatlabOut == 1 } {
      set matfile [open "RCBeamSectionfiberS$id.out" "w"]
      puts $matfile "FiberSection $id"
      puts $matfile "patch quadr $coreID $nfCoreZ $nfCoreY $ncoreY $coreZ $ncoreY $ncoreZ $coreY $ncoreZ $coreY $coreZ"
	   puts $matfile "patch quadr $coverID 1 $nfCoverY $ncoverY $coverZ $ncoreY $coreZ $coreY $coreZ $coverY $coverZ"
	   puts $matfile "patch quadr $coverID 1 $nfCoverY $ncoreY $ncoreZ $ncoverY $ncoverZ $coverY $ncoverZ $coreY $ncoreZ"
	   puts $matfile "patch quadr $coverID $nfCoverZ 1 $ncoverY $coverZ $ncoverY $ncoverZ $ncoreY $ncoreZ $ncoreY $coreZ"
	   puts $matfile "patch quadr $coverID $nfCoverZ 1 $coreY $coreZ $coreY $ncoreZ $coverY $ncoverZ $coverY $coverZ"
	   puts $matfile "layer straight $steelID $nBarbot $botbarArea $ncoreY $coreZ $ncoreY $ncoreZ"
	   puts $matfile "layer straight $steelID $nBartop $topbarArea $coreY $coreZ $coreY $ncoreZ"
	   close $matfile
    }

}
