# Define a procedure which generates a rectangular reinforced concrete section
# with one layer of steel distributed around the perimeter and a confined core.
# 
# BASED on RCsection.tcl, contained in openSEES website.
# 
#                   y
#                   |
#                   |
#         +-------------------+    
#         | o o o o o o o o o |    
#         | o    zBarArea   o |
#         | o               o |
#         | o               o |
#         | o               o |
#  z -----| o               o |     h
#         | o               o |
#         | o               o |
#         | o               o |
#         | o    zBarArea   o |
#         | o o o o o o o o o |
#         +-------------------+
#
#                   b
#
# Formal arguments
#    id - tag for the section that is generated by this procedure
#    h - overall height of the section (see above)
#    b - overall width of the section (see above)
#    cover - thickness of the cover patches
#    coreID - material tag for the core patch
#    coverID - material tag for the cover patches
#    steelID - material tag for the reinforcing steel
#    yonumBars - number of reinforcing bars on outer side of 
#                 y-parallel sides of the section (of length h)
#    zonumBars - number of reinforcing bars on outer side of 
#                 z-parallel sides of the section (of length b)
#    ybarArea - cross-sectional area of each reinforcing bar in y-direction (parallel to y-direction)
#    zbarArea - cross-sectional area of each reinforcing bar in z-direction
#    nfCoreY - number of fibers in the core patch in the y direction
#    nfCoreZ - number of fibers in the core patch in the z direction
#    nfCoverY - number of fibers in the cover patches with long sides in the y direction
#    nfCoverZ - number of fibers in the cover patches with long sides in the z direction
#    MatlabOut - if non-zero then the routine sends output to an external file that can be
#                read by matlab to plot the section shape and elements (optional, default=0).
#
# Notes
#    The thickness of cover concrete is constant on all sides of the core.
#    The number of bars is NOT the same on any given side of the section. Only on parallel sides
#    The reinforcing bars are not all the same size. They may differ in y vs z. Note that 
#       the corner position is always taken by bars along z-direction. The bars along y-direction
#       are placed always between the two corners along a length of [h - cover - 2 bar spacings].
#    The number of fibers in the short direction of the cover patches is set to 1.
#
# Created 22/Oct/2012 by D.Vamvatsikos
#
# 
proc RCsectionRect {id h b cover coreID coverID steelID yonumBars zonumBars ybarArea zbarArea nfCoreY nfCoreZ nfCoverY nfCoverZ {MatlabOut 0}} {

   # The distance from the section z-axis to the edge of the cover concrete
   # in the positive y direction
   set coverY [expr $h/2.0]

   # The distance from the section y-axis to the edge of the cover concrete
   # in the positive z direction
   set coverZ [expr $b/2.0]

   # The negative values of the two above
   set ncoverY [expr -$coverY]
   set ncoverZ [expr -$coverZ]

   # Determine the corresponding values from the respective axes to the
   # edge of the core concrete
   set coreY [expr $coverY-$cover]
   set coreZ [expr $coverZ-$cover]
   set ncoreY [expr -$coreY]
   set ncoreZ [expr -$coreZ]
   #set ilayerY [expr $coverY-$cover-$layerd]
   #set ilayerZ [expr $coverZ-$cover-$layerd]
   #set inlayerY [expr -$ilayerY]
   #set inlayerZ [expr -$ilayerZ]



   # Define the fiber section
   section fiberSec $id {

	# Define the core patch
	patch quadr $coreID $nfCoreZ $nfCoreY $ncoreY $coreZ $ncoreY $ncoreZ $coreY $ncoreZ $coreY $coreZ
      
	# Define the four cover patches
	patch quadr $coverID 1 $nfCoverY $ncoverY $coverZ $ncoreY $coreZ $coreY $coreZ $coverY $coverZ
	patch quadr $coverID 1 $nfCoverY $ncoreY $ncoreZ $ncoverY $ncoverZ $coverY $ncoverZ $coreY $ncoreZ
	patch quadr $coverID $nfCoverZ 1 $ncoverY $coverZ $ncoverY $ncoverZ $ncoreY $ncoreZ $ncoreY $coreZ
	patch quadr $coverID $nfCoverZ 1 $coreY $coreZ $coreY $ncoreZ $coverY $ncoverZ $coverY $coverZ

	# Define the OUTER steel layer along constant values of y (in the z direction)
	layer straight $steelID $zonumBars $zbarArea $ncoreY $coreZ $ncoreY $ncoreZ
	layer straight $steelID $zonumBars $zbarArea $coreY $coreZ $coreY $ncoreZ
        

	# Determine the spacing for the remaining bars in the y direction
	set spacingY [expr ($coreY-$ncoreY)/($yonumBars+1)]

	
	# Define remaining OUTER steel in the y direction
	layer straight $steelID $yonumBars $ybarArea [expr $coreY-$spacingY] $coreZ [expr $ncoreY+$spacingY] $coreZ
	layer straight $steelID $yonumBars $ybarArea [expr $coreY-$spacingY] $ncoreZ [expr $ncoreY+$spacingY] $ncoreZ
	
   }
   if { $MatlabOut == 1 } {
        set matfile [open "RCsectionRectfiberS$id.out" "w"]
        puts $matfile "FiberSection $id"
        puts $matfile "patch quadr $coreID $nfCoreZ $nfCoreY $ncoreY $coreZ $ncoreY $ncoreZ $coreY $ncoreZ $coreY $coreZ"
 
	puts $matfile "patch quadr $coverID 1 $nfCoverY $ncoverY $coverZ $ncoreY $coreZ $coreY $coreZ $coverY $coverZ"
	puts $matfile "patch quadr $coverID 1 $nfCoverY $ncoreY $ncoreZ $ncoverY $ncoverZ $coverY $ncoverZ $coreY $ncoreZ"
	puts $matfile "patch quadr $coverID $nfCoverZ 1 $ncoverY $coverZ $ncoverY $ncoverZ $ncoreY $ncoreZ $ncoreY $coreZ"
	puts $matfile "patch quadr $coverID $nfCoverZ 1 $coreY $coreZ $coreY $ncoreZ $coverY $ncoverZ $coverY $coverZ"

	puts $matfile "layer straight $steelID $zonumBars $zbarArea $ncoreY $coreZ $ncoreY $ncoreZ"
	puts $matfile "layer straight $steelID $zonumBars $zbarArea $coreY $coreZ $coreY $ncoreZ"
        
	puts $matfile "set spacingY [expr ($coreY-$ncoreY)/($yonumBars+1)]"

	puts $matfile "layer straight $steelID $yonumBars $ybarArea [expr $coreY-$spacingY] $coreZ [expr $ncoreY+$spacingY] $coreZ"
	puts $matfile "layer straight $steelID $yonumBars $ybarArea [expr $coreY-$spacingY] $ncoreZ [expr $ncoreY+$spacingY] $ncoreZ"
	close $matfile
    }

}
