# Define a Pinching4 material section
# Created/Modified by Dimitrios Vamvatsikos
#    uses the concepts developed by Luis Ibarra for properly weighting the hinges versus the elastic beam
#
# Updated 28/Oct/2008: Old version, was using a 6EI/L in file hyst_mat.tcl,
#         so this was meant for a beam with double curvature bending. New version requests a direct
#         input of "n=nstiff". This is meant to be used from inside bhinge_Pinching4.tcl
#         I have also removed inputs "bay" and "secID" which are no longer used.
# Updated 18/Nov/2008: Took the hysteretic-material version and turned it into a Pinching4 one!
# Updated 03/Apr/2013: Included a fix for estimating mu in the spring when it falls before mc or mr.
# Updated 19/May/2013: Updated the above fix by using initial values (ah0,mu0, etc in finding Rfu 
#         about line 57. Also added option "debugout" for outputting old and new ah,ac... values.
#         Default is no output on the screen.
#
#======================================
# matID : ID of the material to be created
# fy    : moment input (negative if the law is not symmetric)
# ratio : positive to negative moment ratio. If ratio = 1 then the law is symmetric for positive and 
#         negative moment
# Young : Young's modulus
# In    : The stiffness of the beam or column (i.e. around the axis that represents Moment for this hinge)
# Wpl   : dummy value: M=Wpl*fy
# fcr   : Parameter that controls what percentage of Mp is the M_cr ->> M_cr= fcr*Mp, say M_cr=0.3*Mp
# thp   : Plastic (yield) rotation for negative moment
# mcr0  : _cr/_p ratio for negative moment
# thpn   : Plastic (yield) rotation for positive moment
# mcrn0  : _cr/_p ratio for positive moment
# ah0	: hardening ratio (% of initial section flex. stiffness)
# mc0	: (theta capping)/(theta yield) for negative moment
# ac0	: caping slope (% of initial section flex. stiffness)
# R		: residual plateau (% Myield)
# mu0	: ultimate ductilty (x yielding curvature) for negative moment
# mc1	: (theta capping)/(theta yield) for positive moment
# mu1	: ultimate ductilty (x yielding curvature) for positive moment
# debugout: If 1, then print on the screen all the old and new values for the spring parameters.

#
# NOTE: p is (well not exactly) the reciprocal of Luis' weight "n" between the hinges and the elastic beam
#       In general, the lower "p" is, the more jagged the appearance of the post-yield part of the pushover becomes 
#       and convergence becomes much harder to achieve. 

proc Pinching4_hinge {matID fy ratio Young In Wpl fcr thp mcr0 thpn mcrn0 ah0 mc0 ac0 R mu0 mc1 mu1 n damagepars eletag {debugout 1}} {


# negative moment 

set ah  [expr $ah0/($n+1-$n*$ah0)]; 
set ac  [expr $ac0/($n+1-$n*$ac0)]

set mc  [expr ($mc0-1.0)*(1.0-$ah0)*$n+$mc0]

# Auxiliary values to help with mu. 
set mr0 [expr $mc0 + (1.+($mc0-1.)*$ah0-$R)/(-$ac0)]
set mr  [expr $mc + (1.+($mc-1.)*$ah-$R)/(-$ac)]

if {$mr0<=$mu0} {
  # OLD: IT does not work well if mu0<mr0  (an earlier cut-off).
  set mu  [expr $mr + ($mu0-$mr0)*$n]
} elseif {$mc0<=$mu0} {
  # The value of force where the cut-off happens
  set Rfu [expr 1.+($mc0-1.)*$ah0 + $ac0*($mu0-$mc0)]
  # corresponding ductility considering the analogy (may not be perfect)
  set mu  [expr $mc + (1.+($mc-1.)*$ah-$Rfu)/(-$ac)]
} else {
  # NEWER Version: Works on the same principle as finding mc.
  set mu  [expr ($mu0-1)*(1.0-$ah0)*$n+$mu0]	
}


set Mpl   [expr $fy*$Wpl]
set kbeam [expr $Young*$In]
set kh    [expr $ah*$kbeam]
set kc    [expr $ac*$kbeam]

set myield [expr $Mpl/$kbeam]

# ~~~~~~~~~~ including initial crack ~~~~~~~~
set xa [expr $mcr0*$thp]
set ya [expr $fcr*$Mpl]

set xb $thp
set yb $Mpl

set xc [expr $mc*$xb]
set yc [expr $yb+$kh*($mc-1.)*$xb]

set yd [expr $R*$yb]
set xd [expr $xc+($yd-$yc)/$kc]

set maxd [expr $mu*$thp]

# ~~~~~~~~~~  end ~~~~~~~~~~


#~~~~ MOD FOR POSITIVE MOMENT~~~~
#if ratio=M+/M- equals 1, then cross section behaviour is symmetric.
if {$ratio==1.} {
    #set cmd "uniaxialMaterial Pinching4 [expr $matID+1000]        $ya         $xa         $yb        $xb         $yc         $xc  [expr 1.0001*$yc] [expr  1.01*$xc]\
    #                                          [expr -$ya] [expr -$xa] [expr -$yb] [expr -$xb] [expr -$yc] [expr -$xc] [expr       -1.0001*$yc] [expr -1.01*$xc]\
	#				      $damagepars"
    set cmd "uniaxialMaterial Pinching4 [expr $matID+1000]        $ya         $xa         $yb        $xb         $yc         $xc  $yd $xd\
                                              [expr -$ya] [expr -$xa] [expr -$yb] [expr -$xb] [expr -$yc] [expr -$xc] [expr       -$yd] [expr -$xd]\
					      $damagepars"
    eval $cmd
    #uniaxialMaterial MinMax matTag? otherMatTag? -min minStrain? -max maxStrain?
    uniaxialMaterial MinMax $matID [expr $matID+1000] -min [expr -$maxd] -max [expr $maxd]
	#puts "Column"
		set matfile [open "Mcapacity[expr $matID+1000].out" "w"]
		puts $matfile "[expr -$yb] [expr -$yc] $yb $yc"
		close $matfile




	} else {
	
	# positive moment
	set ahp  [expr $ah0/($n+1-$n*$ah0)]; 
	set acp  [expr $ac0/($n+1-$n*$ac0)]

	set mcp [expr ($mc1-1.0)*(1.0-$ah0)*$n+$mc1]
	
    # Auxiliary values to help with mu. 
	set mr1 [expr $mc1 + (1.+($mc1-1.)*$ah0-$R)/(-$ac0)]
	set mrp  [expr $mcp + (1.+($mcp-1.)*$ahp-$R)/(-$acp)]
	
	if {$mr1<=$mu1} {
	  # OLD: IT does not work well if mu0<mr0  (an earlier cut-off).
	  set mup  [expr $mrp + ($mu1-$mr1)*$n]
	} elseif {$mc1<=$mu1} {
	  # The value of force where the cut-off happens
	  set Rfu1 [expr 1.+($mc1-1.)*$ah0 + $ac0*($mu1-$mc1)]
	  # corresponding ductility considering the analogy (may not be perfect)
	  set mup  [expr $mcp + (1.+($mcp-1.)*$ahp-$Rfu1)/(-$acp)]
	} else {
	  # NEWER Version: Works on the same principle as finding mc.
	  set mup  [expr ($mu1-1)*(1.0-$ah0)*$n+$mu1]	
	}
	
	set Mplp   [expr $ratio*$fy*$Wpl] ; #positive moment
	set khp    [expr $ahp*$kbeam]
	set kcp    [expr $acp*$kbeam]

	set myieldp [expr $Mplp/$kbeam]
	
	# ~~~~~~~~~~ including initial crack ~~~~~~~~
	set xap [expr $mcrn0*$thpn]; 
	set yap [expr $fcr*$Mplp]

	set xbp $thpn
	set ybp $Mplp

	set xcp [expr $mcp*$xbp]
	set ycp [expr $ybp+$khp*($mcp-1.)*$xbp]

	set ydp [expr $R*$ybp]
	set xdp [expr $xcp+($ydp-$ycp)/$kcp]

	set maxdp [expr $mup*$thpn]

	# ~~~~~~~~~~  end ~~~~~~~~~~

				  
   	set cmd "uniaxialMaterial Pinching4 [expr $matID+1000]        $yap         $xap         $ybp         $xbp         $ycp         $xcp  $ydp     $xdp\
                                              [expr -$ya] [expr -$xa] [expr -$yb] [expr -$xb] [expr -$yc] [expr -$xc] [expr       -$yd] [expr -$xd]\
					      $damagepars"
	eval $cmd
	#uniaxialMaterial MinMax matTag? otherMatTag? -min minStrain? -max maxStrain?
	uniaxialMaterial MinMax $matID [expr $matID+1000] -min [expr -$maxd] -max [expr $maxdp]
	puts "xd = $xd, xdp=$xdp, xcp=$xcp, xc=$xc"
	set matfile [open "Mcapacity[expr $matID+1000].out" "w"]
	puts $matfile "[expr -$yb] [expr -$yc] $ybp $ycp"
	close $matfile




	
}


}