function PerformanceAssessment_MRF4Story(basicdir,designcase,AnalysisType,...
                   LabelSize,FigureFontSize,MarkerSize)
% PerformanceAssessment_MRF4Story(basicdir,AnalysisType,...
%                    LabelSize,FigureFontSize,MarkerSize)
% -------------------------------------------------------------------------
% Loads the IDA results and performs the checks of Chapter 19 (for single
% & double stripe analysis: FDrpo < FC and for MAF estimate:
% MAFdemand < MAFcapacity. The results and the figures are stored in the
% ResultsPath folder. The selected Intensity Measure is Sa(T1)
% -------------------------------------------------------------------------
% INPUT
% basicdir:       directory where PerformanceAssessment_MRF4Story.m file
%                 is stored    
% designcase:     Options:
%                 'A' or 'a'    for the-story MRF designed using method A 
%                               (book's example 1)
%                 'B' or 'b'    for the-story MRF designed using method B 
%                               (book's example 2)
%                 'C' or 'c'    for the-story MRF designed using method C 
%                               (book's example 3)
% AnalysisType:   Analysis type:  'single' for single stripe analysis
%                                 'double' for double stripe analysis
%                                 'MAFestimation' to estimate the mean 
%                                 annual frequency (MAF) of exceeding the
%                                 performance objective (PO)
% LabelSize:      size of x and y axes labels of figures
% FigureFontSize: size of fonts in figures
% MarkerSize:     size of the markers plot on IDA curves (default 10)
% -------------------------------------------------------------------------
% OUTPUT
% none but saves many files in the ...\Examples_1_2_3\Results\ExampleXXX\PerformanceAssessmentResults
% path
% -------------------------------------------------------------------------
% EXAMPLE
% % Double stripe analysis on Akrivi's PC
% basicdir='C:\Users\superuser\Examples_1_2_3';
% PerformanceAssessment_MRF4Story(basicdir,'double')
% % Single stripe analysis on Akrivi's PC
% basicdir='C:\Users\superuser\Examples_1_2_3';
% PerformanceAssessment_MRF4Story(basicdir,'single')
% % Single stripe analysis on Akrivi's PC with smaller font & marker sizes
% basicdir='C:\Users\superuser\Examples_1_2_3';
% PerformanceAssessment_MRF4Story(basicdir,'single',16,16,8)

% _________________________________________________________________________
% Created 08/07/2019 by A. Chatzidaki & D. Vamvatsikos



if nargin<6, MarkerSize=10; end
if nargin<5, FigureFontSize=18; end
if nargin<4, LabelSize=22; end
if nargin<3, error('Need at least two arguments'); end




% ****************** setting the parameters ******************

% change the '\' to '/' (if any exists)
basicdir=regexprep(basicdir,'\','/');
cd(basicdir)

% add the path where the functions are stored
addpath([basicdir,'/More']);

% For double stripe analysis, the second stripe is at IMdoubleFactor*
% IMlevel level, where IM level is the IM of the first stripe. 
IMdoubleFactor=1.10;

% convert the design case to the example number. Useful
% for reading the correct IDA file and storing the results in the correct folder
if strcmpi(designcase,'A')==1;
	exampleno=1;
elseif strcmpi(designcase,'B')==1;
	exampleno=2;
elseif strcmpi(designcase,'C')==1;
	exampleno=3;
end


% Set the path where the Results will be stored 
% ResultsPath = path where the figures and the results will be stored
ResultsPath=[basicdir,'/Results/Example',num2str(exampleno),'/PerformanceAssessmentResults'];
% create the ResultsPath directory if it does not already exist
if ~exist(ResultsPath, 'dir'); mkdir(ResultsPath);  end

% Load the .sida.mat file with the IDA results
% IDAresultsPath = path where IDA results are stored
IDAresultsPath=[basicdir,'/IDAresults'];
% IDAFileName = Name of IDA results file
IDAFileName=['Mark4StoryExample',num2str(exampleno),'.sida.mat'];
% load the file
load(fullfile(IDAresultsPath,IDAFileName));

% read the number of records used in the IDA analysis
Nrecs=length(thfilename);


% name of the seismic hazard curve that is used in the analysis. Default is San Jose, California
SeismicHazardName='SanJose.hz.mat';

% define the limit of each PO
if strcmpi(designcase,'c')==1
	% maximum Interstory drift ratio (IDR) limit
	IDRlimit=0.02;
	% column DCR limit
	columnDCRlimit=1.0;
	% beam DCR limit
	beamDCRlimit=1.0;
	% ductility limit (ductility is checked using Roof Drift Ratio -RDR- as the
	% Engineering Demand Parameters in IDA)
	RDRlimit=3.52*1.5/648;
	% collapse limit: collapse is deemed to occur when a large IDR value of
	% 0.08 is exceeded
	collapselimit=0.08;
	
	
	% Define confidence level for each PO
	% confidence level for theta max limit (maximum IDR)
	confIDR=0.70;
	% confidence level for column DCR
	confDCRcolumns=0.75;
	% confidence level for beam DCR
	confDCRbeams=0.75;
	% confidence level for ductility check
	confRDR=0.70;
	% confidence level for collapse PO
	confCollapse=0.90;
	
	% set the MAF limit for the Performance Objectives to be checked. We have
	% two limits: one of 10% probability of exceedance in 50ys and the other of
	% 1% probability of exceedance in 50 yrs
	% Following a poissonian assumption, the Mean Annual Frequency (lambda) of
	% exceeding a PO is given by:
	% P = 1-exp(-lambda*t) -> lambda = -ln(1-P)/t.
	% where P is the probability of exceeding the PO in t years
	% Be careful since in matlab ln is calculated using log function
	MAFCapacityIDR=-log(1-0.10)/50;
	MAFCapacityColumnDCR=-log(1-0.10)/50;
	MAFCapacityBeamDCR=-log(1-0.10)/50;
	MAFCapacityRDR=0.0139; % 50%/50yr
	MAFCapacityCollapse=-log(1-0.01)/50;
	
	
elseif strcmpi(designcase,'a')==1
	% maximum Interstory drift ratio (IDR) limit
	IDRlimit=0.02;
	% column DCR limit
	columnDCRlimit=1.0;
	% beam DCR limit
	beamDCRlimit=1.0;
	% ductility limit (ductility is checked using Roof Drift Ratio -RDR- as the
	% Engineering Demand Parameters in IDA)
	RDRlimit=3.6*4.01/648;
	
	% Define confidence level for each PO
	% confidence level for theta max limit (maximum IDR)
	confIDR=0.50;
	% confidence level for column DCR
	confDCRcolumns=0.60;
	% confidence level for beam DCR
	confDCRbeams=0.60;
	% confidence level for ductility check
	confRDR=0.50;
	
	% set the MAF limit for the Performance Objectives to be checked
	MAFCapacityIDR=-log(1-0.10)/50;
	MAFCapacityColumnDCR=-log(1-0.10)/50;
	MAFCapacityBeamDCR=-log(1-0.10)/50;
	MAFCapacityRDR=-log(1-0.02)/50; % 2%/50yr
	
elseif strcmpi(designcase,'b')==1
	% maximum Interstory drift ratio (IDR) limit
	IDRlimit=0.02;
	% column DCR limit
	columnDCRlimit=1.0;
	% beam DCR limit
	beamDCRlimit=1.0;
	
	% Define confidence level for each PO
	% confidence level for theta max limit (maximum IDR)
	confIDR=0.68;
	% confidence level for column DCR
	confDCRcolumns=0.75;
	% confidence level for beam DCR
	confDCRbeams=0.75;
	
	% set the MAF limit for the Performance Objectives to be checked
	MAFCapacityIDR=-log(1-0.10)/50;
	MAFCapacityColumnDCR=-log(1-0.10)/50;
	MAFCapacityBeamDCR=-log(1-0.10)/50;
else
	error('only designcase a, b or c are currently available')
end


if or(strcmpi(AnalysisType,'single')==1,strcmpi(AnalysisType,'double')==1)
	% define the additional uncertainty to be employed for the demand capacity
	% factored design (DCFD)
	betacapacity=0.20;
	% Define the records whose results will be used for the stripe analysis
	% The following records were randomly selected.
	RecordsSaT1=[1,3,5,9,11,13,15,17,19,21,22,33,34,38,40,42,44]; % 17 records
    % records of the second stripe
	RecordsSaT1Double=RecordsSaT1;% the same records used for both stripes
    % Create a folder to store the results      
    ResultsPath=[ResultsPath,'/',AnalysisType,'stripe'];
    if ~exist(ResultsPath, 'dir'); mkdir(ResultsPath);  end
	
	
elseif strcmpi(AnalysisType,'MAFestimation')==1
	% An approximately equivalent dispersion in intensity measure (IM) terms of
	% 0.25 is instead adopted for the mean annual frequency (MAF) format
	bepist=0.25;	
	SSF=1.35; % spectral as per FEMA P695 (see page 509)
	
	% create inside the ResultsPath a folder where the IDA results will be
	% stored, named MAFestimation
    if ~exist([ResultsPath,'/MAFestimation'], 'dir'); mkdir(ResultsPath,'/MAFestimation');  end

end

if strcmpi(designcase,'c')==1
	% set the Sa(T1) from Code Design Spectrum 
	Sa_T1=0.75651025866;
elseif strcmpi(designcase,'a')==1
	Sa_T1=0.5718229309744;
elseif strcmpi(designcase,'b')==1
	Sa_T1 = 0.6181264179315;
else
	error('available options for the design case are a, b or c')
	
end


% ------- IDA process parameters (start) --------------------
truncate_dvalue=[]; % no truncation needed. It finds flatline on its own!

relaxNaNs=1; % Allow removal of "single" intermediate NaNs!
% line styles to use for plotting
linestyles={'k-','k-','k-','k-'};
% drift above which all drift values are considered infinite (collapse occurs)
% helps with fitting! Try setting it to 100 to see the difference with some badly
% behaved sets!
infdr=0.4;
% fractiles
qs=[0.16,0.50,0.84]';
% ------- IDA process parameters (end) --------------------



% define the colors for plotting  points on IDAs
% first stripe: light grey
Stripe1Color=[0.68,0.67,0.67];
% second stripe: dark grey
Stripe2Color=[0.46,0.44,0.44];
% MAF estimation: light grey
PointColor=[0.68,0.67,0.67];


% FigNumbering = figure numbering starts from this value. Finds active
% figures and starts plotting in the next figure. This is done to avoid
% plotting one figure on the top of the other. If you want to start plotting
% from a certain figure number you should change the FigNumbering
h =  findobj('type','figure');
FigNumbering = length(h)+1;

% ****************** setting the parameters (end) ******************

% load the seismic hazard curve
hz=load(SeismicHazardName);

%%

% To offer a fair assessment, the hazard curve of Example 3 is unscaled 
if strcmpi(designcase,'C')==1; 
	sf=1; 
else
	% find the scale factor of the hazard curve: we want to scale the Hazard
	% curve so that for 10%/50yr (which is equivalent to a MAF of 0.0021) the Sa
	% value will be the same as the one obtained from code.
	[sf]=findSfHazardCurve(T_periods(1,1),0.0021,Sa_T1,hz,'interplinear',1,LabelSize,...
		FigureFontSize,MarkerSize);
end


%% MAX IDR
disp(['PO: IDR of ',num2str(IDRlimit)])
% define the IM level of the 1st stripe
IMlevel=Sa_T1;

% get the IDA results (IDRval) for the 1st stripe. Note that we keep the
% tsv values where individual IDR IDAs are truncated to force IDAs
% of the other EDPs to truncate at the same IM level 
Nvals={IMlevel,IDRlimit};
[cv,cvsa,sa_range,IDRval,qdr,savalIDR,dr_range,qSa,lowest_C,tdv,tsv,tdvaluesIDR,tsvaluesIDR]=...
	postIDA_simpleprocessIDA(svalues,dvalues,Nvals,qs,infdr,[],truncate_dvalue,relaxNaNs);
plot_cv_IDAs(tsvaluesIDR,tdvaluesIDR,cv,lowest_C,[0,0.08],FigNumbering+1,linestyles,'',0,1,1.5)
set(gcf,'color','white'); box on; set(gca,'fontsize',FigureFontSize); grid on
ylabel({'first-mode spectral acceleration';'S_a(T_1,5%) (g)'},'fontsize',LabelSize);
xlabel('maximum interstory drift ratio, \theta^{ }_{max}','fontsize',LabelSize);


if strcmpi(AnalysisType,'single')==1;
	% plot the results of the 1st stripe for the selected records on the top of
	% IDA curves
	hold on
	plot(IDRval(RecordsSaT1),IMlevel*ones(1,length(RecordsSaT1)),'o','MarkerFaceColor',Stripe1Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize); 
	saveas(gca,fullfile(ResultsPath,['IDR_',AnalysisType,'_stripe_IDAs.fig']));

	% get the EDP values for the first stripe from IDA results
	EDPval={IDRval(RecordsSaT1)};

	[ IDRResults.FDrpo,IDRResults.FC]=CheckPOs_StripeAnalysis( AnalysisType,IDRlimit,EDPval,IMlevel,confIDR,betacapacity,sf,T_periods(1,1),hz,1,[]);
	display(IDRResults)
	saveas(gca,fullfile(ResultsPath,['IDR_',AnalysisType,'_stripe_HC.fig']));
	save(fullfile(ResultsPath,['IDR_',AnalysisType,'_stripe_Results.mat']),'IDRResults')
elseif strcmpi(AnalysisType,'double')==1;
	% plot the results of the 1st stripe for the selected records on the top of
	% IDA curves
	hold on
	plot(IDRval(RecordsSaT1),IMlevel*ones(1,length(RecordsSaT1)),'o','MarkerFaceColor',Stripe1Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
	% set the records of the 2nd stripe that are the same as the ones used for the 1st stripe
	RecordsSaT1Double=RecordsSaT1;
	% define the IM level of the 2nd stripe
	SaDouble=IMdoubleFactor*IMlevel;
	% get the results for the 2nd stripe
	NvalsDouble={SaDouble,[]};
	[~,~,~,IDRval2,~,~,~,~,~,~,~,~,~]=...
		postIDA_simpleprocessIDA(svalues,dvalues,NvalsDouble,qs,infdr,[],tsv,relaxNaNs);
	hold on
	% plot the second stripe 
	plot(IDRval2(RecordsSaT1Double),SaDouble*ones(1,length(RecordsSaT1Double)),'o','MarkerFaceColor',Stripe2Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize)
	saveas(gca,fullfile(ResultsPath,['IDR_',AnalysisType,'_stripe_IDAs.fig']));
	% define the IM levels of the two stripes
	IMlevel2=[IMlevel,SaDouble];
	% define the cell with the EDP values for both stripes
	EDPval={IDRval(RecordsSaT1);IDRval2(RecordsSaT1Double)};
	[ IDRResults.FDrpoIDRDouble,IDRResults.FCrIDRDouble ]=CheckPOs_StripeAnalysis( AnalysisType,IDRlimit,EDPval,IMlevel2,confIDR,betacapacity,sf,T_periods(1,1),hz,1,[]);
	display(IDRResults)
	saveas(gca,fullfile(ResultsPath,['IDR_',AnalysisType,'_stripe_HC.fig']));
	save(fullfile(ResultsPath,['IDR_',AnalysisType,'_stripe_Results.mat']),'IDRResults')
elseif strcmpi(AnalysisType,'MAFestimation')==1;
	% plot IDA results 
	hold on
	plot(IDRlimit*ones(1,Nrecs),savalIDR,'o','MarkerFaceColor',PointColor,'MarkerEdgeColor','k','MarkerSize',MarkerSize); 

	% calculate the dispersion (i.e. log standard deviation of the data)
	betaIDR=std(log(sort(savalIDR)));
	% calculate the median IM
	medianIDR=median((sort(savalIDR)));
	[IDRMAF.lambdaXIDR,IDRMAF.lambda50IDR,IDRMAF.lambdamIDR]=CheckMAF(confIDR,medianIDR,betaIDR,T_periods(1,1),1,sf,MAFCapacityIDR,bepist);
% 	display(IDRMAF)
% 	display(MAFCapacityIDR)
	saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['IDR_',AnalysisType,'_IDAs.fig']));
	saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['IDR_',AnalysisType,'_IDAs.png']));
	save(fullfile([ResultsPath,'/MAFestimation'],['IDR_',AnalysisType,'_Results.mat']),'IDRMAF')
end




%% Column Demand Capacity Ratio (DCR) 
disp(['PO: Column DCR = ',num2str(columnDCRlimit)])

DCRcolumns={anslout.ColumnDCR};
	


Nvals={IMlevel,columnDCRlimit};

% note the "tsv" defined herein in the postIDA_simpleprocessIDA function,
% which is the output of the corresponding post-processing function of 
% the maximum interstory drift ratio. What we do is to get the IM values
% where each IDA is truncated and force the IDAs for a different EDP to
% be truncated at the same IM levels.
% Check that we use 5.0 as the limit where the IDAs of column DCR are
% truncated. Change it to see the difference in the spline fitting
[cvColumnDCR,cvsa,sa_rangeColumnDCR,DCRColumn1,qdr,savalColumnDCR,dr_range,qSa,lowest_CColumnDCR,tdv,~,tdvaluesColumnDCR,tsvaluesColumnDCR]=...
	postIDA_simpleprocessIDA(svalues,DCRcolumns,Nvals,qs,5.0,[],tsv,relaxNaNs);
plot_cv_IDAs(tsvaluesColumnDCR,tdvaluesColumnDCR,cvColumnDCR,lowest_CColumnDCR,[-0.004,1.5],FigNumbering+7,linestyles,'',0,1,1.5)
set(gcf,'color','white'); box on; set(gca,'fontsize',FigureFontSize); grid on
ylabel({'first-mode spectral acceleration';'S_a(T_{1},5%) (g)'},'fontsize',LabelSize);
xlabel('maximum column DCR = \theta_{demand}^{pl}/\theta_{capacity}^{pl}','fontsize',LabelSize);


if strcmpi(AnalysisType,'single')==1;
	IMlevel=Sa_T1;
	hold on;
	plot(DCRColumn1(RecordsSaT1),IMlevel*ones(1,length(RecordsSaT1)),'o','MarkerFaceColor',Stripe1Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
	saveas(gca,fullfile(ResultsPath,['ColumnDCR_',AnalysisType,'_stripe_IDAs.fig']));	
	EDPval={DCRColumn1(RecordsSaT1)};
	[ ColumnDCRResults.FDrpoDuctSingle,ColumnDCRResults.FCrDuctSingle ]=CheckPOs_StripeAnalysis( AnalysisType,columnDCRlimit,EDPval,IMlevel,confDCRcolumns,betacapacity,sf,T_periods(1,1),hz,1,[]);
	display(ColumnDCRResults)
	saveas(gca,fullfile(ResultsPath,['ColumnDCRResults_',AnalysisType,'_stripe_HC.fig']));	
	save(fullfile(ResultsPath,['ColumnDCRResults_',AnalysisType,'_stripe_Results.mat']),'ColumnDCRResults');
elseif strcmpi(AnalysisType,'double')==1;
	hold on;
	plot(DCRColumn1(RecordsSaT1Double),IMlevel*ones(1,length(RecordsSaT1Double)),'o','MarkerFaceColor',Stripe1Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
	saveas(gca,fullfile(ResultsPath,['ColumnDCR_',AnalysisType,'_stripe_IDAs.fig']));	
	SaDouble=IMdoubleFactor*IMlevel;
	NvalsDouble={SaDouble,[]};
	[~,~,~,DCRColumn2,~,~,~,~,~,~,~,~,~]=postIDA_simpleprocessIDA(svalues,DCRcolumns,NvalsDouble,qs,5.0,[],tsv,relaxNaNs);
	hold on
	plot(DCRColumn2(RecordsSaT1Double),SaDouble*ones(1,length(RecordsSaT1Double)),'o','MarkerFaceColor',Stripe2Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize)
	saveas(gca,fullfile(ResultsPath,['ColumnDCR_',AnalysisType,'_stripe_IDAs.fig']));
	IMlevel2=[IMlevel,SaDouble];
	EDPval={DCRColumn1(RecordsSaT1);DCRColumn2(RecordsSaT1Double)};
	[ ColumnDCRResults.FDrpoDuctDouble ,ColumnDCRResults.FCrDuctDouble]=CheckPOs_StripeAnalysis( AnalysisType,columnDCRlimit,EDPval,IMlevel2,confDCRcolumns,betacapacity,sf,T_periods(1,1),hz,1,[]);
	display(ColumnDCRResults)
	saveas(gca,fullfile(ResultsPath,['ColumnDCRResults_',AnalysisType,'_stripe_HC.fig']));
	save(fullfile(ResultsPath,['ColumnDCRResults_',AnalysisType,'_stripe_Results.mat']),'ColumnDCRResults')
elseif strcmpi(AnalysisType,'MAFestimation')==1;
	% plot IDA results 
	hold on
	plot(columnDCRlimit*ones(1,Nrecs),savalColumnDCR,'o','MarkerFaceColor',PointColor,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
	betaColumnDCR=std(log(sort(savalColumnDCR)));
	medianColumnDCR=median((sort(savalColumnDCR)));
	[ColumnDCRResults.lambdaXIDR,ColumnDCRResults.lambda50IDR,ColumnDCR.lambdamIDR]=CheckMAF(confDCRcolumns,medianColumnDCR,betaColumnDCR,T_periods(1,1),1,sf,MAFCapacityColumnDCR,bepist);
% 	display(ColumnDCRResults)
% 	display(MAFCapacityColumnDCR)
	saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['ColumnDCRResults_',AnalysisType,'_IDAs.fig']));
	saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['ColumnDCRResults_',AnalysisType,'_IDAs.png']));
	save(fullfile([ResultsPath,'/MAFestimation'],['ColumnDCRResults_',AnalysisType,'_Results.mat']),'ColumnDCRResults');
end


%% Beam Demand Capacity Ratio (DCR) 
disp(['PO: Beam DCR = ',num2str(beamDCRlimit)])

DCRbeams={anslout.BeamDCR};
	


Nvals={IMlevel,beamDCRlimit};

% note the "tsv" defined herein in the postIDA_simpleprocessIDA function,
% which is the output of the corresponding function of post-processing
% the maximum interstory drift ratio. What we do is to get the IM values
% where each IDA is truncated and force the IDAs for a different EDP to
% be truncated at the same IM values.
% Check that we use 5.0 as the limit where the IDAs of beam DCR are
% truncated. Change it to see the difference in the spline fitting
[cvBeamDCR,cvsa,sa_rangeBeamDCR,DCRBeam1,qdr,savalBeamDCR,dr_range,qSa,lowest_CBeamDCR,tdv,~,tdvaluesBeamDCR,tsvaluesBeamDCR]=...
	postIDA_simpleprocessIDA(svalues,DCRbeams,Nvals,qs,5.0,[],tsv,relaxNaNs);
plot_cv_IDAs(tsvaluesBeamDCR,tdvaluesBeamDCR,cvBeamDCR,lowest_CBeamDCR,[-0.004,1.5],FigNumbering+7,linestyles,'',0,1,1.5)
set(gcf,'color','white'); box on; set(gca,'fontsize',FigureFontSize); grid on
ylabel({'first-mode spectral acceleration';'S_a(T_{1},5%) (g)'},'fontsize',LabelSize);
xlabel('maximum beam DCR = \theta_{demand}^{pl}/\theta_{capacity}^{pl}','fontsize',LabelSize);


if strcmpi(AnalysisType,'single')==1;
	IMlevel=Sa_T1;
	hold on;
	plot(DCRBeam1(RecordsSaT1),IMlevel*ones(1,length(RecordsSaT1)),'o','MarkerFaceColor',Stripe1Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
	saveas(gca,fullfile(ResultsPath,['BeamDCRResults_',AnalysisType,'_stripe_IDAs.fig']));	
	EDPval={DCRBeam1(RecordsSaT1)};
	if sum(isnan(EDPval{1,1}))>0; 
		statisticsflag=2; 
	else
		statisticsflag=1; 
	end
	[ BeamDCRResults.FDrpoDuctSingle,BeamDCRResults.FCrDuctSingle ]=CheckPOs_StripeAnalysis( AnalysisType,beamDCRlimit,EDPval,IMlevel,confDCRbeams,betacapacity,sf,T_periods(1,1),hz,statisticsflag,[]);
	display(BeamDCRResults)
	saveas(gca,fullfile(ResultsPath,['BeamDCRResults_',AnalysisType,'_stripe_HC.fig']));	
	save(fullfile(ResultsPath,['BeamDCRResults_',AnalysisType,'_stripe_Results.mat']),'BeamDCRResults');
elseif strcmpi(AnalysisType,'double')==1;
	hold on;
	plot(DCRBeam1(RecordsSaT1Double),IMlevel*ones(1,length(RecordsSaT1Double)),'o','MarkerFaceColor',Stripe1Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
	saveas(gca,fullfile(ResultsPath,['BeamDCRResults_',AnalysisType,'_stripe_IDAs.fig']));	
	SaDouble=IMdoubleFactor*IMlevel;
	NvalsDouble={SaDouble,[]};
	[~,~,~,DCRBeam2,~,~,~,~,~,~,~,~,~]=postIDA_simpleprocessIDA(svalues,DCRbeams,NvalsDouble,qs,5.0,[],tsv,relaxNaNs);
	hold on
	plot(DCRBeam2(RecordsSaT1Double),SaDouble*ones(1,length(RecordsSaT1Double)),'o','MarkerFaceColor',Stripe2Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize)
	saveas(gca,fullfile(ResultsPath,['BeamDCRResults_',AnalysisType,'_stripe_IDAs.fig']));
	IMlevel2=[IMlevel,SaDouble];
	EDPval={DCRBeam1(RecordsSaT1);DCRBeam2(RecordsSaT1Double)};
	if or(strcmpi(designcase,'c')==1, strcmpi(designcase,'b')==1)
		[ BeamDCRResults.FDrpoDuctDouble ,BeamDCRResults.FCrDuctDouble]=CheckPOs_StripeAnalysis( AnalysisType,beamDCRlimit,EDPval,IMlevel2,confDCRbeams,betacapacity,sf,T_periods(1,1),hz,1,[]);
	else
		[ BeamDCRResults.FDrpoDuctDouble ,BeamDCRResults.FCrDuctDouble]=CheckPOs_StripeAnalysis( AnalysisType,beamDCRlimit,EDPval,IMlevel2,confDCRbeams,betacapacity,sf,T_periods(1,1),hz,2,[]);
	end
	display(BeamDCRResults)
	saveas(gca,fullfile(ResultsPath,['BeamDCRResults_',AnalysisType,'_stripe_HC.fig']));
	save(fullfile(ResultsPath,['BeamDCRResults_',AnalysisType,'_stripe_Results.mat']),'BeamDCRResults')
elseif strcmpi(AnalysisType,'MAFestimation')==1;
	% plot IDA results 
	hold on
	plot(beamDCRlimit*ones(1,Nrecs),savalBeamDCR,'o','MarkerFaceColor',PointColor,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
	betaBeamDCR=std(log(sort(savalBeamDCR)));
	medianBeamDCR=median((sort(savalBeamDCR)));
	[BeamDCRResults.lambdaXIDR,BeamDCRResults.lambda50IDR,BeamDCR.lambdamIDR]=CheckMAF(confDCRbeams,medianBeamDCR,betaBeamDCR,T_periods(1,1),1,sf,MAFCapacityBeamDCR,bepist);
% 	display(BeamDCRResults)
% 	display(MAFCapacityBeamDCR)
	saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['BeamDCRResults_',AnalysisType,'_IDAs.fig']));
	saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['BeamDCRResults_',AnalysisType,'_IDAs.png']));
	save(fullfile([ResultsPath,'/MAFestimation'],['BeamDCRResults_',AnalysisType,'_Results.mat']),'BeamDCRResults');
end

%% Ductility limit: only for design A and C
if or(strcmpi(designcase,'a')==1, strcmpi(designcase,'c')==1)
	disp(['PO: Ductility limit of = ',num2str(RDRlimit)])
	
	if strcmpi(designcase,'a')==1
		% for this example linear interpolation performed to compute the IM
		% from the scaled hazard curve. The difference is minor and of no
		% great importance 
		[ IMlevel ] = findIMfromHazardCurve(T_periods(1,1),sf,MAFCapacityRDR,hz,0,0)
	else
		[ IMlevel ] = findIMfromHazardCurve(T_periods(1,1),sf,MAFCapacityRDR,hz,1,0)
	end
	
	% change the format of the rdr results so that post-processing function can
	% use them directly
	rdrvalues=cell(1,Nrecs);
	for i=1:Nrecs
		rdrvalues{i}=anslout(i).maxrdrx';
		rdrvalues{i}(1,1)=0;
	end
	
	
	Nvals={IMlevel,RDRlimit};
	
	% note the "tsv" defined herein in the postIDA_simpleprocessIDA function,
	% which is the output of the corresponding function of post-processing
	% the maximum interstory drift ratio. What we do is to get the IM values
	% where each IDA is truncated and force the IDAs for a different EDP to
	% be truncated at the same IM values.
	[cvRDR,cvsa,sa_rangeRDR,RDR1,qdr,savalRDR,dr_range,qSa,lowest_CRDR,tdv,~,tdvaluesRDR,tsvaluesRDR]=...
		postIDA_simpleprocessIDA(svalues,rdrvalues,Nvals,qs,infdr,[],tsv,relaxNaNs);
	plot_cv_IDAs(tsvaluesRDR,tdvaluesRDR,cvRDR,lowest_CRDR,[0,0.08],FigNumbering+8,linestyles,'',0,1,1.5)
	set(gcf,'color','white'); box on; set(gca,'fontsize',FigureFontSize); grid on
	ylabel({'first-mode spectral acceleration';'S_a(T_{1},5%) (g)'},'fontsize',LabelSize);
	xlabel('roof drift ratio, \theta_{roof}','fontsize',LabelSize);
	
	
	if strcmpi(AnalysisType,'single')==1;
		hold on;
		plot(RDR1(RecordsSaT1),IMlevel*ones(1,length(RecordsSaT1)),'o','MarkerFaceColor',Stripe1Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
		saveas(gca,fullfile(ResultsPath,['RDRResults_',AnalysisType,'_stripe_IDAs.fig']));
		EDPval={RDR1(RecordsSaT1)};
		if sum(isnan(EDPval{1,1}))>0;
			statisticsflag=2;
		else
			statisticsflag=1;
		end
		if sum(isnan(EDPval{1,1}))/length(EDPval{1,1})>0.25
			display('more than 25% collapses for RDR, skipping stripe analysis...')
			% in this case you need to modify the code to compute stripe analysis results 
		else
			[ RDRResults.FDrpoDuctSingle,RDRResults.FCrDuctSingle ]=CheckPOs_StripeAnalysis( AnalysisType,RDRlimit,EDPval,IMlevel,confRDR,betacapacity,sf,T_periods(1,1),hz,statisticsflag,[]);
			display(RDRResults)
			saveas(gca,fullfile(ResultsPath,['RDRResults_',AnalysisType,'_stripe_HC.fig']));
			save(fullfile(ResultsPath,['RDRResults_',AnalysisType,'_stripe_Results.mat']),'RDRResults');
		end
	elseif strcmpi(AnalysisType,'double')==1;
		hold on;
		plot(RDR1(RecordsSaT1Double),IMlevel*ones(1,length(RecordsSaT1Double)),'o','MarkerFaceColor',Stripe1Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
		saveas(gca,fullfile(ResultsPath,['RDRResults_',AnalysisType,'_stripe_IDAs.fig']));
		SaDouble=IMdoubleFactor*IMlevel;
		NvalsDouble={SaDouble,[]};
		[~,~,~,RDR2,~,~,~,~,~,~,~,~,~]=postIDA_simpleprocessIDA(svalues,rdrvalues,NvalsDouble,qs,infdr,[],tsv,relaxNaNs);
		hold on
		plot(RDR2(RecordsSaT1Double),SaDouble*ones(1,length(RecordsSaT1Double)),'o','MarkerFaceColor',Stripe2Color,'MarkerEdgeColor','k','MarkerSize',MarkerSize)
		saveas(gca,fullfile(ResultsPath,['RDRResults_',AnalysisType,'_stripe_IDAs.fig']));
		IMlevel2=[IMlevel,SaDouble];
		EDPval={RDR1(RecordsSaT1);RDR2(RecordsSaT1Double)};
		if sum(isnan(EDPval{1,1}))/length(EDPval{1,1})>0.25
			display('more than 25% collapses for RDR thus double stripe analysis results are not computed')
		else
			[ RDRResults.FDrpoDuctDouble ,RDRResults.FCrDuctDouble]=CheckPOs_StripeAnalysis( AnalysisType,RDRlimit,EDPval,IMlevel2,confRDR,betacapacity,sf,T_periods(1,1),hz,1,[]);
			display(RDRResults)
			saveas(gca,fullfile(ResultsPath,['RDRResults_',AnalysisType,'_stripe_HC.fig']));
			save(fullfile(ResultsPath,['RDRResults_',AnalysisType,'_stripe_Results.mat']),'RDRResults')
		end
	elseif strcmpi(AnalysisType,'MAFestimation')==1;
		% plot IDA results 
		hold on
		plot(RDRlimit*ones(1,Nrecs),savalRDR,'o','MarkerFaceColor',PointColor,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
		betaRDR=std(log(sort(savalRDR)));
		medianRDR=median((sort(savalRDR)));
		[RDRResults.lambdaXIDR,RDRResults.lambda50IDR,RDRResults.lambdamIDR]=CheckMAF(confRDR,medianRDR,betaRDR,T_periods(1,1),1,sf,MAFCapacityRDR,bepist);
		% 	display(RDRResults)
		% 	display(MAFCapacityRDRResults)
		saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['RDRResults_',AnalysisType,'_IDAs.fig']));
		saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['RDRResults_',AnalysisType,'_IDAs.png']));
		save(fullfile([ResultsPath,'/MAFestimation'],['RDRResults_',AnalysisType,'_Results.mat']),'RDRResults');
	end
end

%% Collapse (only for design case = c)

if strcmpi(designcase,'c')==1
	
	
	disp('PO: Collapse')
	
	% get the IDA results (IDRval) for the 1st stripe. Note that we keep the
	% tsv values where individual IDAs are truncated to force IDAs
	% of the other EDPs* to truncate at the same IM levels (*Engineering Demand
	% Parameters)
	Nvals={IMlevel,collapselimit};
	[cv,cvsa,sa_range,IDRval,qdr,savalIDR,dr_range,qSa,lowest_C,tdv,tsv,tdvaluesIDR,tsvaluesIDR]=...
		postIDA_simpleprocessIDA(svalues,dvalues,Nvals,qs,infdr,[],truncate_dvalue,relaxNaNs);
	plot_cv_IDAs(tsvaluesIDR,tdvaluesIDR,cv,lowest_C,[0,0.08],FigNumbering,linestyles,'',0,1,1.5)
	set(gcf,'color','white'); box on; set(gca,'fontsize',FigureFontSize); grid on
	ylabel({'first-mode spectral acceleration';'S_a(T_1,5%) (g)'},'fontsize',LabelSize);
	xlabel('maximum interstory drift ratio, \theta^{ }_{max}','fontsize',LabelSize);
	
	
	if strcmpi(AnalysisType,'MAFestimation')==1;
		% plot IDA results 
		hold on
		plot(collapselimit*ones(1,Nrecs),savalIDR,'o','MarkerFaceColor',PointColor,'MarkerEdgeColor','k','MarkerSize',MarkerSize);
		betaCollapse=std(log(sort(savalIDR)));
		medianCollapse=median((sort(savalIDR)));
		[CollapseResults.lambdaXIDR,CollapseResults.lambda50IDR,CollapseResults.lambdamIDR]=CheckMAF(confCollapse,medianCollapse,betaCollapse,T_periods(1,1),1,sf,MAFCapacityCollapse,bepist);
		% 	display(CollapseResults)
		% 	display(MAFCapacityCollapse)
		saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['CollapseResults_',AnalysisType,'_IDAs.fig']));
		saveas(gca,fullfile([ResultsPath,'/MAFestimation'],['CollapseResults_',AnalysisType,'_IDAs.png']));
		
		[Collapse.lambdaXIDRModifiedMedian,Collapse.lambda50IDRModifiedMedian,Collapse.lambdamIDRModifiedMedian]=CheckMAF(confCollapse,SSF*medianCollapse,betaCollapse,T_periods(1,1),1,sf,MAFCapacityCollapse,bepist)
		save(fullfile([ResultsPath,'/MAFestimation'],['CollapseResults_',AnalysisType,'_Results.mat']),'CollapseResults');
		
	end
end