function [cv,cvsa,sa_range,drval,qdr,saval,dr_range,qSa,lowest_C,trunc_dv,...
          trunc_sv,tdvalues,tsvalues]=...
          postIDA_simpleprocessIDA(svalues,dvalues,Nvals,qs,infdr,fitcode,...
          trunc_val,relaxNaNs)
%[cv,cvsa,sa_range,drval,qdr,saval,dr_range,qSa,lowest_C,trunc_dv,...
%           trunc_sv,tdvalues,tsvalues]=...
%           postIDA_simpleprocessIDA(svalues,dvalues,Nvals,qs,infdr,fitcode,...
%           trunc_val,relaxNaNs)
% This routine uses postIDA_interpolateIDA to interpolate the IDAs and generate
% stripes of dvalues for given svalues levels. 
% It will also find 16,50,84 quantiles!
% 
%__________________________________________________________________
% INPUT 
% svalues,dvalues : cell arrays 1xN of vectors of Sas and drifts
% Nvals           : if a single number, then it is the number of values to
%                   compute via spline interpolation both for dr given SA and 
%                   for Sa given dr.
%                   if a vector of two, then first number is as above,
%                   second is the maxdrift up to which you want dr_range to
%                   reach. This is very useful when you want to have
%                   stripes of Sa|drift at the same drift values for
%                   many different buildings (or cases). Note that in this
%                   case only the Nvals(1) is used for the sa-stripes
%                   (dividing up to maxsa).
%                   Otherwise it must be a cell array of length 2. 
%                   Nvals{1} is a SORTED vector of Sa-levels to compute drift
%                   stripes. If empty, no stripes are generated
%                   Nvals{2} similarly a SORTED vector of dr-levels.
% qs              : a vector with elements in [0,1] to use for computing
%                   quantiles. For example: [0.16,0.50,0.84]
% infdr           : A maximum drift above which the structure is assumed 
%                   collapsed and all such higher drifts are replaced by Inf.
%                   The reason I am using this is that excessive drifts, say 10
%                   have no physical meaning and will make the fits terrible!
%                   Default is "1". Note that if you are fitting normalized R vs mu 
%                   data then something like 20 may be more reasonable!
% fitcode         :  0 = piecewise linear fit
%                    1 = std. natural splines (cscvn2.m) (DEFAULT)
%                    2 = adv. natural splines (fitIDA.m)
% relaxNaNs       : if 0 (default) then the first NaN signals collapse.
%                   This is good for robust models, where we are certain that
%                   convergence is easy to achieve.
%                   if 1 (careful!) then if there exists a convergent run
%                   with drift less than Th_drift directly above an early NaN, 
%                   then that NaN is considered bogus (numerical non-convergence but
%                   not dynamic instability) and it is dropped! So instead
%                   of calling it a "resurrection", we decide that we had
%                   no collapse in the first case. 
%                   if 2 (VERY careful!) even two or more consecutive NaNs could be 
%                   indeed considered collapse if at least one convergent
%                   run (with drift<Th_drift) exists above them. This is
%                   for very shaky models only.
% truncval        : if single number then it is a truncation drift. All
%                   IDAs are truncated at that drift. If a vector then it
%                   is a set of truncation Sa's, one for each IDA.
%
% OUTPUT 
% dr              : array N*length(sa_range), each column is one
%                   stripe at fixed Sa-level. Each row corresponds
%                   to one record.
% cv              :  use cv{.} to plot spline fits (x=drift)
% cvsa            :  use cvsa{.} to compute drifts given SAs (x=Sa)
% sa_range,drval  : levels of sa and corresponding stripes of drift
% saval,dr_range  : levels of drift and corresponding stripes of sa
% qSa, qdr        : fractiles of Sa,dr (As given by qs) at stripes defined by
%                   dr_range or sa_range values respectively
% lowest_C        : array Nx1, of indices of the lowest (in Sa)
%                   convergent points. One for each IDA. This is a
%                   by-product of the filtering done to do the
%                   interpolation. Useful if you want to place some
%                   text at the end of an IDA-line in a plot!
% trunc_dv,trunc_sv : the dv and sv values where truncation has occured
% tsvalues,tdvalues : the svalues and dvalues corresponding to the truncated
%                     IDAs that are returned in cv.
%___________________________________________________________________    
%       
% It does not need an ida-object to do the postprocessing and 
% provides much less info compared to prostIDA_processIDA.m
%
% Created 09/Nov/2004, Copyright (c) 2004 by D.Vamvatsikos
% Updated 19/Feb/2005: Made compatible with new postIDA_interpolateIDA.
%                      It passes the trunc_val and outputs trunc_sv,trunc_dv
%                      for truncated IDAs!! Now, the default infdr value is
%                      Inf instead of 1!
% Updated  8/May/2006: relaxNaNs parameter added to properly handle non-robust 
%                      models that may show early collapses due to
%                      non-convergence while convergent runs clearly exist
%                      at higher IMs. This is for LA9_2Dmfrag that shows
%                      this behavior, with clear indications that it is not
%                      a resurrection!
% Updated 29/Feb/2008: Now Nvals is allowed to be a vector of two scalars.
%                      First number is the number of discretization levels
%                      to produce, second number is the maxdrift to impose
%                      on dr_range.
% Updated 23/May/2010: Added checks before computing qSa, qdr on whether
%                      saval or drval is empty. Otherwise "quantile" fails.
% Updated 06/Sep/2010: Fixed a small logical error in the above. I forgot
%                      to place parenthesis around the ~(x||y) clause and
%                      it was working as ~x||y. It is fine now.

% defaults are no plotting and fitting through cscvn2.m
plotflag=0;
% default behavior is to keep all NaNs as strict collapses.
if nargin<8, relaxNaNs=0; end
if nargin<7, trunc_val=[]; end
if nargin<6||isempty(fitcode), fitcode=1; end
if nargin<5||isempty(infdr), infdr=Inf; end
if nargin<4, 
   qs=[]; 
elseif size(qs,2)>1
   % make sure it is a single column!
   qs=qs';
end
if nargin<3, Nvals=[]; end


%// number of IDAs in current suite
maxR=length(svalues);  
% replace all drifts above infdr with Inf.
for R=1:maxR
   indx=find(dvalues{R}>infdr);
   dvalues{R}(indx)=NaN;
end


if isempty(Nvals)
   sa_range=[]; 
   dr_range=[];
elseif iscell(Nvals)&&length(Nvals)==2
   sa_range=Nvals{1};
   dr_range=Nvals{2};
elseif isa(Nvals,'double')&&length(Nvals)<=2
   % Nvals must be a scalar!!
   %// get the last CONVERGENT sa of each IDA (actually the maximum Sa of each!)
   %// unfortunately, fancy indexing doesn't work on cells 
   %// i.e  last_sa=cat(1,svalues{:}(end)) won't run!
   for R=1:maxR
      % index to last convergent point in the IDA. This will include
      % all earlier resurrections! Not the same as lowest_C in general.
      ilastC(R)=max(find(~isnan(dvalues{R})&(~isinf(dvalues{R}))));
      last_sa(R)=svalues{R}(ilastC(R));
      last_dr(R)=dvalues{R}(ilastC(R));
      % or last_sa(R)=nanmax(svalues{R});  % maybe better!!!
   end  
   
   % maximum Sa value in all IDAs. If svalues are row-vectors or
   % column vectors, using the two "max" in a row will make this work!
   % maxsa=max(max(cat(1,svalues{:})));
   if ~isempty(trunc_val)
      % there is a valid truncation value. Use it to better define
      % the limits of dr_range and sa_range
      if length(trunc_val)==1
         maxdr=min(trunc_val,quantile(last_dr',0.90));
         maxsa=max(last_sa);
      else
         % maybe I should use the 90% of the last_dr values, so that a
         % single IDA going nuts (too large DM) will not throw us off.
         maxdr=quantile(last_dr',0.90);
         maxsa=min(max(last_sa),max(trunc_val));
      end
   else
      maxsa=max(last_sa);
      maxdr=quantile(last_dr',0.90);
   end
   % vectors of sa,dr-values to use for drift-stripes generation
   if length(Nvals)==2,
      maxdr=Nvals(2);
   end
   sa_range=linspace(0,maxsa,Nvals(1));
   dr_range=linspace(0,maxdr,Nvals(1));
else
   error('Incorrect argument Nvals passed: Must be scalar or cell of length 2')
end


% fit the curves and generate stipes of drift given Sa
[drval,cv,cvsa,lowest_C,saval,trunc_dv,trunc_sv,tdvalues,tsvalues]=...
   postIDA_interpolateIDA(svalues,dvalues,sa_range,fitcode,plotflag,...
   dr_range,trunc_val,relaxNaNs);

% quantiles of Sa given drift
if ~(isempty(saval)||isempty(qs))
   qSa=quantile(saval,qs);
else 
   qSa=[];
end
% quantiles of drift given Sa
if ~(isempty(drval)||isempty(qs))
   qdr=iquantile(drval,qs);
else
   qdr=[];
end
