function [svalues,dvalues,Tperiods,recSaT1,recPGA,thfilename,nstories,nrec,...
          rdrvalues,iidrvalues,pfavalues]=processAnlsout2Dframe(s,g,addPGA)
% 
% Use this function to process loaded files of the .sida.mat type. As long as
% this is a 2D frame structure, this routine will parse the runIDA.... output
% and present you with a set of IDRs, PFAs, RDRs to work with.
%
%____________________________________________________________________________
% INPUT
% s      : a structure resulting from loading a ".sida.mat" file, e.g. as in
%          "s=load('2Dframe_12recs.sida.mat')"
% g      : gravity constant to turn accelerations into g's. Default is 9.81 to
%          suite units of m/sec2 (as used in my opensees scripts) 
% addPGA : if 1, then if PGA at the ground floor is not included in anlsout, it
%          will be added here! Very useful for older building results where I
%          forgot to include an acceleration recorder on the ground.
% OUTPUT
%
% rdrvalues: cell array 1xNrec, 
%            each entry contains Nim roof drift values, one
%            per value of the corresponding svalues entry
% iidrvalues: cell array 1xNstories
%            each entry is a 1xNrec cell, containing peak interstory 
%            drift values for each IM level.
% pfavalues : cell array 1xNstories (if ground floor PGA is not present and
%            addPGAflag=0, otherwise, either if PGA is included in anlsout or
%            this routine is instructed to insert it, you get a 1x(Nstories+1)
%            cell. Each entry is a 1xNrec cell, of peak floor accelerations.
%_____________________________________________________________________________
%
% Created 24/Dec/2014: Derived from code used in CostAssessGEM_RC7;
%
% EXAMPLE: 
%   see RMTK_testing.m
%   I should also integrate this to all my CostAsesss_BDLG...m files.

% default is to add the PGA for the ground floor whenever it is missing
if nargin<3, addPGA=1; end
if nargin<2, g=9.81; end

% Multiply by this to transform PFA values from their units (typically m/s2)
% to units of g.
invg=1/g;

svalues=s.svalues;
dvalues=s.dvalues;
anlsout=s.anlsout;
Tperiods=s.T_periods;
recSaT1=s.record_saxy(:,1);
recPGA=s.record_pgaxy;
thfilename=s.thfilename;
nstories=size(s.anlsout(1).maxidr_mx,1); 
nrec=length(svalues);

zk=zeros(nstories,1);
maxR=length(thfilename);
rdrvalues=cell(1,maxR);
iidrvalues=cell(1,nstories);
pfavalues=cell(1,nstories+1);
for k=1:maxR
   % remove the NaNs for the (0,0) run and introduce zeros!
   rdrvalues{k}=[0,anlsout(k).maxrdrx(2:end)]';    
   %iidrvalues{i}{k}=[zk,anlsout{i}(k).maxidr_mx(:,2:end)]';
   %pfavalues{i}{k}=[zk,anlsout{i}(k).maxacc_mx(:,2:end)]';
   itmp=num2cell([zk,anlsout(k).maxidr_mx(:,2:end)]',1);
   atmp=num2cell([zk,anlsout(k).maxacc_mx(:,2:end)*invg]',1);
   if addPGA && length(atmp)==nstories
      % offset needed to insert the ground floor accel at index 1
      ioff=1;
   else 
      ioff=0;
   end
   for j=1:nstories
      iidrvalues{j}{k}=itmp{j};
      pfavalues{j+ioff}{k}=atmp{j};
   end
   if ioff
      % this is where you add PGA at ground floor 1
      % k=thfilename, j=1 is the ground floor
      pfavalues{1}{k}=svalues{k}/recSaT1(k)*recPGA(k);
   else
      % no need for the above, ioff==0 and thus the ground floor PFA is already
      % at its place. Just add the roof PFA and you are done.
      pfavalues{j+1}{k}=atmp{j+1};
   end
end


