function [truncatedcv,truncval,truncflag]=truncateDPO(cv,Th_drift)
%-------------------------------------------------------------------------
% INPUT  
%   cv : A cell array 1 x maxR of curves
%   Th_drift :    a scalar, the drift where we truncate the curves
%                 or a vector 1xmaxR, containing separate Th_drift values
%                 for each IDA. The latter case is useful if you use 
%                 flipcscvn to invert the (x,y) of the curves and you want
%                 to truncate at several given SA values!
% 
% OUTPUT
%   truncatedcv : a 1xmaxR cell array containing the truncated version
%                 of input curves
%   truncval    : the sa value where the truncation occured (if any) or 
%                 the last svalue if no truncation occured (Th_drift was too
%                 large)
%   truncflag   : a vector (size maxR) of flags: 0=no truncation, 1=truncation
%                 occured
%   
%-------------------------------------------------------------------------
%
% Copyright (c) 1999 by D.Vamvatsikos
% Updated: Feb 19, 2005: Returns truncflag, including 0 or 1 for each curve
%                        with truncation or not. Very useful for the new
%                        postIDA_interpolateIDA.m. I have added a check
%                        that no truncation occurs if the truncation tvalue
%                        is higher or equal to the maximum break value.
% Updated: Mar 07, 2005: Fixed a mistake in line 59, where just dummy_y was
%                        assigned instead of min(dummy_y). This would cause
%                        an error if multiple sa-values appear at the same 
%                        Th_drift

maxR=length(cv);
if length(Th_drift)==1
   Th_drift=repmat(Th_drift,1,maxR); 
elseif length(Th_drift)~=maxR; 
   error('Th_drift must be of length 1 or same length as the number of records') 
end

for R=1:maxR
   [dummy_y,dummy_flag,tvalue]=x2y(Th_drift(R),cv{R}); 
   %// we are going to truncate at the earliest (minimum t)
   %// point that we reach drift equal to Th_drift.
   %// This is consistent to our new definition of capacity
   [breaks,coefs]=ppbrk(cv{R});
   % usually dummy_flag should indicate whether the truncation value 
   % supplied actually does truncate the IDA. But if it happens to be
   % the last point of the IDA, then it may well be that within some small
   % tolerance (usually about 1e-16), dummy_flag==0 and the tvalue returned
   % is actually about 1e-16 larger or equal to the last break!! Make sure
   % that you treat such cases as "no truncation" by requesting 
   % that "all(breaks<=min(tvalue))"
   if dummy_flag==1 || all(breaks<=min(tvalue))
     % Th_drift is never reached, no truncation occurs 
     truncflag(R)=0;
     truncatedcv{R}=cv{R};
     % As truncation Sa return the maximum Sa of the curve. Alternatively
     % you could return Inf, but this helps placing flatlines in a single command!
     dummy_xy=ppual(cv{R},max(breaks));
     truncval(R)=dummy_xy(2);
   else
     %//truncate ! 
     truncflag(R)=1;
     truncval(R)=min(dummy_y);
     tvalue=min(tvalue);
     %[breaks,coefs]=ppbrk(cv{R});
     %// keep all breaks less than tvalue (where we cut)
     %// and append tvalue afterwards.
     newbreaks=[breaks(find(breaks<tvalue)),tvalue];     
     %// keep only as many polynomial pieces as there are (breaks-1)
     %// for each of x(t) and y(t)
     newcoefs=coefs(1:2*(length(newbreaks)-1),:);
     truncatedcv{R}=ppmak(newbreaks,newcoefs,2);
   end
end

