function [dydx,ddydx,flag]=x2dxy(x,cv)
% function [dydx,ddydx,flag]=x2dxy(x,cv)
%-----------------------------------------------------------------------
% INPUT
% cv : Natural Spline curve produced thru "cscvn" or similar
%      it is essentialy a piecewise polynomial in pp-form, that
%      uses a parameter t to produce (x,y) values.
%      i.e. cv(t)=(x(t),y(t)) ( R-->R^2 function )
%      what this routine does is take an x value (i.e. a SA), 
%      find corresponding t and then produce slope and curvature at
%      that point. Careful, both are in terms of  of y vs x.
% OUTPUT
% dydx : slope at the (x,y) point
% ddydx: Curvature at the (x,y) point.
% flag : If it is 1 then the specified x is not producing an acceptable
%        value of "t", i.e the routine will only interpolate(flag=0), but
%        not extrapolate (flag=1). If such an "x,y" is required, an obsene 
%        value of (x,y)=(10,10) will be returned and flag is raised to 1.
%------------------------------------------------------------------------
% CAUTION :
% Due to the nature of the spline approximation, i.e piecewise cubic
% polynomials, even though macroscopically it is not apparent, you should 
% expect quite a few minor slope variations. 
% e.g. even if you supply a perfect monotonic set of points, the
% approximation will be mostly monotonic, but in some small intervals it
% will wiggle back and forth. So don't trust your eyes all the time
% NOTE: regarding x2y.m use
% when used inversly, i.e x=drift,y=Sa,  sometimes the same x  has 
% multiple corresponding y's (Sa's). Then, as in the output the y's
% come in the order they were found, "y" is ordered in increasing
% parameter "t", which almost always means increasing Sa. This is 
% useful to interpret the output of x2dxy.m . The multiple dydx,ddydx 
% coming out correspond to increasing values of Sa!! See traceDPO.m to see
% how this is implemented to get a single (the needed one) value of dydx
% out of a multiple output.
% (Last Updated: April 22th, 1999)
% Copyright (c) 1999 by D.Vamvatsikos

[y,flag,t]=x2y(x,cv);
dcv=fnder(cv,1);
[brk,C,n,k]=ppbrk(dcv); % get breaks, polynomial coefficients and # of breaks 

if flag==1
  % extrapolation danger. Raise flag.
  dydx=NaN;
  ddydx=NaN;
else
  xy=fnval(cv,t);  % now evaluate the "cv" curve at found "t"
  y=xy(2,:);  % separate the y's from xy points
  x=xy(1,:);
  dxydt=fnval(dcv,t); % (dx/dt,dy/dt) points
  dxdt=dxydt(1,:);  % dx/dt
  dydt=dxydt(2,:);  % dy/dt
  dydx=dydt./dxdt;  % dy/dx
  ddcv=fnder(dcv,1); % 2nd derivative w.r.t "t"
  ddxydt=fnval(ddcv,t);
  ddxdt=ddxydt(1,:); % ddx/d(t^2)
  ddydt=ddxydt(2,:); % ddy/d(t^2)
  ddydx=(ddydt.*dxdt-ddxdt.*dydt)./(dxdt).^3; % ddy/d(x^2)
end
