function runIDA_MRF4Story(anlsdir,recorddir)
% runIDA_MRF4Story(anlsdir,recorddir)
%
% Runs IDA analysis for a preselected suite of records on
% Lumped_Mark4Story.tcl by OpenSEES.
%________________________________________________________
% INPUT
%   anlsdir : Where the opensees model ".tcl" file resides. It should be
%             configured so that when invoked from within that directory it
%             will run flawlessly
%  recorddir: Where the records used for analyzing the model ".tcl" file reside.
%             Note that DV routines will generally apply a small
%             modification, moving their 4-line header (PEER style) to the
%             tail.
% OUTPUT
%   None, but it saves a lot in files.
%________________________________________________________
% NOTE: anls.savefilename is considered relative to anls.anlsdir
%_________________________________________________________________________
%
% Created 26/Nov/2011, Copyright (c) 2008 by D.Vamvatsikos
% Modified 08/07/2019 by A. Chatzidaki & D. Vamvatsikos to run the 4-story MRF model

if nargin<2; error('need at least recorddir/anlsdir inputs'); end



% Run IDAs for 44 (22 pairs) of records, both X,Y directions
anls.thfilename={'NORTHR/MUL009.AT2','NORTHR/MUL279.AT2','NORTHR/LOS000.AT2',...
	'NORTHR/LOS270.AT2','DUZCE/BOL000.AT2','DUZCE/BOL090.AT2','HECTOR/HEC000.AT2',...
	'HECTOR/HEC090.AT2','IMPVALL/H-DLT262.AT2','IMPVALL/H-DLT352.AT2',...
	'IMPVALL/H-E11140.AT2','IMPVALL/H-E11230.AT2','KOBE/NIS000.AT2',...
	'KOBE/NIS090.AT2','KOBE/SHI000.AT2','KOBE/SHI090.AT2','KOCAELI/DZC180.AT2',...
	'KOCAELI/DZC270.AT2','KOCAELI/ARC000.AT2','KOCAELI/ARC090.AT2',...
	'LANDERS/YER270.AT2','LANDERS/YER360.AT2','LANDERS/CLW-LN.AT2',...
	'LANDERS/CLW-TR.AT2','LOMAP/CAP000.AT2','LOMAP/CAP090.AT2','LOMAP/G03000.AT2',...
	'LOMAP/G03090.AT2','MANJIL/ABBAR--L.AT2','MANJIL/ABBAR--T.AT2',...
	'SUPERST/B-ICC000.AT2','SUPERST/B-ICC090.AT2','SUPERST/B-POE270.AT2',...
	'SUPERST/B-POE360.AT2','CAPEMEND/RIO270.AT2','CAPEMEND/RIO360.AT2',...
	'CHICHI/CHY101-E.AT2','CHICHI/CHY101-N.AT2','CHICHI/TCU045-E.AT2',...
	'CHICHI/TCU045-N.AT2','SFERN/PEL090.AT2','SFERN/PEL180.AT2','FRIULI/A-TMZ000.AT2',...
	'FRIULI/A-TMZ270.AT2'};

% scale by the first period, which appears in X-direction.
anls.iscaleT=1;
anls.comp=[3,0,0]; % X component only, Sa(T1) is calculated for X-dir
anls.rectype='silva';
% this is the default damping used for estimating Sa(T1). Leave it at 5%
% despite of your model's damping. The reason is that hazard curves almost
% always come out for Sa(T,5%).
anls.def_zeta=0.05;


% OBSERVE How I use Unix standard slashes. This is compatible with TCL and Opensees
% and matlab does not complain.
% NOTE: it is best if you also include the drive letter!
anls.recorddir=recorddir;
anls.anlsdir=anlsdir;
anls.infile='Lumped_Mark4Story.tcl'; % name of the file to run


% This is the directory where the output is stored.
anls.outdir='./';
% use the openSees executable residing in the parent directory of anlsdir!
anls.exefile='../openSees';
anls.blackbox_anlsproc='anlsproc_oseesNDi';
anls.blackbox_postproc='postproc_osees2Di_MRF4Story';
% extra input passed to postproc. Must be a cell array containing all the values that
% will be passed. Note that when calling postproc, the argument is <anls.postproc_input{:}>
% to create a comma-separated list of values. This is not used for SDOF
% analysis but it is very useful e.g. for bridges as it may be used to
% decide what is the main EDP reported back to traceIDA to guide the
% running of the IDA. For example, for a bridge this could be pier drift or
% deck displacement. For frames the best is usually max interstory drift,
% so there is not much of a choice. Of course, your postprocessing routine
% should be customized to achieve this.
anls.postproc_input={};

% Read a bit in traceIDA to understand what all these mean.
% Under these settings it will perform 13 runs per record 
trace.maxrpr=12; % max runs per record
trace.iniSa=0.1;
trace.incSa=0.2;
% Set a happy 10% drift limit. Stop the analysis if you exceed that.
% Very useful if your structure never experiences collapse
trace.Th_drift=0.10;
% max allowable Sa is 50g
trace.Th_Sa=50;
trace.mode=[2 0];
% demand high resolution if an Inf or Th_drift are reached (1/20!)
trace.hf=[20,6,20];
trace.eSa=0.05;
trace.edr=0;

% name of the file with IDA results
anls.savefilename=sprintf('MRF4Story_Lumped.sida.mat');

if exist(fullfile(anls.anlsdir,anls.savefilename),'file')
	fprintf('Savefile %s already exists. Aborting\n',anls.savefilename)
else
	%%% USE FOR SINGLE CPU
	[svalues,dvalues,anlsout,T_periods,runs,record_saxy,record_pgaxy]=runIDA_ND(anls,trace);
	% no need to save the output. This is already done. I am just
	% supplying these output vars in case you need to do something with
	% them here.
end